# RFPYE
> Este módulo tem como objetivo o processamento e extração otimizada de dados dos arquivos `.bin` de monitoramento do espectro provenientes do script Logger executados nas estações de Monitoramento CRFS RFeye Node. Para tal utilizamos as várias funcionalidades da biblioteca <a href='https://fastcore.fast.ai/basics.html'>fastcore</a>, que expande e otimiza as estruturas de dados da linguagem python. 


## Instalação

`Ubuntu`: 

```bash
python -m pip install rfpye
```

`Windows`:

Como parte dessa lib utiliza código c compilado com `Cython`, é preciso que um compilador `C` esteja instalado. Em Windows, uma opção é instalar a versão apropriada do Visual Studio seguindo as orientações do site da Microsoft. No entanto uma solução mais simples e a recomendada é utilizando o `conda`.

Primeiramente instale o [miniconda](https://docs.conda.io/en/latest/miniconda.html). Com o conda instalado e disponível no seu `PATH` ou através do `Anaconda Prompt` execute o comando:

```bash
conda install -c intel libpython m2w64-toolchain -y

echo [build] > %CONDA_PREFIX%\Lib\distutils\distutils.cfg

echo compiler = mingw32 >> %CONDA_PREFIX%\Lib\distutils\distutils.cfg
```

Depois disso basta instalar normalmente a lib:
`python -m pip install rfpye`

Em Linux normalmente o sistema já possui o compilador `gcc` instalado então basta executar o comando `pip install` acima.

## Como utilizar
Abaixo mostramos as funcionalidades principais dos módulos, utilizando-os dentro de algum outro script ou `REPL`

Precisamos necessariamente de um diretório de entrada, contendo um ou mais arquivos `.bin`
> Mude os caminhos abaixo para suas pastas locais

```python
from fastcore.xtras import Path
from rfpye.utils import get_files
from rich import print
```

A função abaixo baixa alguns arquivos de exemplo:

```python
path = Path(r'binfiles')
if not path.exists() or not len(get_files(path, extensions=['.bin'])):
    path = Path('.')
    !wget --header 'Host: raw.githubusercontent.com' --user-agent 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:89.0) Gecko/20100101 Firefox/89.0' --header 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8' --header 'Accept-Language: pt-BR,pt;q=0.8,en-US;q=0.5,en;q=0.3' --referer 'https://github.com/EricMagalhaesDelgado/SpecFiles/blob/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002092_210208_T202310_CRFSBINv.5.bin' --header 'DNT: 1' --header 'Upgrade-Insecure-Requests: 1' 'https://raw.githubusercontent.com/EricMagalhaesDelgado/SpecFiles/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002092_210208_T202310_CRFSBINv.5.bin' --output-document 'rfeye002092_210208_T202310_CRFSBINv.5.bin'
    !wget --header 'Host: raw.githubusercontent.com' --user-agent 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:89.0) Gecko/20100101 Firefox/89.0' --header 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8' --header 'Accept-Language: pt-BR,pt;q=0.8,en-US;q=0.5,en;q=0.3' --referer 'https://github.com/EricMagalhaesDelgado/SpecFiles/blob/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002092_210208_T203131_CRFSBINv.2.bin' --header 'DNT: 1' --header 'Upgrade-Insecure-Requests: 1' 'https://raw.githubusercontent.com/EricMagalhaesDelgado/SpecFiles/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002092_210208_T203131_CRFSBINv.2.bin' --output-document 'rfeye002092_210208_T203131_CRFSBINv.2.bin'
    !wget --header 'Host: raw.githubusercontent.com' --user-agent 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:89.0) Gecko/20100101 Firefox/89.0' --header 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8' --header 'Accept-Language: pt-BR,pt;q=0.8,en-US;q=0.5,en;q=0.3' --referer 'https://github.com/EricMagalhaesDelgado/SpecFiles/blob/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002292_210208_T202215_CRFSBINv.4.bin' --header 'DNT: 1' --header 'Upgrade-Insecure-Requests: 1' 'https://raw.githubusercontent.com/EricMagalhaesDelgado/SpecFiles/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002292_210208_T202215_CRFSBINv.4.bin' --output-document 'rfeye002292_210208_T202215_CRFSBINv.4.bin'
    !wget --header 'Host: raw.githubusercontent.com' --user-agent 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:89.0) Gecko/20100101 Firefox/89.0' --header 'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8' --header 'Accept-Language: pt-BR,pt;q=0.8,en-US;q=0.5,en;q=0.3' --referer 'https://github.com/EricMagalhaesDelgado/SpecFiles/blob/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002292_210208_T203238_CRFSBINv.3.bin' --header 'DNT: 1' --header 'Upgrade-Insecure-Requests: 1' 'https://raw.githubusercontent.com/EricMagalhaesDelgado/SpecFiles/main/Combo3%20(CRFS%20Bin%20-%20DataTypes%204%2C%207%2C%208%2C%2060-65%20e%2067-69)/rfeye002292_210208_T203238_CRFSBINv.3.bin' --output-document 'rfeye002292_210208_T203238_CRFSBINv.3.bin'

```

A função `parse_bin` é a função principal que encapsula o processamento dos arquivos bin.


<h4 id="parse_bin" class="doc_header"><code>parse_bin</code><a href="https://github.com/ronaldokun/rfpye/tree/master/rfpye/parser.py#L42" class="source_link" style="float:right">[source]</a></h4>

> <code>parse_bin</code>(**`bin_file`**:`Union`\[`str`, `Path`\])

Receives a CRFS binfile and returns a dictionary with the file metadata, a GPS Class and a list with the different Spectrum Classes
A block is a piece of the .bin file with a known start and end and that contains different types of information.
It has several fields: file_type, header, data and footer.
Each field has lengths and information defined in the documentation.
Args:
    bin_file (Union[str, Path]): path to the bin file

Returns:
    Dictionary with the file metadata, file_version, string info, gps and spectrum blocks.


## Extração de Dados

Vamos listar arquivos da última versão do script Logger, **CRFS Bin - Versão 5**

```python
files = get_files(r'D:\OneDrive - ANATEL\Sensores', extensions=['.bin'])
file = files.shuffle()[0]
```

```python
%%time
dados = parse_bin(file)
```

    Wall time: 14.6 s
    

```python
print(dados)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span>
    <span style="color: #008000; text-decoration-color: #008000">'filename'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002130_210622_T151702.bin'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_version'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">23</span>,
    <span style="color: #008000; text-decoration-color: #008000">'string'</span>: <span style="color: #008000; text-decoration-color: #008000">'CRFS DATA FILE V023'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'hostname'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002130'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'method'</span>: <span style="color: #008000; text-decoration-color: #008000">'ScriptRFeye2021_v.1'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'unit_info'</span>: <span style="color: #008000; text-decoration-color: #008000">'Stationary'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_number'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'identifier'</span>: <span style="color: #008000; text-decoration-color: #008000">'INFO'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'gps'</span>: GPS Data - Median of Coordinates: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.68619</span>:<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span> Altitude: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">210.10</span> 
#Satellites: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'spectrum'</span>: <span style="font-weight: bold">[</span><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">300</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 1 de 10).'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">18457</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">310</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC </span>
<span style="color: #008000; text-decoration-color: #008000">2021 (Faixa 2 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">155.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">165.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1024</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">18457</span>,
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">100</span>,
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PRD 2021 (Faixa principal 1 de 4).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">50.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">90.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBμV/m'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1024</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-70.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-70.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">110</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PRD 2021 (Faixa principal 2 de </span>
<span style="color: #008000; text-decoration-color: #008000">4).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">70.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">110.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBμV/m'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1024</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-29.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-29.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">120</span>, 
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PRD 2021 (Faixa principal 3 de 4).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">170.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">220.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBμV/m'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1280</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-69.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-69.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">130</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PRD 2021 (Faixa principal 4 de </span>
<span style="color: #008000; text-decoration-color: #008000">4).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">470.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">700.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBμV/m'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">5888</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-42.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-42.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">200</span>, 
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF 2021 (Faixa 1 de 6).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">700.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">960.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, 
<span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">6656</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">210</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF 2021 (Faixa 2 de 6).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1710.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1980.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">6912</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">220</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF 2021 </span>
<span style="color: #008000; text-decoration-color: #008000">(Faixa 3 de 6).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2100.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1002168.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1792</span>, 
<span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, 
<span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">230</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF 2021 (Faixa 4 de 6).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2290.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2390.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2560</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">240</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF 2021 (Faixa 5 de 6).'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2500.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2690.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">4864</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">250</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEF </span>
<span style="color: #008000; text-decoration-color: #008000">2021 (Faixa 6 de 6).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3290.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3700.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">10496</span>, 
<span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, 
<span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">320</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 3 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">320.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">340.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">512</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">330</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 4 de 10).'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">400.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">410.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">256</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">340</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC </span>
<span style="color: #008000; text-decoration-color: #008000">2021 (Faixa 5 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">960.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001218.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">6656</span>, 
<span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, 
<span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">350</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 6 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001388.999</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001428.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1280</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">360</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 </span>
<span style="color: #008000; text-decoration-color: #008000">(Faixa 7 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1530.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001648.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3072</span>, 
<span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, 
<span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">370</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 8 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2690.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1002898.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">5376</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">380</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 </span>
<span style="color: #008000; text-decoration-color: #008000">(Faixa 9 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">5000.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">5160.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">4096</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">390</span>,
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 10 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1005338.999</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1005458.999</span>, 
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3328</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)]</span>
<span style="font-weight: bold">}</span>
</pre>



A saída da função é um dicionário, com os metadados do arquivo.

## GPS
No entanto as duas chaves mais importantes do dicionário retornado são `gps` e `spectrum`

Se você imprimir a classe retornada pela chave `gps` é retornado um resumo dos seus atributos:

```python
print(dados['gps'])
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace">GPS Data - Median of Coordinates: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.68619</span>:<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span> Altitude: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">210.10</span> #Satellites: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span>
</pre>



> Para extrair os atributos em si de dado objeto e retorná-los todos num dicionário, o módulo utils tem a função auxiliar `getattrs`


<h4 id="getattrs" class="doc_header"><code>getattrs</code><a href="https://github.com/ronaldokun/rfpye/tree/master/rfpye/utils.py#L146" class="source_link" style="float:right">[source]</a></h4>

> <code>getattrs</code>(**`obj`**:`Any`, **`attrs`**:`Iterable`\[`T_co`\]=*`None`*)

Receives an object and return the atributes listed in `attrs`, if attrs is None return its public attributes


```python
print(getattrs(dados['gps']))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span><span style="color: #008000; text-decoration-color: #008000">'altitude'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">210.1</span>, <span style="color: #008000; text-decoration-color: #008000">'latitude'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.686185</span>, <span style="color: #008000; text-decoration-color: #008000">'longitude'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span>, <span style="color: #008000; text-decoration-color: #008000">'num_satellites'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span><span style="font-weight: bold">}</span>
</pre>



Os atributos listados são os valores consolidados por meio da __mediana__ dos diversos blocos de GPS do arquivo. 

### Dados Brutos de GPS
> Caso desejar a lista original de valores, os atributos são os mesmos mas precedidos de `_`, o que os torna __atributos privados__ em python, isso somente quer dizer que não são explicitados em algus métodos como `getattrs`, pois normalmente não são acessíveis diretamente, mas nada impede que sejam acessados.

```python
dados['gps']._latitude
```




    (#9058) [-10.686196,-10.686173,-10.686203,-10.686203,-10.686191,-10.686178,-10.686201,-10.686205,-10.686205,-10.686209...]



```python
dados['gps']._longitude
```




    (#9058) [-37.439175,-37.439172,-37.439143,-37.43916,-37.439191,-37.439171,-37.439177,-37.439192,-37.439172,-37.43917...]



```python
dados['gps']._altitude
```




    (#9058) [211.4,221.8,213.3,210.1,223.2,211.1,206.6,212.6,213.1,210.5...]



```python
dados['gps']._num_satellites 
```




    (#9058) [11,11,12,10,11,11,11,12,12,12...]



## Dados de Nível Espectral
Cada arquivo bin normalmente possui vários fluxos de espectro distintos, cada fluxo espectral é uma classe Python, na chave `spectrum` é retornado uma lista com todos os fluxos de espectro.

```python
fluxos = dados['spectrum']
print(len(fluxos))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">20</span>
</pre>



Vamos investigar um deles:

```python
fluxo = fluxos[0]
```

Ao imprimir um fluxo é mostrado informações mínimas sobre o seu conteúdo:

```python
print(fluxo)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace">Blocks of Type: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, Thread_id: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">300</span>, Start: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span> MHz, Stop: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span> MHz
</pre>



A função `repr` retorna uma representação com todos os metadados do fluxo:

```python
print(repr(fluxo))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">300</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 1 de 10).'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">18457</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>
</pre>



Qualquer um dos atributos listados podem ser acessados diretamente:

```python
print(fluxo.description) , print(fluxo.bw)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace">PMEC <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2021</span> <span style="font-weight: bold">(</span>Faixa <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span> de <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">10</span><span style="font-weight: bold">)</span>.
</pre>




<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">18457</span>
</pre>






    (None, None)



No entanto o principal atributo de um fluxo de espectro são os valores de nível medidos, os valores medidos são retornados por meio do atributo `levels`:

```python
print(fluxo.levels)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">[[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-93.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-99.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span> <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-85</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-86.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span><span style="font-weight: bold">]</span>
 <span style="font-weight: bold">[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-93.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span> <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-88</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-88.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>. <span style="font-weight: bold">]</span>
 <span style="font-weight: bold">[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-86.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-86.5</span> <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-86</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-85.5</span><span style="font-weight: bold">]</span>
 <span style="color: #808000; text-decoration-color: #808000">...</span>
 <span style="font-weight: bold">[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-91</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-92</span>.  <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-92</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-93.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-96.5</span><span style="font-weight: bold">]</span>
 <span style="font-weight: bold">[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-92</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-93</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-95</span>.  <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-92.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-91.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-91</span>. <span style="font-weight: bold">]</span>
 <span style="font-weight: bold">[</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-87.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-87.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-89.5</span> <span style="color: #808000; text-decoration-color: #808000">...</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>.  <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-94.5</span> <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-94</span>. <span style="font-weight: bold">]]</span>
</pre>



```python
print(f'Formato da matriz com os níveis: {fluxo.levels.shape}')
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace">Formato da matriz com os níveis: <span style="font-weight: bold">(</span><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9058</span>, <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span><span style="font-weight: bold">)</span>
</pre>



O nº de linhas da matriz nos dá o número de pontos medidos naquele dado fluxo e as colunas o número de traços no qual o Span ( Stop - Start ) foi dividido. O número de traços pode ser retornada também por meio da função `len`

```python
print(len(fluxo))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9058</span>
</pre>



O atributo anterior retorna uma `numpy.ndarray`, que é um formato eficiente para processamento. 

### Medidas de nível como pandas dataframe
No entanto temos adicionalmente o método `.matrix()` que retorna a matriz de dados como um _Pandas Dataframe_ formatada com o tempo da medição de cada traço como índice das linhas e as frequências de cada traço como coluna.

Vamos mostrar as cinco primeiras e cinco últimas linhas e colunas. 

```python
fluxo.matrix().iloc[:5, :5]
```




<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>Frequencies</th>
      <th>105.000000</th>
      <th>105.009768</th>
      <th>105.019537</th>
      <th>105.029305</th>
      <th>105.039073</th>
    </tr>
    <tr>
      <th>Time</th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>2021-06-22 15:18:01.549012</th>
      <td>-93.5</td>
      <td>-99.5</td>
      <td>-90.5</td>
      <td>-90.0</td>
      <td>-92.0</td>
    </tr>
    <tr>
      <th>2021-06-22 15:19:01.408958</th>
      <td>-93.5</td>
      <td>-90.5</td>
      <td>-90.5</td>
      <td>-92.5</td>
      <td>-96.5</td>
    </tr>
    <tr>
      <th>2021-06-22 15:20:01.149028</th>
      <td>-90.5</td>
      <td>-86.5</td>
      <td>-86.5</td>
      <td>-95.0</td>
      <td>-86.5</td>
    </tr>
    <tr>
      <th>2021-06-22 15:21:00.968982</th>
      <td>-90.5</td>
      <td>-90.5</td>
      <td>-91.5</td>
      <td>-89.0</td>
      <td>-89.0</td>
    </tr>
    <tr>
      <th>2021-06-22 15:22:01.729287</th>
      <td>-91.0</td>
      <td>-90.0</td>
      <td>-86.5</td>
      <td>-91.0</td>
      <td>-93.0</td>
    </tr>
  </tbody>
</table>
</div>



```python
fluxo.matrix().iloc[-5:, -5:]
```




<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>Frequencies</th>
      <th>139.960927</th>
      <th>139.970695</th>
      <th>139.980463</th>
      <th>139.990232</th>
      <th>140.000000</th>
    </tr>
    <tr>
      <th>Time</th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>2021-06-28 22:11:01.172916</th>
      <td>-103.0</td>
      <td>-96.5</td>
      <td>-94.0</td>
      <td>-97.5</td>
      <td>-93.5</td>
    </tr>
    <tr>
      <th>2021-06-28 22:12:01.317300</th>
      <td>-92.0</td>
      <td>-95.0</td>
      <td>-93.5</td>
      <td>-93.0</td>
      <td>-92.0</td>
    </tr>
    <tr>
      <th>2021-06-28 22:13:01.742929</th>
      <td>-96.0</td>
      <td>-92.5</td>
      <td>-92.0</td>
      <td>-93.5</td>
      <td>-96.5</td>
    </tr>
    <tr>
      <th>2021-06-28 22:14:01.693040</th>
      <td>-94.5</td>
      <td>-93.0</td>
      <td>-92.5</td>
      <td>-91.5</td>
      <td>-91.0</td>
    </tr>
    <tr>
      <th>2021-06-28 22:15:01.614231</th>
      <td>-90.5</td>
      <td>-91.0</td>
      <td>-90.0</td>
      <td>-94.5</td>
      <td>-94.0</td>
    </tr>
  </tbody>
</table>
</div>



Novamente, caso desejado acessar todos os atributos de um fluxo no formato de dicionário, basta utilizar a função `getattrs`

```python
print(getattrs(fluxo))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span>
    <span style="color: #008000; text-decoration-color: #008000">'antuid'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'bw'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">18457</span>,
    <span style="color: #008000; text-decoration-color: #008000">'description'</span>: <span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 1 de 10).'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'dtype'</span>: <span style="color: #008000; text-decoration-color: #008000">'dBm'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'minimum'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>,
    <span style="color: #008000; text-decoration-color: #008000">'ndata'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>,
    <span style="color: #008000; text-decoration-color: #008000">'processing'</span>: <span style="color: #008000; text-decoration-color: #008000">'peak'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'start_mega'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'stop_mega'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'thread_id'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">300</span>,
    <span style="color: #008000; text-decoration-color: #008000">'thresh'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>,
    <span style="color: #008000; text-decoration-color: #008000">'timestamp'</span>: <span style="font-weight: bold">[</span><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:18:01.549012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:19:01.408958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:20:01.149028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:21:00.968982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:22:01.729287'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:23:01.629084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:24:01.538972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:25:01.408987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:26:01.208987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:27:01.189029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:28:01.179019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:29:01.109253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:30:01.904250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:31:01.491220'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:32:00.999072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:33:01.293070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:34:01.290820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:35:00.948964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:36:01.749016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:37:01.568967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:38:01.529057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:39:01.378976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:40:01.288986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:41:01.298968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:42:01.219012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:43:01.169125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:44:00.989020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:45:00.950353'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:46:01.749102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:47:01.559275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:48:01.398999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:49:01.369000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:50:01.169020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:51:00.969044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:52:01.739067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:53:01.528960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:54:01.569014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:55:01.638992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:56:01.549824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:57:01.349124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:58:01.891450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T15:59:01.893200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:00:01.740287'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:01:01.539155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:02:01.399129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:03:01.179725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:04:00.988959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:05:01.739044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:06:01.549085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:07:01.458976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:08:01.469002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:09:01.529044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:10:01.369033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:11:01.139096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:12:01.791810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:13:00.949074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:14:01.719490'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:15:01.570202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:16:01.378957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:17:01.178992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:18:01.149124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:19:00.969073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:20:01.768997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:21:01.588962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:22:01.588951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:23:01.439035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:24:01.369005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:25:01.159011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:26:00.978979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:27:01.779016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:28:01.549064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:29:01.418989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:30:01.220168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:31:01.199068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:32:00.998969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:33:01.792640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:34:00.968968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:35:00.999037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:36:00.968951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:37:01.718938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:38:01.559019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:39:01.369067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:40:01.158993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:41:00.988949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:42:01.739030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:43:01.549023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:44:01.388976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:45:01.150408'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:46:00.999097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:47:01.768952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:48:01.549120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:49:01.599205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:50:01.379022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:51:01.169021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:52:00.998992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:53:01.729022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:54:01.538954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:55:01.388999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:56:01.178991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:57:01.302320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:58:01.739061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T16:59:01.568967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:00:01.370323'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:01:01.199091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:02:01.249066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:03:01.208964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:04:01.129070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:05:01.190640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:06:01.768939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:07:01.778956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:08:01.549125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:09:01.378988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:10:01.199072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:11:00.989119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:12:01.738974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:13:01.538941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:14:01.379058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:15:01.430158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:16:01.450225'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:17:01.360216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:18:01.209082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:19:01.200990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:20:01.915000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:21:01.769008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:22:01.578982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:23:01.349067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:24:01.209184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:25:01.149002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:26:01.202280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:27:00.989316'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:28:00.999060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:29:00.949083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:30:01.740123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:31:01.679021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:32:01.529066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:33:01.758985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:34:01.749047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:35:01.559119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:36:01.419128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:37:01.158977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:38:00.969059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:39:01.769012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:40:01.558956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:41:01.509109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:42:01.399021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:43:01.209181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:44:01.109205'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:45:01.245'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:46:01.769062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:47:01.548974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:48:01.338959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:49:01.139123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:50:01.490000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:51:00.938949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:52:01.739007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:53:01.568965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:54:01.479099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:55:01.369055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:56:01.209378'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:57:01.129217'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:58:00.988968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T17:59:01.738989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:00:01.590291'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:01:01.379068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:02:01.159072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:03:00.958923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:04:00.989016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:05:01.779229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:06:01.718939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:07:01.608971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:08:01.718948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:09:01.599142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:10:01.379104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:11:01.199085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:12:00.978966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:13:01.728976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:14:01.549007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:15:01.380251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:16:01.159057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:17:01.792060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:18:00.978961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:19:01.729000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:20:01.579089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:21:01.738984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:22:01.599237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:23:01.519466'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:24:01.398982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:25:01.199093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:26:00.978975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:27:01.799029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:28:01.769051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:29:01.749228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:30:01.560189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:31:01.589062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:32:01.398984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:33:01.469040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:34:01.489009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:35:01.489458'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:36:01.349012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:37:01.199028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:38:00.959329'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:39:01.749058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:40:01.538977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:41:01.419034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:42:01.169034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:43:00.949218'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:44:00.948936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:45:01.740178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:46:01.598996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:47:01.608979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:48:01.728968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:49:01.588962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:50:01.509038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:51:01.449045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:52:01.399015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:53:01.169173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:54:00.958970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:55:01.749043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:56:01.618956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:57:01.569020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:58:01.568962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T18:59:01.379284'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:00:01.220184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:01:01.199828'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:02:01.158984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:03:01.189710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:04:01.738961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:05:01.549222'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:06:01.358966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:07:01.159004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:08:01.109203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:09:00.969067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:10:01.739209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:11:01.589023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:12:01.349114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:13:01.189107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:14:01.389610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:15:01.102120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:16:01.739133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:17:01.739776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:18:01.549017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:19:01.418940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:20:01.159025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:21:01.119016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:22:00.998989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:23:01.729217'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:24:01.549066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:25:01.399116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:26:01.379098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:27:01.189018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:28:01.118995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:29:00.949017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:30:01.740388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:31:01.639227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:32:01.529064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:33:01.648969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:34:01.609124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:35:01.529127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:36:01.399046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:37:01.149060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:38:00.998987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:39:00.959123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:40:01.758998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:41:01.739238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:42:01.579013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:43:01.398987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:44:01.209023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:45:01.300272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:46:01.129062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:47:00.998977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:48:01.739326'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:49:01.579011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:50:01.389140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:51:01.159129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:52:01.139199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:53:01.289510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:54:01.297530'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:55:00.959084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:56:01.739716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:57:01.539090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:58:01.388967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T19:59:01.149110'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:00:01.154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:01:01.749179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:02:01.729285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:03:01.559090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:04:01.399007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:05:01.209275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:06:01.149157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:07:01.190610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:08:01.291980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:09:01.119086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:10:00.979062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:11:01.728991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:12:01.739128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:13:01.628965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:14:01.538930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:15:01.390179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:16:01.149101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:17:00.968985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:18:01.749070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:19:01.708941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:20:01.608999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:21:01.598950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:22:01.669027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:23:01.568962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:24:01.369047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:25:01.158978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:26:00.978973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:27:01.749088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:28:01.599054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:29:01.349071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:30:01.170300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:31:01.491470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:32:00.978987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:33:01.209291'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:34:01.691470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:35:01.290580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:36:00.948975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:37:01.739106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:38:01.559083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:39:01.498942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:40:01.349015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:41:01.188988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:42:00.978968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:43:01.818999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:44:01.728995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:45:01.590223'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:46:01.439118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:47:01.338980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:48:01.388994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:49:01.388962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:50:01.159109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:51:00.979100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:52:01.758961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:53:01.568956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:54:01.409039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:55:01.189134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:56:01.169050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:57:01.292820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:58:01.729062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T20:59:01.568986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:00:01.570142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:01:01.468978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:02:01.349073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:03:01.179045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:04:00.958997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:05:01.738941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:06:01.618961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:07:01.528944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:08:01.369068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:09:01.179063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:10:01.149125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:11:00.999098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:12:01.768963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:13:01.619101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:14:01.559093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:15:01.560231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:16:01.459003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:17:01.350238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:18:01.148977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:19:00.948976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:20:01.739098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:21:01.548987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:22:01.389044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:23:01.449037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:24:01.359055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:25:01.119104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:26:00.948965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:27:01.729024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:28:01.559084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:29:01.448990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:30:01.420355'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:31:01.228953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:32:01.129039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:33:01.299096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:34:01.319475'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:35:01.169053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:36:01.129004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:37:00.959057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:38:01.728967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:39:01.539035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:40:01.458978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:41:01.388963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:42:01.259049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:43:01.159016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:44:00.999187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:45:01.750244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:46:01.528939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:47:01.369051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:48:01.169106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:49:00.969051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:50:01.739076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:51:01.569146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:52:01.519019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:53:01.399117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:54:01.359131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:55:01.309085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:56:01.219053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:57:01.159257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:58:00.969110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T21:59:01.729032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:00:01.551536'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:01:01.389172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:02:01.209034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:03:00.989058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:04:01.189870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:05:01.759152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:06:01.759097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:07:01.529114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:08:01.419076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:09:01.459106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:10:01.420156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:11:01.149017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:12:00.979046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:13:01.759158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:14:01.529017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:15:01.390197'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:16:01.169033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:17:01.991380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:18:00.968977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:19:01.719117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:20:01.548998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:21:01.439053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:22:01.419150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:23:01.369025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:24:01.189096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:25:00.959055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:26:01.729012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:27:01.649274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:28:01.549140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:29:01.409049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:30:01.210174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:31:01.801100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:32:00.979119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:33:01.794250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:34:01.792950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:35:01.292510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:36:00.968969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:37:01.779960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:38:01.729178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:39:01.569018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:40:01.369229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:41:01.149040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:42:00.949100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:43:01.758995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:44:01.569019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:45:01.390303'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:46:01.159118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:47:00.959034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:48:01.729015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:49:01.698992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:50:01.569655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:51:01.539126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:52:01.349086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:53:01.149095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:54:00.989000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:55:01.749004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:56:01.569239'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:57:01.459031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:58:01.369143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T22:59:01.139156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:00:00.960172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:01:01.779033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:02:01.709195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:03:01.709178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:04:01.548937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:05:01.508979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:06:01.369203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:07:01.139252'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:08:00.979096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:09:01.749045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:10:01.559102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:11:01.469139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:12:01.419013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:13:01.159788'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:14:00.949185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:15:01.790269'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:16:01.739014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:17:01.889563'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:18:01.779093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:19:01.539022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:20:01.298972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:21:01.159154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:22:01.119188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:23:00.969003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:24:01.739020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:25:01.589012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:26:01.419041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:27:01.159055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:28:01.397400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:29:01.109103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:30:01.130202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:31:01.891450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:32:01.191000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:33:01.393840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:34:00.959056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:35:01.739017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:36:01.549041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:37:01.369052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:38:01.229281'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:39:01.188998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:40:00.979061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:41:01.739044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:42:01.588983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:43:01.738948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:44:01.699125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:45:01.570499'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:46:01.359214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:47:01.219029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:48:01.139070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:49:01.490950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:50:00.948986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:51:01.749085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:52:01.539012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:53:01.339014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:54:01.159214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:55:01.159134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:56:01.911200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:57:00.949006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:58:01.730245'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-22T23:59:01.539062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:00:01.370193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:01:01.129299'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:02:01.119149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:03:00.959184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:04:01.729067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:05:01.549037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:06:01.368998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:07:01.159025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:08:00.959076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:09:01.194850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:10:01.493140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:11:01.291620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:12:00.959067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:13:01.739245'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:14:01.558988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:15:01.390226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:16:01.179115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:17:00.978995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:18:01.729076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:19:01.569007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:20:01.409124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:21:01.169099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:22:01.592190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:23:01.102740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:24:00.969036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:25:01.749304'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:26:01.509235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:27:01.469103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:28:01.309165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:29:01.289037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:30:01.170182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:31:01.492000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:32:00.999056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:33:01.249160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:34:01.129141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:35:00.959153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:36:01.149059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:37:01.129073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:38:00.999012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:39:01.819040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:40:01.749101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:41:01.729265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:42:01.569012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:43:01.549005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:44:01.359181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:45:01.180271'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:46:01.492630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:47:00.959047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:48:01.739003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:49:01.729120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:50:01.759015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:51:01.709058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:52:01.549008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:53:01.389323'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:54:01.169070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:55:01.916200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:56:00.949011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:57:01.779013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:58:01.599020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T00:59:01.579013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:00:01.550292'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:01:01.429085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:02:01.419122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:03:01.319140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:04:01.379087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:05:01.309019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:06:01.310208'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:07:01.189107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:08:01.491830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:09:00.999189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:10:01.738979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:11:01.719175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:12:01.568990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:13:01.449113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:14:01.369224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:15:01.220207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:16:01.209140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:17:01.109160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:18:00.949020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:19:01.738984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:20:01.619053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:21:01.348989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:22:01.149029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:23:00.999188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:24:01.789151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:25:01.699060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:26:01.629097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:27:01.559127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:28:01.428989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:29:01.409156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:30:01.380337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:31:01.439014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:32:01.419051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:33:01.419102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:34:01.349124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:35:01.189070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:36:01.109219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:37:00.959104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:38:01.779091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:39:01.579032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:40:01.439047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:41:01.409000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:42:01.489064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:43:01.479508'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:44:01.489169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:45:01.360302'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:46:01.159175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:47:01.900400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:48:01.739151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:49:01.579076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:50:01.408999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:51:01.159201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:52:00.978995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:53:01.729016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:54:01.589132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:55:01.389212'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:56:01.299050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:57:01.199126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:58:01.139092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T01:59:00.979007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:00:01.770242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:01:01.739004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:02:01.539107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:03:01.359112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:04:01.179125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:05:00.969007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:06:01.739013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:07:01.579225'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:08:01.369032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:09:01.349154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:10:01.289020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:11:01.339011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:12:01.199045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:13:00.958983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:14:01.729102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:15:01.530202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:16:01.399128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:17:01.190320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:18:01.149073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:19:00.989043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:20:00.989030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:21:01.758995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:22:01.759040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:23:01.769169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:24:01.569169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:25:01.409085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:26:01.199044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:27:01.291910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:28:00.979029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:29:01.749009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:30:01.550228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:31:01.459314'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:32:01.399138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:33:01.479200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:34:01.349010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:35:01.449143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:36:01.399133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:37:01.179150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:38:00.999001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:39:01.729005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:40:01.569168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:41:01.379092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:42:01.149109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:43:00.948987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:44:01.749014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:45:01.590227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:46:01.379012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:47:01.129145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:48:01.109138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:49:01.692610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:50:00.979015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:51:00.949006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:52:01.749006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:53:01.549067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:54:01.339365'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:55:01.159042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:56:00.969062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:57:01.739042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:58:01.689137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T02:59:01.579030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:00:01.370300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:01:01.179089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:02:01.291260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:03:00.959010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:04:01.749039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:05:01.589227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:06:01.349001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:07:01.149033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:08:01.992390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:09:00.949119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:10:01.739015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:11:01.629116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:12:01.539037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:13:01.349233'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:14:01.159188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:15:01.150358'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:16:01.900100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:17:00.949168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:18:00.949026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:19:01.758993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:20:01.579144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:21:01.388997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:22:01.149176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:23:00.999000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:24:01.758994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:25:01.549102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:26:01.389010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:27:01.189013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:28:00.988995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:29:00.989051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:30:01.760238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:31:01.829125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:32:01.739083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:33:01.828981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:34:01.709161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:35:01.698990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:36:01.549185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:37:01.379020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:38:01.239154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:39:01.149032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:40:00.979117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:41:01.749072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:42:01.589017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:43:01.389069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:44:01.358999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:45:01.190366'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:46:00.999492'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:47:01.749145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:48:01.589014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:49:01.409019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:50:01.209151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:51:00.999160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:52:01.729080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:53:01.539059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:54:01.329103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:55:01.169114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:56:01.119106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:57:01.993110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:58:00.989169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T03:59:01.759044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:00:01.570224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:01:01.389018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:02:01.389002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:03:01.329192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:04:01.159091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:05:01.791060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:06:00.969078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:07:01.759007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:08:01.529095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:09:01.479019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:10:01.359052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:11:01.309070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:12:01.149321'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:13:01.192770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:14:00.978985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:15:01.780191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:16:01.699079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:17:01.559057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:18:01.519206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:19:01.479264'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:20:01.389285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:21:01.168998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:22:01.192900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:23:00.948951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:24:01.818979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:25:01.729009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:26:01.549098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:27:01.398999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:28:01.189118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:29:01.892850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:30:00.950194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:31:01.829053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:32:01.729116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:33:01.819176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:34:01.679005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:35:01.599036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:36:01.639034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:37:01.499164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:38:01.399121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:39:01.199011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:40:01.189117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:41:00.990108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:42:00.959210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:43:01.291900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:44:01.769009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:45:01.630316'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:46:01.409034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:47:01.169122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:48:00.968992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:49:01.799100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:50:01.749034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:51:01.599943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:52:01.349030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:53:01.199116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:54:00.948987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:55:01.729082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:56:01.630876'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:57:01.579030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:58:01.369250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T04:59:01.139103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:00:00.950311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:01:01.729001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:02:01.629103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:03:01.758981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:04:01.729080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:05:01.608998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:06:01.649085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:07:01.599026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:08:01.369157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:09:01.318996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:10:01.159133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:11:01.902700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:12:00.949022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:13:01.799141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:14:01.649013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:15:01.540233'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:16:01.589030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:17:01.549486'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:18:01.359099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:19:01.189119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:20:01.899000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:21:01.739078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:22:01.539093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:23:01.389148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:24:01.149114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:25:00.969128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:26:01.749005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:27:01.609042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:28:01.589112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:29:01.629034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:30:01.740356'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:31:01.659163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:32:01.529003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:33:01.619199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:34:01.518997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:35:01.379030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:36:01.199100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:37:00.999010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:38:01.769029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:39:01.678998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:40:01.658991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:41:01.579009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:42:01.409027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:43:01.279922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:44:01.139144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:45:00.980191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:46:01.759125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:47:00.969017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:48:01.748978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:49:01.569013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:50:01.359256'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:51:01.179096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:52:00.989251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:53:01.739008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:54:01.719119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:55:01.609104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:56:01.579267'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:57:01.519044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:58:01.418983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T05:59:01.149253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:00:00.960290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:01:01.719187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:02:01.539024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:03:01.429003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:04:01.359040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:05:01.189023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:06:00.949164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:07:01.759128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:08:01.568999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:09:01.568991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:10:01.459913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:11:01.599007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:12:01.389160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:13:01.169021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:14:01.191440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:15:01.750335'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:16:01.559007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:17:01.420214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:18:01.349168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:19:01.149256'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:20:00.968980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:21:01.758989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:22:01.769160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:23:01.708989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:24:01.599060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:25:01.560121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:26:01.379093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:27:01.149288'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:28:00.999094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:29:01.739003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:30:01.700273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:31:01.639083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:32:01.519021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:33:01.649248'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:34:01.628986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:35:01.618978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:36:01.669132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:37:01.569109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:38:01.379048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:39:01.189089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:40:00.969155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:41:01.749000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:42:01.569243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:43:01.359043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:44:01.199024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:45:01.102970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:46:01.769165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:47:01.559083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:48:01.399045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:49:01.418943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:50:01.299025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:51:01.219128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:52:00.949032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:53:01.739068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:54:01.629135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:55:01.549011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:56:01.389045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:57:01.209060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:58:01.179054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T06:59:00.969122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:00:01.770218'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:01:01.579004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:02:01.529104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:03:01.439304'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:04:01.319014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:05:01.179129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:06:00.979046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:07:01.739038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:08:01.569037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:09:01.389067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:10:01.159208'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:11:01.119130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:12:00.969049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:13:01.749002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:14:01.539148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:15:01.450299'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:16:01.459003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:17:01.379980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:18:01.179027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:19:00.949080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:20:01.739001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:21:01.589531'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:22:01.528964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:23:01.409172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:24:01.309096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:25:01.159053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:26:00.989000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:27:01.749082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:28:01.609049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:29:01.619149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:30:01.610191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:31:01.669085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:32:01.569076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:33:01.609247'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:34:01.389006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:35:01.489006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:36:01.409290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:37:01.189013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:38:00.969001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:39:00.978991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:40:01.779119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:41:01.588994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:42:01.639039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:43:01.569001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:44:01.339125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:45:01.100360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:46:00.959015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:47:01.739119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:48:01.569040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:49:01.409098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:50:01.139165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:51:01.392890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:52:00.949094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:53:01.749102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:54:01.609169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:55:01.429135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:56:01.599010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:57:01.429135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:58:01.349019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T07:59:01.199148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:00:01.415580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:01:00.959109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:02:01.799008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:03:01.719046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:04:01.539045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:05:01.379024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:06:01.339140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:07:01.159060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:08:00.989040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:09:00.948987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:10:00.958999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:11:01.759126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:12:01.568981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:13:01.419069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:14:01.159027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:15:00.990158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:16:01.769026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:17:01.599108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:18:01.529190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:19:01.439045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:20:01.309027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:21:01.149033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:22:01.498710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:23:00.949006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:24:01.719199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:25:01.519241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:26:01.528988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:27:01.349576'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:28:01.149144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:29:00.949032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:30:01.750284'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:31:01.609337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:32:01.368990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:33:01.499163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:34:01.399122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:35:01.279056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:36:01.349500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:37:01.178996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:38:01.119260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:39:01.690660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:40:00.979108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:41:01.729035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:42:01.579096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:43:01.529124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:44:01.379044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:45:01.200328'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:46:01.130542'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:47:01.392160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:48:01.149145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:49:01.795890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:50:01.129201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:51:00.949045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:52:01.739205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:53:01.569108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:54:01.379024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:55:01.149147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:56:01.914200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:57:01.739047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:58:01.589015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T08:59:01.459016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:00:01.430187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:01:01.389159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:02:01.189071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:03:01.390550'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:04:01.739054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:05:01.519113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:06:01.389029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:07:01.189117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:08:00.949034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:09:01.789192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:10:01.689026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:11:01.569115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:12:01.379018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:13:01.269261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:14:01.199163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:15:01.101540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:16:00.969124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:17:02.291790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:18:00.939073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:19:01.749012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:20:01.539049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:21:01.338984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:22:01.159278'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:23:01.109203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:24:00.959023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:25:01.739080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:26:01.569036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:27:01.429108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:28:01.359310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:29:01.289055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:30:01.210277'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:31:01.239139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:32:01.119196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:33:01.239201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:34:01.119168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:35:00.979395'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:36:01.779141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:37:01.749150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:38:01.599032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:39:01.459158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:40:01.359014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:41:01.409019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:42:01.309040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:43:01.129127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:44:00.979145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:45:01.750524'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:46:01.559181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:47:01.399007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:48:01.159065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:49:01.902800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:50:01.749126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:51:01.729021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:52:01.599035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:53:01.549006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:54:01.539096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:55:01.528987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:56:01.369101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:57:01.199020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:58:00.959045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T09:59:01.758998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:00:01.530171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:01:01.399011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:02:01.319005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:03:01.149099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:04:00.999009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:05:01.748975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:06:01.559013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:07:01.459154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:08:01.529242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:09:01.348997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:10:01.159235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:11:00.959149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:12:01.748987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:13:01.559046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:14:01.528995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:15:01.360372'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:16:01.189141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:17:00.969452'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:18:01.769020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:19:01.688996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:20:01.569006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:21:01.479018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:22:01.329358'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:23:01.139103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:24:00.949038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:25:01.739216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:26:01.579001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:27:01.399105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:28:01.159044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:29:01.903800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:30:01.740248'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:31:01.649042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:32:01.529301'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:33:01.649141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:34:01.599178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:35:01.579214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:36:01.389048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:37:01.129279'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:38:00.969028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:39:01.749112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:40:01.569019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:41:01.549031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:42:01.339037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:43:01.239031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:44:01.109129'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:45:01.257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:46:01.759003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:47:01.579015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:48:01.519136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:49:01.529108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:50:01.359232'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:51:01.179015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:52:00.989145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:53:01.739012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:54:01.529137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:55:01.389038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:56:01.129272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:57:00.939001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:58:01.759083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T10:59:01.549077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:00:01.380266'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:01:01.398991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:02:01.429296'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:03:01.339072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:04:01.149184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:05:01.159011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:06:01.926400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:07:00.999043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:08:01.739014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:09:01.559046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:10:01.359137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:11:01.149149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:12:00.978997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:13:01.728995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:14:01.659006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:15:01.710169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:16:01.529056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:17:01.390116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:18:01.139118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:19:01.219009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:20:01.159058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:21:00.989015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:22:00.989010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:23:01.749237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:24:01.589081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:25:01.398998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:26:01.159123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:27:01.191810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:28:01.789127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:29:01.779292'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:30:01.750769'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:31:01.629046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:32:01.558973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:33:01.609173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:34:01.479150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:35:01.379081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:36:01.160400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:37:01.990490'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:38:00.969065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:39:00.949097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:40:01.739030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:41:01.739116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:42:01.749027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:43:01.549005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:44:01.349008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:45:01.180410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:46:01.169021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:47:00.979120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:48:01.749151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:49:01.719110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:50:01.549053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:51:01.479016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:52:01.379015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:53:01.189277'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:54:01.792080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:55:00.999880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:56:01.799376'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:57:01.679014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:58:01.579025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T11:59:01.629025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:00:01.500195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:01:01.369221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:02:01.159013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:03:01.119244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:04:00.949140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:05:00.949042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:06:01.718996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:07:01.589104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:08:01.649063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:09:01.748994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:10:01.549085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:11:01.339139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:12:01.179294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:13:01.992370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:14:00.969017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:15:00.950229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:16:01.789268'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:17:01.729127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:18:01.529017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:19:01.368999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:20:01.179024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:21:01.491900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:22:00.999093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:23:01.729166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:24:01.549095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:25:01.439072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:26:01.319339'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:27:01.219141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:28:01.109115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:29:00.979066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:30:01.750181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:31:01.759002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:32:01.519133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:33:01.799152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:34:01.719033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:35:01.719059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:36:01.619122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:37:01.509832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:38:01.359118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:39:01.189149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:40:01.109773'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:41:00.989035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:42:01.749069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:43:01.559230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:44:01.409192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:45:01.160304'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:46:01.931900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:47:01.759026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:48:01.769158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:49:01.669921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:50:01.549079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:51:01.399190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:52:01.159064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:53:00.969269'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:54:01.729122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:55:01.549029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:56:01.319050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:57:01.159065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:58:01.490970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T12:59:00.959012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:00:01.751131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:01:01.729123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:02:01.649117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:03:01.549034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:04:01.359150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:05:01.149146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:06:00.989061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:07:01.749036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:08:01.559115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:09:01.499073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:10:01.489142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:11:01.359116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:12:01.159363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:13:01.199053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:14:01.109302'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:15:01.803310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:16:00.989116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:17:01.989870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:18:01.769008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:19:01.549025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:20:01.399014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:21:01.159280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:22:00.939033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:23:01.749041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:24:01.618973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:25:01.479118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:26:01.369065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:27:01.339226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:28:01.249114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:29:01.209044'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:30:01.241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:31:01.819021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:32:01.719056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:33:01.819179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:34:01.709388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:35:01.529218'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:36:01.399041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:37:01.309103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:38:01.139283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:39:00.959066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:40:01.769167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:41:01.699085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:42:01.649120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:43:01.529017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:44:01.369127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:45:01.160295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:46:00.989117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:47:01.759101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:48:01.599054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:49:01.359023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:50:01.179207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:51:01.179123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:52:00.979086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:53:01.739109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:54:01.559133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:55:01.499011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:56:01.389088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:57:01.179091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:58:01.293330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T13:59:01.729109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:00:01.550229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:01:01.389083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:02:01.179016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:03:01.491050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:04:01.592740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:05:00.949098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:06:01.789138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:07:01.619037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:08:01.619102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:09:01.639011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:10:01.469113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:11:01.339161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:12:01.219104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:13:00.999036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:14:01.692550'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:15:00.950307'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:16:01.738993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:17:01.559255'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:18:01.579060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:19:01.399141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:20:01.199023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:21:00.969013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:22:00.989065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:23:00.969043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:24:01.809029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:25:01.779055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:26:01.579245'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:27:01.499079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:28:01.389152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:29:01.189050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:30:00.980293'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:31:01.292680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:32:01.739262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:33:01.879216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:34:01.749265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:35:01.699027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:36:01.669008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:37:01.569102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:38:01.489866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:39:01.409022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:40:01.169030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:41:01.392650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:42:00.979081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:43:01.749148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:44:01.579077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:45:01.360313'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:46:01.169210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:47:01.119154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:48:00.999038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:49:01.301000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:50:01.910400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:51:01.739063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:52:01.739092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:53:01.599041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:54:01.339062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:55:01.179155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:56:01.169059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:57:00.999038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:58:01.739060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T14:59:01.579033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:00:01.380274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:01:01.189045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:02:01.389199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:03:01.299086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:04:01.159074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:05:01.189036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:06:00.989123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:07:01.749029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:08:01.709023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:09:01.549272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:10:01.359010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:11:01.159167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:12:00.949013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:13:01.769026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:14:01.569088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:15:01.610620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:16:01.549097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:17:01.449005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:18:01.349018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:19:01.329126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:20:01.159125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:21:00.989044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:22:01.719030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:23:01.579029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:24:01.409160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:25:01.229138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:26:01.149044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:27:01.403610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:28:00.979062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:29:01.149077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:30:00.970272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:31:01.879042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:32:01.769007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:33:01.789123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:34:01.539117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:35:01.519075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:36:01.369063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:37:01.239148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:38:01.149116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:39:00.999151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:40:01.779002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:41:01.748998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:42:00.949036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:43:01.729160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:44:01.569021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:45:01.390270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:46:01.309063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:47:01.189102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:48:01.149038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:49:00.949059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:50:01.759106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:51:01.539006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:52:01.379207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:53:01.179110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:54:01.392540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:55:00.999275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:56:00.949588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:57:01.749300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:58:01.539174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T15:59:01.349024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:00:01.150523'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:01:00.959044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:02:01.719175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:03:01.558990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:04:01.369028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:05:01.159045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:06:01.203260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:07:00.969010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:08:01.749067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:09:01.292490'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:10:00.999143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:11:01.739074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:12:01.548990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:13:01.419170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:14:01.159034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:15:01.504800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:16:00.949066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:17:01.769000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:18:01.569065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:19:01.409141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:20:01.198995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:21:01.591710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:22:01.691910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:23:00.969017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:24:01.769756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:25:01.539053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:26:01.368998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:27:01.169074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:28:00.989133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:29:01.749036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:30:01.740363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:31:01.599050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:32:01.549017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:33:01.859122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:34:01.729161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:35:01.189128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:36:01.199050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:37:00.999071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:38:01.758999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:39:01.559071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:40:01.379123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:41:01.219161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:42:01.109759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:43:00.949027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:44:01.739119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:45:01.570601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:46:01.429035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:47:01.409241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:48:01.199254'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:49:01.129294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:50:01.290310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:51:00.949048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:52:01.739148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:53:01.669035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:54:01.499214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:55:01.419014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:56:01.139219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:57:00.969188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:58:01.729156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T16:59:01.569134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:00:01.500206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:01:01.439043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:02:01.369084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:03:01.369525'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:04:01.179074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:05:00.989169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:06:01.739036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:07:01.719002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:08:01.539326'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:09:01.429208'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:10:01.459033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:11:01.339029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:12:01.179127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:13:00.969047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:14:01.789030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:15:01.800314'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:16:01.749049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:17:01.529041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:18:01.349060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:19:01.179067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:20:01.792450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:21:00.949029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:22:01.739020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:23:01.659176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:24:01.589111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:25:01.359552'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:26:01.149278'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:27:01.149091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:28:01.191320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:29:00.939047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:30:01.730210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:31:01.619060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:32:01.549193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:33:01.619248'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:34:01.489077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:35:01.359027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:36:01.159142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:37:01.901800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:38:00.959010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:39:01.749148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:40:01.539047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:41:01.569013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:42:01.499150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:43:01.369096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:44:01.199166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:45:01.160361'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:46:01.911700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:47:00.949131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:48:01.739044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:49:01.739146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:50:01.579103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:51:01.399110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:52:01.339055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:53:01.169145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:54:01.392630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:55:01.493050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:56:01.925200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:57:01.769148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:58:01.739126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T17:59:01.529193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:00:01.320242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:01:01.179198'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:02:00.979138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:03:01.789054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:04:01.569155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:05:01.409128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:06:01.169282'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:07:01.491290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:08:01.395220'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:09:00.949039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:10:01.779778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:11:01.569105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:12:01.429100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:13:01.319181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:14:01.219049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:15:01.160241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:16:00.969088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:17:02.910100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:18:01.291030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:19:00.969175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:20:01.759052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:21:01.739300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:22:01.699071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:23:01.539350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:24:01.339127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:25:01.189180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:26:00.969038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:27:01.769048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:28:01.669328'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:29:01.559100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:30:01.420238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:31:01.259211'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:32:01.129433'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:33:01.269179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:34:01.149099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:35:01.605040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:36:00.939122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:37:01.739129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:38:01.699273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:39:01.509175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:40:01.329032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:41:01.179130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:42:01.129055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:43:00.969098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:44:01.739541'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:45:01.650386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:46:01.559120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:47:01.399025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:48:01.379216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:49:01.209050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:50:00.989142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:51:01.799071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:52:01.729077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:53:01.609052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:54:01.569055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:55:01.399055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:56:01.169086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:57:00.949147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:58:01.749131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T18:59:01.599022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:00:01.340444'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:01:01.219193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:02:01.199189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:03:00.989036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:04:01.739233'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:05:01.699033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:06:01.529199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:07:01.368993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:08:01.129032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:09:00.969043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:10:00.949020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:11:01.749235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:12:01.669124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:13:01.509026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:14:01.419033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:15:01.450209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:16:01.349078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:17:01.159079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:18:01.139246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:19:01.169053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:20:00.979044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:21:01.729151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:22:01.679084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:23:01.559117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:24:01.419080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:25:01.319221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:26:01.179029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:27:01.393290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:28:01.493590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:29:00.959243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:30:01.751576'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:31:01.659034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:32:01.548996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:33:01.619230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:34:01.499130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:35:01.429039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:36:01.369226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:37:01.169069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:38:00.979137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:39:01.749114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:40:01.579121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:41:01.409103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:42:01.429141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:43:01.449033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:44:01.429107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:45:01.330437'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:46:01.349751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:47:01.539622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:48:01.619047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:49:01.569249'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:50:01.429170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:51:01.339125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:52:01.229196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:53:01.149123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:54:01.219072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:55:01.329100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:56:01.169029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:57:01.169058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:58:00.959101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T19:59:01.739022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:00:01.104480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:01:01.779031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:02:01.589196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:03:01.359043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:04:01.139108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:05:00.949051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:06:01.739063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:07:01.549020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:08:01.379190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:09:01.239113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:10:01.119182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:11:00.939034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:12:01.769112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:13:01.729133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:14:01.608972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:15:01.530258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:16:01.529347'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:17:01.380192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:18:01.189135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:19:01.292720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:20:01.739045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:21:01.749046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:22:01.759049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:23:01.789077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:24:01.619051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:25:01.569067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:26:01.409114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:27:01.159173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:28:01.928200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:29:01.799105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:30:01.760305'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:31:01.669028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:32:01.529006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:33:01.709237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:34:01.579117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:35:01.569102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:36:01.389781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:37:01.149094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:38:01.190720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:39:01.739083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:40:01.739067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:41:01.549165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:42:01.359008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:43:01.149129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:44:00.999153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:45:01.780282'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:46:01.639199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:47:01.539029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:48:01.609119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:49:01.539853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:50:01.389021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:51:01.179160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:52:00.979027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:53:00.959189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:54:01.759106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:55:01.569246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:56:01.349025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:57:01.179118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:58:00.999032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T20:59:01.719039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:00:01.750357'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:01:01.609000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:02:01.539047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:03:01.429886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:04:01.349094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:05:01.199041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:06:00.989175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:07:01.769178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:08:01.528996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:09:01.409045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:10:01.179146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:11:00.959240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:12:01.779185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:13:01.569024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:14:01.439155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:15:01.430201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:16:01.339056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:17:01.159141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:18:01.993030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:19:00.949147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:20:01.819138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:21:01.729039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:22:01.589116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:23:01.339095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:24:01.139086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:25:00.999137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:26:01.739116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:27:01.728984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:28:00.949159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:29:00.959092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:30:01.750361'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:31:01.819050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:32:01.699029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:33:01.799133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:34:01.739059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:35:01.569108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:36:01.529080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:37:01.439140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:38:01.409125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:39:01.199034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:40:01.169111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:41:01.169226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:42:01.892500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:43:01.190180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:44:01.779005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:45:01.580315'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:46:01.369391'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:47:01.159220'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:48:00.959162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:49:01.749021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:50:01.529387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:51:01.379110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:52:01.209035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:53:01.393300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:54:01.109136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:55:01.794800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:56:00.939032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:57:01.799209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:58:01.549035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T21:59:01.439131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:00:01.390465'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:01:01.299140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:02:01.169117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:03:01.179164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:04:01.249299'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:05:01.209117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:06:01.500280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:07:01.493430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:08:01.139045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:09:00.999029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:10:01.692370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:11:00.949182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:12:01.729091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:13:01.209125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:14:01.469210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:15:01.430240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:16:01.400410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:17:01.309663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:18:01.209059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:19:01.159283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:20:01.139083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:21:01.209129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:22:01.139221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:23:00.959060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:24:00.969009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:25:01.709174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:26:01.609228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:27:01.489424'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:28:01.339190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:29:01.169113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:30:00.970214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:31:01.393110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:32:01.769064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:33:02.917200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:34:00.979049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:35:00.959037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:36:01.749226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:37:01.579030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:38:01.379109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:39:01.169113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:40:00.949065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:41:01.739189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:42:01.569035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:43:01.379024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:44:01.189078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:45:01.150314'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:46:01.149137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:47:00.989034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:48:01.149242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:49:00.969043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:50:01.759047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:51:01.569011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:52:01.429102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:53:01.369104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:54:01.159144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:55:00.959227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:56:01.749262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:57:01.589001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:58:01.369193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T22:59:01.129190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:00:01.190327'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:01:01.149367'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:02:00.989016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:03:01.749072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:04:01.589024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:05:01.389029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:06:01.169481'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:07:00.949031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:08:01.769068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:09:01.739132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:10:01.579092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:11:01.509068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:12:01.509026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:13:01.399143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:14:01.209276'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:15:01.160242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:16:00.989118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:17:01.740237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:18:01.569069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:19:01.379184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:20:01.169079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:21:00.979079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:22:01.779037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:23:01.559027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:24:01.419215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:25:01.169138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:26:01.492450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:27:01.193380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:28:00.969188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:29:01.739080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:30:01.540411'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:31:01.499032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:32:01.509107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:33:01.609158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:34:01.559032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:35:01.369028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:36:01.149269'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:37:01.392020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:38:00.949027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:39:01.769003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:40:00.948995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:41:01.779014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:42:01.659083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:43:01.549124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:44:01.389139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:45:01.140274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:46:00.989257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:47:01.729107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:48:01.609047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:49:01.569071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:50:01.379111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:51:01.159057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:52:01.292340'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:53:00.949098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:54:01.809035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:55:01.749033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:56:01.549117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:57:01.379012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:58:01.159017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-23T23:59:00.999169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:00:01.770294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:01:01.689189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:02:01.569036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:03:01.399094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:04:01.199132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:05:00.979087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:06:01.729041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:07:00.949118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:08:01.679147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:09:01.619138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:10:01.529146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:11:01.379064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:12:01.159191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:13:01.169124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:14:00.999096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:15:01.740257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:16:01.679216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:17:01.600263'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:18:01.379061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:19:01.409128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:20:01.409214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:21:01.189251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:22:00.949070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:23:01.779092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:24:01.699179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:25:01.519051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:26:01.409097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:27:01.329533'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:28:01.139241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:29:01.916200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:30:01.740329'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:31:01.629060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:32:01.589061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:33:01.799358'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:34:01.719154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:35:01.569170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:36:01.379055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:37:01.329055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:38:01.139239'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:39:00.989103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:40:01.739094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:41:01.539046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:42:01.329196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:43:01.298997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:44:01.159376'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:45:00.980482'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:46:01.849088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:47:01.789265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:48:01.549041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:49:01.359218'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:50:01.309073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:51:01.159387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:52:00.989173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:53:01.769047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:54:01.559143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:55:01.369204'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:56:01.159136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:57:01.915100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:58:01.738958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T00:59:00.949233'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:00:00.950503'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:01:01.759063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:02:01.579162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:03:01.389095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:04:01.179131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:05:00.949050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:06:01.739207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:07:01.559053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:08:01.389070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:09:01.159152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:10:01.592200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:11:00.999039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:12:01.759087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:13:01.769197'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:14:01.789039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:15:01.680450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:16:01.569089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:17:01.359271'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:18:01.139171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:19:00.969202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:20:01.739085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:21:01.679131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:22:01.569203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:23:01.379224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:24:01.299131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:25:01.139345'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:26:01.119174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:27:01.290840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:28:01.719053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:29:01.529059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:30:01.360434'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:31:01.229072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:32:01.159257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:33:01.689342'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:34:01.749127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:35:01.739201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:36:01.589102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:37:01.589063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:38:01.379089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:39:01.209193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:40:01.119133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:41:00.999151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:42:01.749543'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:43:01.589059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:44:01.709117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:45:01.560396'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:46:01.509100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:47:01.369118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:48:01.189241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:49:00.949055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:50:01.739046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:51:01.709057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:52:01.599127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:53:01.539171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:54:01.419187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:55:01.299050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:56:01.179216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:57:00.979106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:58:01.739150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T01:59:01.589059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:00:01.530319'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:01:01.419258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:02:01.159127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:03:00.949204'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:04:01.769060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:05:01.539317'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:06:01.379235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:07:01.339344'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:08:01.399238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:09:01.149106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:10:00.949042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:11:01.739081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:12:01.589124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:13:01.369166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:14:01.219082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:15:01.210262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:16:00.949098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:17:01.930049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:18:01.779046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:19:00.969049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:20:01.929500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:21:01.492820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:22:01.791640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:23:00.969055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:24:01.729366'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:25:01.549138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:26:01.339201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:27:01.169163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:28:00.979089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:29:01.729154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:30:01.590294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:31:01.679069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:32:01.559067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:33:01.849160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:34:01.759169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:35:01.549060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:36:01.329286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:37:01.189478'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:38:00.959086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:39:01.729180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:40:01.599214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:41:01.339169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:42:01.159217'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:43:00.949129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:44:01.739101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:45:01.540283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:46:01.439113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:47:01.419054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:48:01.419246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:49:01.279363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:50:01.149113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:51:00.969102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:52:00.969112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:53:01.739063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:54:01.519091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:55:01.479124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:56:01.319186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:57:01.169145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:58:00.999160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T02:59:01.729149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:00:01.590496'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:01:01.619197'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:02:01.519362'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:03:01.359193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:04:01.279049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:05:01.189076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:06:01.159166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:07:00.979045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:08:01.739124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:09:01.709305'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:10:01.549330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:11:01.379180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:12:01.199129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:13:01.159108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:14:01.791970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:15:01.703250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:16:00.969153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:17:01.739047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:18:01.539207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:19:01.529202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:20:01.349224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:21:01.199183'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:22:01.693670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:23:01.294060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:24:01.739070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:25:01.599079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:26:01.479185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:27:01.479188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:28:01.419122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:29:01.159139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:30:01.105720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:31:01.292570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:32:00.959057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:33:02.937400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:34:00.969213'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:35:01.759056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:36:01.719259'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:37:01.559095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:38:01.369364'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:39:01.359171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:40:01.349191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:41:01.309160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:42:01.279221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:43:01.139195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:44:01.191750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:45:01.770410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:46:01.699358'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:47:01.579314'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:48:01.499159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:49:01.409117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:50:01.169223'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:51:00.969215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:52:01.749405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:53:01.679138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:54:01.619191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:55:01.339100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:56:01.199349'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:57:01.290930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:58:01.719121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T03:59:01.609185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:00:01.520450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:01:01.399101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:02:01.149210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:03:01.139219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:04:00.959337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:05:01.729078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:06:01.639184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:07:01.549216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:08:01.399140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:09:01.169156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:10:01.109438'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:11:00.989128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:12:01.789064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:13:01.579238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:14:01.379115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:15:01.170532'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:16:01.291370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:17:01.740390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:18:01.759103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:19:01.519114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:20:01.519135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:21:01.399138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:22:01.179175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:23:01.159219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:24:00.949197'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:25:01.739177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:26:01.569778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:27:01.359112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:28:01.149202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:29:00.959108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:30:01.780475'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:31:01.649209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:32:01.589168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:33:01.789213'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:34:01.739420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:35:01.559383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:36:01.339219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:37:01.149227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:38:00.989153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:39:01.749168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:40:01.589144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:41:01.549182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:42:01.349081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:43:01.239113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:44:01.149134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:45:01.203680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:46:00.949947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:47:00.989204'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:48:01.770126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:49:01.559106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:50:01.399102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:51:01.169148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:52:01.394570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:53:00.949070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:54:01.739116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:55:01.569230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:56:01.589021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:57:01.509160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:58:01.449123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T04:59:01.399206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:00:01.310339'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:01:01.179311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:02:00.979089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:03:01.779087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:04:01.719109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:05:01.559126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:06:01.419132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:07:01.349159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:08:01.179337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:09:01.908900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:10:01.779610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:11:01.549186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:12:01.439184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:13:01.529172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:14:01.449085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:15:01.340333'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:16:01.179126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:17:00.989140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:18:01.739149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:19:01.589167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:20:01.379208'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:21:01.189097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:22:00.989078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:23:00.939145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:24:01.749324'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:25:01.739358'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:26:01.639191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:27:01.729118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:28:01.599089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:29:01.529140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:30:01.370321'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:31:01.439345'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:32:01.339150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:33:01.479376'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:34:01.539147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:35:01.419207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:36:01.189110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:37:00.959187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:38:01.789113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:39:01.749214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:40:01.799118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:41:01.739329'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:42:01.549274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:43:01.359155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:44:01.199164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:45:00.960350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:46:01.739170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:47:01.539078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:48:01.379147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:49:01.149150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:50:00.949163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:51:01.709348'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:52:01.549169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:53:01.539087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:54:01.419355'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:55:01.179144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:56:00.999111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:57:01.789242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:58:01.769128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T05:59:01.569159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:00:01.450348'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:01:01.389229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:02:01.219103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:03:01.119227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:04:00.949111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:05:01.779129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:06:01.599181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:07:01.569250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:08:01.419129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:09:01.189140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:10:00.959115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:11:00.959085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:12:01.729139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:13:01.599142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:14:01.359136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:15:01.180401'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:16:00.969113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:17:01.880031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:18:01.769264'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:19:01.719101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:20:01.739219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:21:01.719077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:22:01.589120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:23:01.379237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:24:01.159319'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:25:01.193850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:26:01.749130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:27:01.609223'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:28:01.379102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:29:01.169130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:30:00.980337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:31:01.849091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:32:01.991460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:33:02.289296'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:34:01.169281'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:35:01.159367'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:36:00.959143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:37:01.769231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:38:01.569176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:39:01.319261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:40:01.139122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:41:00.999196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:42:00.949104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:43:01.739107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:44:01.539261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:45:01.430534'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:46:01.379099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:47:01.299085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:48:01.149135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:49:01.194150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:50:01.769072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:51:01.559306'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:52:01.359100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:53:01.209292'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:54:01.293360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:55:00.999197'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:56:01.769137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:57:01.559118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:58:01.389277'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T06:59:01.459121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:00:01.350322'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:01:01.179171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:02:01.942900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:03:01.739256'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:04:01.559113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:05:01.409126'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:06:01.149129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:07:00.949155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:08:01.739128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:09:01.579205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:10:01.379217'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:11:01.179210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:12:01.159122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:13:01.293290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:14:00.949140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:15:01.790392'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:16:01.729072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:17:01.720387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:18:01.559190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:19:01.499243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:20:01.379108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:21:01.189196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:22:00.999274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:23:01.779294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:24:01.549154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:25:01.619140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:26:01.769250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:27:01.689129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:28:01.539178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:29:01.389166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:30:01.160399'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:31:01.692410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:32:00.969237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:33:01.989205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:34:01.729226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:35:01.559216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:36:01.399175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:37:01.169447'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:38:00.989131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:39:01.594400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:40:00.969114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:41:01.769198'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:42:01.579159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:43:01.559275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:44:01.379283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:45:01.180436'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:46:01.993880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:47:00.979144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:48:01.729162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:49:01.709143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:50:01.569345'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:51:01.559234'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:52:01.589157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:53:01.429189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:54:01.289172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:55:01.169388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:56:00.969251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:57:01.749120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:58:01.580779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T07:59:01.359270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:00:01.200439'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:01:00.989211'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:02:01.729141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:03:01.529184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:04:01.449297'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:05:01.389258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:06:01.379164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:07:01.159430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:08:00.989274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:09:01.759311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:10:01.629172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:11:01.549319'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:12:01.419332'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:13:01.289273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:14:01.179189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:15:00.990434'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:16:01.749283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:17:01.839206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:18:01.739179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:19:01.779285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:20:01.569388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:21:01.389160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:22:01.309160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:23:01.149449'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:24:00.969153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:25:01.719164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:26:01.539182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:27:01.419139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:28:01.159240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:29:00.989148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:30:00.980518'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:31:01.839262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:32:01.749361'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:33:01.819326'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:34:01.689170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:35:01.519206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:36:01.449283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:37:01.319243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:38:01.199141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:39:00.959286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:40:01.789185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:41:01.669274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:42:01.569301'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:43:01.409152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:44:01.339394'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:45:01.350400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:46:01.309557'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:47:01.159292'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:48:00.989166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:49:00.949149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:50:00.959281'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:51:01.739234'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:52:01.529157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:53:01.409154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:54:01.159285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:55:00.989144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:56:01.729449'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:57:01.599138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:58:01.609134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T08:59:01.529433'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:00:01.430624'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:01:01.319145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:02:01.159207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:03:01.914400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:04:00.959168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:05:01.749190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:06:01.559301'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:07:01.319201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:08:01.169185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:09:00.959295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:10:01.739201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:11:01.719216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:12:01.609137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:13:01.439181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:14:01.549279'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:15:01.390424'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:16:01.289137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:17:01.169183'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:18:01.159255'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:19:00.999124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:20:01.749248'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:21:01.719237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:22:01.539231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:23:01.349245'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:24:01.199258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:25:01.119402'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:26:01.926800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:27:00.969182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:28:01.779148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:29:01.709139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:30:01.590420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:31:01.639148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:32:01.539121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:33:01.599225'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:34:01.579275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:35:01.399157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:36:01.159291'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:37:01.197300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:38:01.799137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:39:01.799148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:40:01.730016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:41:01.689130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:42:01.549178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:43:01.389242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:44:01.229128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:45:01.190427'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:46:01.193010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:47:01.729148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:48:01.559226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:49:01.409269'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:50:01.149202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:51:00.979127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:52:00.949163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:53:01.729172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:54:01.629352'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:55:01.519267'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:56:01.389132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:57:01.359297'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:58:01.319216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T09:59:01.169205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:00:00.950326'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:01:01.729392'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:02:01.599251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:03:01.549283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:04:01.349147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:05:01.439185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:06:01.449261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:07:01.329151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:08:01.159451'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:09:01.393470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:10:00.939203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:11:00.959680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:12:01.749108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:13:01.589369'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:14:01.379175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:15:01.160555'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:16:01.293470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:17:00.969160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:18:01.779147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:19:01.739160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:20:01.679264'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:21:01.579162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:22:01.379270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:23:01.149123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:24:00.969130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:25:01.729164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:26:01.539335'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:27:01.369271'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:28:01.279134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:29:01.159172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:30:00.970335'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:31:01.869188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:32:01.593050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:33:02.289209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:34:01.179144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:35:01.169140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:36:00.949129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:37:01.729140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:38:01.559340'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:39:01.419277'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:40:01.149180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:41:00.969154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:42:01.739144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:43:01.539259'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:44:01.369120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:45:01.360399'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:46:01.189265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:47:01.293520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:48:00.979150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:49:01.259460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:50:01.159173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:51:00.979217'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:52:01.779278'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:53:01.789142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:54:01.759171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:55:01.599162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:56:01.399105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:57:01.229128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:58:01.189222'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T10:59:01.169297'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:00:01.150295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:01:00.989435'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:02:00.959287'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:03:01.759082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:04:01.669186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:05:01.529280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:06:01.389184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:07:01.229294'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:08:01.139307'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:09:00.999214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:10:01.749172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:11:01.579160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:12:01.559180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:13:01.549177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:14:01.399249'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:15:01.180492'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:16:00.999171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:17:00.959070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:18:01.729187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:19:01.709380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:20:01.569243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:21:01.399267'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:22:01.159304'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:23:00.949244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:24:01.769172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:25:01.779146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:26:01.789228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:27:01.549170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:28:01.369250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:29:01.159286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:30:00.980383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:31:01.839192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:32:01.799368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:33:02.929200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:34:00.959175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:35:01.749191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:36:01.569300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:37:01.339261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:38:01.189295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:39:01.169466'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:40:00.959529'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:41:01.729162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:42:01.599313'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:43:01.489183'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:44:01.369549'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:45:01.200599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:46:01.996290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:47:00.999252'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:48:01.779156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:49:01.809187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:50:01.739165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:51:01.569181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:52:01.529150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:53:01.429205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:54:01.299215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:55:01.159441'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:56:01.139194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:57:00.989320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:58:01.749253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T11:59:01.589263'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:00:01.490542'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:01:01.379460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:02:01.219262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:03:00.939146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:04:01.749141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:05:01.759236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:06:01.729133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:07:01.549286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:08:01.399059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:09:01.169266'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:10:01.159480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:11:00.989205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:12:01.739249'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:13:01.739173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:14:01.529160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:15:01.420298'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:16:01.189453'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:17:01.179988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:18:01.339157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:19:01.289170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:20:01.149271'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:21:00.999148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:22:01.729177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:23:01.579347'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:24:01.389168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:25:01.169301'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:26:01.169241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:27:01.159302'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:28:01.191060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:29:01.769138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:30:01.570363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:31:01.799236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:32:01.719158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:33:01.829230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:34:01.779221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:35:01.619143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:36:01.579227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:37:01.499129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:38:01.359168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:39:01.149351'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:40:01.129296'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:41:00.969274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:42:01.779169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:43:01.589171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:44:01.589176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:45:01.600421'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:46:01.369180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:47:01.149268'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:48:00.959151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:49:01.739300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:50:01.519157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:51:01.349151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:52:01.179275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:53:01.189196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:54:01.159336'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:55:00.979266'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:56:01.749186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:57:01.589250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:58:01.709175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T12:59:01.579311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:00:01.460398'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:01:01.389089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:02:01.169225'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:03:00.989165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:04:01.729434'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:05:01.579102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:06:01.369282'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:07:01.179214'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:08:00.979201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:09:01.749480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:10:01.579134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:11:01.649352'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:12:01.599364'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:13:01.389241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:14:01.209159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:15:00.970388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:16:01.739186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:17:01.559150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:18:01.379323'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:19:01.179258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:20:00.989219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:21:00.949287'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:22:01.749148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:23:01.589171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:24:01.749140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:25:01.679286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:26:01.529175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:27:01.349284'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:28:01.189232'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:29:00.999219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:30:01.730439'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:31:01.639263'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:32:01.589151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:33:02.569338'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:34:01.399738'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:35:01.149298'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:36:00.999239'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:37:00.989135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:38:00.949188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:39:00.959179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:40:01.749151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:41:01.739163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:42:01.559153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:43:01.369161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:44:01.159272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:45:00.950398'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:46:01.739165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:47:01.569350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:48:01.509247'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:49:01.349216'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:50:01.139381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:51:01.169158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:52:01.169192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:53:01.923300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:54:01.739256'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:55:01.699300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:56:01.579155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:57:01.409154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:58:01.169265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T13:59:01.394070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:00:01.105150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:01:01.729206'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:02:01.669374'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:03:01.529179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:04:01.609184'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:05:01.639175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:06:01.539207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:07:01.369147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:08:01.189377'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:09:00.939177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:10:01.749158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:11:01.639333'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:12:01.549162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:13:01.389238'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:14:01.159257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:15:00.991619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:16:01.789431'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:17:01.990244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:18:00.999239'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:19:00.989236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:20:01.769236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:21:01.569252'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:22:01.579161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:23:01.359179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:24:01.149203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:25:01.149178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:26:00.959157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:27:01.779429'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:28:01.609257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:29:01.549188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:30:01.370368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:31:01.269194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:32:01.320082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:33:02.459331'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:34:01.379275'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:35:01.189147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:36:01.925900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:37:01.739195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:38:01.579304'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:39:01.339150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:40:01.139178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:41:00.959120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:42:00.979210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:43:01.739347'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:44:01.569144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:45:01.700495'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:46:01.559155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:47:01.429264'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:48:01.369418'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:49:01.159300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:50:00.959174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:51:01.719248'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:52:01.589182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:53:01.429149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:54:01.419256'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:55:01.209268'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:56:01.293900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:57:01.789180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:58:01.769180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T14:59:01.829205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:00:01.760426'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:01:01.549144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:02:01.509495'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:03:01.409364'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:04:01.179411'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:05:01.493580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:06:00.999601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:07:01.739339'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:08:01.559478'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:09:01.389475'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:10:01.329726'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:11:01.159414'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:12:01.393750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:13:00.979371'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:14:01.729379'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:15:01.610632'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:16:01.499613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:17:01.359380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:18:01.189486'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:19:01.894960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:20:00.989380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:21:01.759380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:22:01.739518'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:23:01.759368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:24:01.699597'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:25:01.599926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:26:01.499491'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:27:01.439386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:28:01.379456'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:29:01.179502'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:30:01.729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:31:01.829934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:32:01.739418'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:33:01.989552'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:34:00.939539'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:35:01.749398'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:36:01.759557'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:37:01.759451'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:38:01.679349'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:39:01.549373'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:40:01.359353'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:41:01.179715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:42:00.969464'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:43:00.939499'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:44:01.739368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:45:01.570627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:46:01.369536'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:47:01.289602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:48:01.159642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:49:01.109543'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:50:01.794670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:51:01.794630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:52:00.999327'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:53:01.779460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:54:01.579356'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:55:01.399501'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:56:01.349534'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:57:01.159484'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:58:01.609120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T15:59:00.959460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:00:01.730611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:01:01.569478'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:02:01.419450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:03:01.319391'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:04:01.209472'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:05:01.179383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:06:00.999364'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:07:00.959377'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:08:01.759528'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:09:01.609370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:10:01.509413'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:11:01.409380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:12:01.179496'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:13:01.149507'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:14:00.989378'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:15:01.800734'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:16:01.719450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:17:01.979618'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:18:01.729444'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:19:01.589456'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:20:01.579495'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:21:01.569374'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:22:01.379419'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:23:01.349609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:24:01.189484'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:25:01.951500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:26:01.739350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:27:01.569390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:28:01.379497'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:29:01.349482'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:30:01.320601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:31:01.289403'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:32:01.149642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:33:02.339471'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:34:01.169391'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:35:00.969412'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:36:01.759362'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:37:01.739370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:38:01.589378'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:39:01.499369'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:40:01.419475'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:41:01.189842'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:42:01.995990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:43:01.119587'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:44:01.210117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:45:01.151382'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:46:00.990082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:47:01.750048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:48:01.580285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:49:01.450012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:50:01.449985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:51:01.320027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:52:01.170058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:53:00.960011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:54:01.750178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:55:01.589985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:56:01.740179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:57:01.659975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:58:01.579977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T16:59:01.430005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:00:01.441183'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:01:01.350078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:02:01.170263'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:03:01.130148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:04:01.120211'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:05:00.970020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:06:01.729975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:07:01.579971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:08:01.400041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:09:01.429988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:10:01.420012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:11:01.429986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:12:01.320001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:13:01.170147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:14:01.120299'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:15:00.971342'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:16:01.730013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:17:01.600021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:18:01.520027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:19:01.430329'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:20:01.320032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:21:01.180090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:22:01.150090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:23:01.230241'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:24:01.320139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:25:01.160163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:26:00.981330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:27:01.749983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:28:01.769964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:29:01.679984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:30:01.571179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:31:01.490285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:32:01.350069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:33:02.430059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:34:01.349979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:35:01.220076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:36:01.160244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:37:00.950040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:38:00.960117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:39:01.741269'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:40:01.569998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:41:01.390114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:42:01.190221'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:43:00.979965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:44:01.611500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:45:00.951283'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:46:01.760099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:47:01.550105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:48:01.538911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:49:01.549036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:50:01.519051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:51:01.408937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:52:01.139054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:53:00.979011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:54:01.758959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:55:01.718899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:56:01.558895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:57:01.379016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:58:01.229000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T17:59:01.129090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:00:00.970090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:01:00.988880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:02:01.838888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:03:00.938864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:04:01.729010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:05:01.729035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:06:01.608907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:07:01.548911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:08:01.398995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:09:01.169128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:10:00.948892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:11:01.808905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:12:01.738898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:13:01.538884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:14:01.448968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:15:01.410109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:16:01.288928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:17:01.169004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:18:01.139095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:19:00.998875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:20:00.950828'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:21:01.768863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:22:01.568929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:23:01.378868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:24:01.159026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:25:00.969000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:26:01.748899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:27:01.558979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:28:01.578923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:29:01.608888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:30:01.550194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:31:01.448928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:32:01.389021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:33:02.359235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:34:01.169005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:35:01.891100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:36:01.738889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:37:01.558990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:38:01.418913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:39:01.159137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:40:00.968983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:41:01.748983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:42:01.728948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:43:01.708996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:44:01.579070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:45:01.550239'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:46:01.398894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:47:01.308925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:48:01.178968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:49:01.168913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:50:00.948958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:51:01.748977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:52:01.579097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:53:01.548989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:54:01.398903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:55:01.528961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:56:01.449307'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:57:01.368935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:58:01.208932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T18:59:00.998903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:00:01.740156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:01:01.538980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:02:01.518867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:03:01.399028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:04:01.179097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:05:01.990840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:06:00.969041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:07:01.758900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:08:01.778974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:09:01.748891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:10:01.549038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:11:01.348939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:12:01.228974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:13:01.138943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:14:00.948870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:15:01.760153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:16:01.749022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:17:01.698986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:18:01.528943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:19:01.448887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:20:01.319052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:21:01.198896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:22:01.189781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:23:01.891040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:24:00.978898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:25:01.719120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:26:01.508920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:27:01.339009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:28:01.158951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:29:01.189980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:30:01.750159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:31:01.638908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:32:01.539020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:33:02.588994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:34:01.388872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:35:01.298868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:36:01.359047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:37:01.159129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:38:00.958986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:39:00.968979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:40:01.748891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:41:01.498885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:42:01.349041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:43:01.159075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:44:00.998872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:45:01.750314'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:46:01.608971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:47:01.548916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:48:01.458930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:49:01.468934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:50:01.359108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:51:01.168991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:52:00.949015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:53:00.958933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:54:01.708875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:55:01.549066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:56:01.428955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:57:01.308908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:58:01.168932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T19:59:00.949030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:00:00.960127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:01:01.749035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:02:00.948961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:03:01.199270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:04:01.768931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:05:01.598861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:06:01.398881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:07:01.158909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:08:00.968834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:09:01.729063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:10:01.578900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:11:01.328992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:12:01.158994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:13:01.790800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:14:01.290800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:15:01.202760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:16:00.948989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:17:01.290250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:18:00.998905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:19:01.739038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:20:01.748904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:21:01.539133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:22:01.408968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:23:01.168919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:24:01.148988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:25:00.958864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:26:01.748868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:27:01.558885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:28:01.428882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:29:01.399047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:30:01.370090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:31:01.238994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:32:01.179107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:33:02.220034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:34:01.129094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:35:01.189880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:36:01.758918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:37:01.748861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:38:01.548910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:39:01.349054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:40:01.189021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:41:01.590860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:42:00.988902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:43:00.958899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:44:01.748869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:45:01.550182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:46:01.338913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:47:01.178946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:48:00.938858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:49:01.728911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:50:01.579088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:51:01.358876'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:52:01.179005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:53:01.390910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:54:01.759011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:55:00.948874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:56:01.729020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:57:01.579355'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:58:01.359510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T20:59:01.189133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:00:00.990541'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:01:01.728891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:02:01.538967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:03:01.408896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:04:01.308902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:05:01.179165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:06:00.978976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:07:01.768875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:08:01.568907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:09:01.448954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:10:01.398899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:11:01.219033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:12:01.188935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:13:00.998983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:14:00.958916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:15:01.770111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:16:01.549000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:17:01.574035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:18:01.528879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:19:01.338915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:20:01.398996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:21:01.398954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:22:01.278993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:23:01.158957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:24:00.988900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:25:01.729068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:26:01.588873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:27:01.338889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:28:01.358897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:29:01.179025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:30:00.950086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:31:01.828968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:32:01.689004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:33:02.769050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:34:01.589138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:35:01.619106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:36:01.438918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:37:01.388875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:38:01.149022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:39:00.948871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:40:01.739090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:41:01.539040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:42:01.378905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:43:01.179025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:44:01.189250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:45:00.950228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:46:01.778931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:47:01.618863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:48:01.598893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:49:01.578954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:50:01.348984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:51:01.178927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:52:00.989063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:53:01.769012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:54:01.808891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:55:01.778932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:56:01.768955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:57:01.568957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:58:01.418878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T21:59:01.159007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:00:01.400830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:01:01.792210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:02:00.978930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:03:01.749322'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:04:01.579006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:05:01.388880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:06:01.149168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:07:00.968931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:08:01.758913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:09:01.588918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:10:01.538907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:11:01.349188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:12:01.169068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:13:00.958926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:14:01.738996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:15:01.710215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:16:01.528951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:17:01.318864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:18:01.169125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:19:00.958911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:20:01.759018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:21:01.589026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:22:01.369038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:23:01.159038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:24:00.958884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:25:00.958972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:26:01.788944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:27:01.568931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:28:01.418916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:29:01.270288'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:30:01.150100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:31:01.288670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:32:01.728993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:33:02.769474'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:34:01.669060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:35:01.679031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:36:01.558972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:37:01.338912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:38:01.148941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:39:00.989039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:40:01.758906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:41:01.718886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:42:00.938902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:43:01.768853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:44:01.538960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:45:01.390154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:46:01.149060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:47:01.891240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:48:01.391180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:49:00.948872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:50:01.768943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:51:01.538899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:52:01.418888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:53:01.138951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:54:01.188830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:55:01.191560'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:56:00.968903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:57:00.959045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:58:01.759022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T22:59:01.738902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:00:01.560158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:01:01.369064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:02:01.158959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:03:00.989179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:04:01.768928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:05:01.738892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:06:01.558913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:07:01.418901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:08:01.308989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:09:01.239072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:10:01.119009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:11:00.968921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:12:01.719133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:13:01.548969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:14:01.328985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:15:01.170154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:16:01.290040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:17:00.958894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:18:01.749103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:19:01.528897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:20:01.388930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:21:01.168950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:22:01.189022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:23:01.178907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:24:01.108894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:25:00.968957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:26:01.768921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:27:01.539047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:28:01.439068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:29:01.458989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:30:01.380195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:31:01.239058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:32:01.128918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:33:02.249022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:34:01.149012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:35:01.904600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:36:01.178944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:37:00.998869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:38:01.768917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:39:01.609001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:40:01.419021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:41:01.169191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:42:01.290080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:43:00.949024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:44:01.728950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:45:01.560165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:46:01.549006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:47:01.329074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:48:01.228901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:49:01.188989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:50:00.988980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:51:00.958884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:52:01.738998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:53:01.618923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:54:01.378913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:55:01.168924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:56:01.590840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:57:00.939008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:58:01.739005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-24T23:59:01.519459'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:00:01.380038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:01:01.199067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:02:01.198990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:03:01.329009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:04:01.168960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:05:00.998882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:06:01.768929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:07:01.780182'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:08:01.538878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:09:01.358917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:10:01.149037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:11:01.292270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:12:00.958932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:13:01.799181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:14:01.748895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:15:01.790201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:16:01.619050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:17:01.588905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:18:01.548909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:19:01.368854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:20:01.209004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:21:00.958869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:22:01.778904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:23:01.809076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:24:01.728990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:25:01.548998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:26:01.378886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:27:01.159049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:28:01.590420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:29:01.899600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:30:01.730108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:31:01.638933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:32:01.378981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:33:02.409096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:34:01.158932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:35:00.978896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:36:01.728921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:37:01.728980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:38:01.588976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:39:01.399144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:40:01.158890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:41:01.499060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:42:00.989335'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:43:01.738888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:44:01.748864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:45:01.560166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:46:01.359114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:47:01.169025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:48:01.921300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:49:01.738915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:50:01.679015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:51:01.548920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:52:01.368915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:53:01.138936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:54:01.190900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:55:01.589880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:56:00.948880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:57:01.769055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:58:01.578931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T00:59:01.558904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:00:01.420213'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:01:01.179053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:02:00.959329'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:03:01.738961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:04:01.758922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:05:01.518958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:06:01.458937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:07:01.699002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:08:01.729088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:09:01.528975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:10:01.348882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:11:01.149180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:12:00.978924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:13:01.718902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:14:01.688913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:15:01.550150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:16:01.408901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:17:01.218991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:18:01.159067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:19:01.188970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:20:00.988896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:21:01.769144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:22:01.598961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:23:01.389118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:24:01.148944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:25:01.188960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:26:00.959043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:27:01.748899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:28:01.558997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:29:01.369037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:30:01.150178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:31:01.604330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:32:01.188700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:33:03.896300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:34:00.978932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:35:01.718942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:36:01.518989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:37:01.389045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:38:01.279015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:39:01.189038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:40:01.148937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:41:00.958944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:42:01.708915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:43:01.538905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:44:01.368973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:45:01.180334'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:46:01.149132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:47:01.218999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:48:00.998930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:49:01.749173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:50:01.549026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:51:01.408899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:52:01.139019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:53:00.958960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:54:01.758899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:55:01.588947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:56:01.388917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:57:01.169087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:58:01.791270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T01:59:01.292050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:00:01.101420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:01:00.969079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:02:01.738897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:03:01.628984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:04:01.508885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:05:01.398981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:06:01.148970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:07:00.978893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:08:01.738873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:09:01.538902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:10:01.359141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:11:01.228982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:12:01.218959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:13:01.219004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:14:01.168929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:15:01.120149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:16:00.988919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:17:01.749011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:18:01.748903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:19:01.538976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:20:01.388909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:21:01.178946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:22:01.188960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:23:00.968901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:24:01.768935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:25:00.959657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:26:01.769105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:27:01.529258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:28:01.318947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:29:01.158977'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:30:01.166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:31:01.819043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:32:01.768894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:33:02.788982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:34:01.688864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:35:01.558900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:36:01.378903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:37:01.178985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:38:01.390590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:39:01.691100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:40:00.978992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:41:01.738860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:42:01.668901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:43:01.538887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:44:01.388944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:45:01.180132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:46:00.958927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:47:01.768906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:48:01.568989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:49:01.368949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:50:01.179013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:51:01.791190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:52:01.118941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:53:00.998965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:54:01.759017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:55:01.598916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:56:01.578895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:57:01.379041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:58:01.149090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T02:59:01.199780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:00:00.960097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:01:01.739068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:02:01.598897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:03:01.568955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:04:01.438982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:05:01.399017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:06:01.348973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:07:01.159045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:08:00.968878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:09:01.768877'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:10:01.529047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:11:01.378901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:12:01.139058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:13:00.938993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:14:01.738940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:15:01.560075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:16:01.348926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:17:01.148981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:18:00.978910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:19:01.778972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:20:01.710210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:21:01.528958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:22:01.358988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:23:01.118908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:24:00.978922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:25:01.729109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:26:01.548924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:27:01.378893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:28:01.179021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:29:00.969205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:30:01.740133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:31:01.698971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:32:01.708878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:33:02.789019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:34:01.719103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:35:01.548889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:36:01.488919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:37:01.378863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:38:01.179093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:39:00.968860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:40:01.738903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:41:01.558880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:42:01.358922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:43:01.178920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:44:01.689430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:45:00.990260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:46:00.938944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:47:01.728882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:48:01.598929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:49:01.438946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:50:01.358869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:51:01.189178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:52:00.999139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:53:01.748902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:54:01.568924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:55:01.378921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:56:01.158912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:57:01.188950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:58:00.979173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T03:59:01.491090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:00:00.970297'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:01:01.728880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:02:01.548900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:03:01.528906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:04:01.409050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:05:01.188908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:06:00.958886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:07:01.728891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:08:01.548892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:09:01.368933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:10:01.288919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:11:01.198907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:12:01.309031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:13:01.189055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:14:01.191090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:15:01.740133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:16:01.569143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:17:01.328883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:18:01.199056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:19:00.948872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:20:01.748872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:21:01.588922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:22:01.379055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:23:01.169136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:24:01.219008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:25:01.189020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:26:01.218944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:27:01.169081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:28:00.958873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:29:01.738897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:30:01.630089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:31:01.408933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:32:01.158910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:33:02.179025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:34:01.158918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:35:01.488750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:36:01.769031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:37:01.519044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:38:01.398988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:39:01.169027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:40:01.790070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:41:00.959117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:42:01.728928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:43:01.538919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:44:01.338943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:45:01.160312'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:46:00.968893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:47:00.959017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:48:01.739108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:49:01.538912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:50:01.358875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:51:01.189025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:52:01.488460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:53:00.979004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:54:01.748888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:55:01.559040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:56:01.400381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:57:01.208927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:58:01.189059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T04:59:00.979139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:00:01.770073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:01:01.718892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:02:01.498914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:03:01.498923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:04:01.368869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:05:01.408941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:06:01.288908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:07:01.178994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:08:00.998843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:09:00.958898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:10:01.739156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:11:01.668944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:12:01.549005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:13:01.359004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:14:01.179129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:15:01.200210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:16:00.948988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:17:01.910065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:18:01.590630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:19:00.998890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:20:01.728874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:21:01.598905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:22:01.348867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:23:01.198910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:24:01.289050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:25:00.968883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:26:01.748978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:27:01.559025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:28:01.418882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:29:01.159056'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:30:01.134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:31:01.891350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:32:00.969045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:33:03.690630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:34:00.949157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:35:01.739152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:36:01.528962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:37:01.318904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:38:01.169061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:39:01.288990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:40:00.958896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:41:01.738869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:42:01.558887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:43:01.348997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:44:01.188929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:45:01.190111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:46:01.128996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:47:00.989031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:48:01.758879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:49:01.548919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:50:01.409101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:51:01.358884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:52:01.178906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:53:00.978965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:54:01.748904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:55:01.748885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:56:01.528886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:57:01.339022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:58:01.328871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T05:59:01.378901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:00:01.180152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:01:01.590300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:02:00.989018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:03:01.178916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:04:01.389670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:05:00.978920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:06:01.758865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:07:01.588897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:08:01.488890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:09:01.388960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:10:01.308863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:11:01.178932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:12:01.139009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:13:01.178975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:14:01.290480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:15:01.101180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:16:01.738916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:17:01.569103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:18:01.619078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:19:01.529169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:20:01.359040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:21:01.169060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:22:00.998908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:23:00.958930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:24:01.759041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:25:00.949967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:26:01.789138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:27:01.558976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:28:01.389009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:29:01.368912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:30:01.160400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:31:01.218918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:32:01.178945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:33:02.209072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:34:01.990330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:35:00.958971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:36:01.758909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:37:01.648999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:38:01.578907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:39:01.349099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:40:01.178949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:41:00.969003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:42:00.948901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:43:01.749018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:44:01.538901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:45:01.350300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:46:01.179130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:47:01.290680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:48:01.729021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:49:01.549020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:50:01.349101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:51:01.219155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:52:01.158938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:53:00.978882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:54:01.749018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:55:01.578895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:56:01.368969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:57:01.178896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:58:01.893300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T06:59:01.748886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:00:01.530257'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:01:01.329023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:02:01.168933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:03:01.129015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:04:00.968980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:05:00.958928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:06:00.978898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:07:01.728913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:08:01.569348'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:09:01.378973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:10:01.198935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:11:00.978926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:12:01.729146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:13:01.688982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:14:01.558860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:15:01.370123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:16:01.138965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:17:01.691160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:18:01.969400'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:19:01.177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:20:00.939030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:21:01.729131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:22:01.599001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:23:01.538884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:24:01.399016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:25:01.218853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:26:01.168905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:27:00.999577'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:28:01.729066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:29:01.688908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:30:01.640200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:31:01.838879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:32:01.738953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:33:02.758916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:34:01.778901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:35:01.528894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:36:01.368942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:37:01.148972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:38:00.999043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:39:01.778895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:40:01.748970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:41:01.588998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:42:01.578886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:43:01.488990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:44:01.399075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:45:01.301408'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:46:01.199006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:47:01.158902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:48:01.943600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:49:00.948906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:50:01.738905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:51:01.549052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:52:01.378896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:53:01.398975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:54:01.188983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:55:01.168919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:56:01.290820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:57:00.989135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:58:01.194280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T07:59:01.738954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:00:01.570148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:01:01.368891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:02:01.158939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:03:01.390760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:04:00.948926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:05:01.728951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:06:01.588896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:07:01.479141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:08:01.388905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:09:01.298882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:10:01.338906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:11:01.289093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:12:01.188951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:13:01.129175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:14:00.968887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:15:01.730154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:16:01.558889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:17:01.368888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:18:01.189288'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:19:00.938907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:20:01.748891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:21:01.599009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:22:01.538907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:23:01.448935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:24:01.439517'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:25:01.329185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:26:01.158959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:27:01.904700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:28:01.728965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:29:01.598978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:30:01.410128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:31:01.269032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:32:01.158929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:33:00.958913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:34:01.358915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:35:01.158995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:36:01.289120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:37:00.949141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:38:00.958914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:39:01.779405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:40:01.578897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:41:01.399138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:42:01.139011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:43:00.959009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:44:01.749143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:45:01.560291'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:46:01.368993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:47:01.289056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:48:01.198955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:49:00.978909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:50:01.759047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:51:01.758967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:52:01.578910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:53:01.358990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:54:01.198931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:55:01.903500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:56:01.768897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:57:01.668923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:58:01.548934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T08:59:01.448882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:00:01.300160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:01:01.169020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:02:01.891300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:03:01.728947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:04:01.718880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:05:01.589165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:06:01.379048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:07:01.168994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:08:00.988899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:09:01.749047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:10:01.578917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:11:01.378935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:12:01.149167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:13:00.988910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:14:00.949114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:15:01.740383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:16:01.598904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:17:01.829682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:18:01.778999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:19:01.569050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:20:01.378902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:21:01.159017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:22:00.969012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:23:01.718905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:24:01.548912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:25:01.328905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:26:01.148994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:27:00.948959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:28:00.958937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:29:01.788996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:30:01.740324'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:31:01.288640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:32:00.958882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:33:01.729157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:34:01.768913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:35:01.738922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:36:01.549001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:37:01.378927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:38:01.149050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:39:00.998997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:40:01.748896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:41:01.688882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:42:01.568928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:43:01.488893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:44:01.559051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:45:01.570146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:46:01.338840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:47:01.129231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:48:01.189910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:49:01.758903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:50:01.568898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:51:01.458977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:52:01.368934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:53:01.178921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:54:00.998902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:55:00.949044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:56:01.738974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:57:01.608886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:58:01.719060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T09:59:01.578914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:00:01.400524'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:01:01.208921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:02:01.493520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:03:00.938908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:04:01.749102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:05:01.678918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:06:01.549168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:07:01.369009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:08:01.198867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:09:01.158974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:10:00.988888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:11:01.498830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:12:01.902400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:13:01.728912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:14:01.568912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:15:01.500083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:16:01.349102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:17:01.168914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:18:01.158985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:19:00.968879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:20:01.790134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:21:01.718908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:22:01.568885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:23:01.409018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:24:01.219029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:25:01.228913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:26:01.591000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:27:00.959121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:28:01.768907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:29:01.588938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:30:01.500100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:31:01.498891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:32:01.428921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:33:01.399010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:34:01.549039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:35:01.378941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:36:01.198985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:37:01.169092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:38:01.199129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:39:01.188976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:40:00.978895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:41:01.728913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:42:01.558916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:43:01.379015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:44:01.198903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:45:01.160178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:46:00.978900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:47:01.778912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:48:01.709164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:49:01.558927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:50:01.439408'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:51:01.428931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:52:01.439090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:53:01.338894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:54:01.169023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:55:00.978882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:56:01.778926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:57:01.569102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:58:01.379004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T10:59:01.189024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:00:01.101890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:01:01.728959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:02:01.539014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:03:01.478909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:04:01.498905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:05:01.349071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:06:01.388961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:07:01.168915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:08:00.938937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:09:00.938921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:10:01.739036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:11:01.548962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:12:01.409867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:13:01.148998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:14:00.939153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:15:01.770068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:16:01.569014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:17:01.369658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:18:01.359085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:19:01.199016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:20:01.191540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:21:01.729106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:22:01.578904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:23:01.378942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:24:01.179081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:25:00.958891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:26:01.778888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:27:01.529013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:28:01.378935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:29:01.168951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:30:01.204140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:31:01.491090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:32:00.999008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:33:01.778856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:34:00.968895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:35:01.759026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:36:01.558893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:37:01.369038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:38:01.168883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:39:00.978907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:40:00.958889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:41:01.738895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:42:01.598981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:43:01.549055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:44:01.589200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:45:01.540152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:46:01.359063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:47:01.138927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:48:00.959027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:49:00.958811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:50:01.719213'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:51:01.579003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:52:01.479065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:53:01.418907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:54:01.318929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:55:01.159101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:56:00.949047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:57:00.999031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:58:01.779152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T11:59:01.668915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:00:01.590195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:01:01.418931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:02:01.329039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:03:01.158996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:04:00.979201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:05:01.748941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:06:01.558938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:07:01.499120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:08:01.378925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:09:01.199226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:10:01.308961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:11:01.199166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:12:01.389150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:13:01.748928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:14:01.588941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:15:01.390141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:16:01.159033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:17:00.999014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:18:01.749030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:19:01.558958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:20:01.459073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:21:01.308948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:22:01.148983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:23:01.900500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:24:00.938958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:25:01.748928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:26:01.699052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:27:01.579144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:28:01.429011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:29:01.298953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:30:01.250237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:31:01.239237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:32:01.690940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:33:00.989048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:34:01.159201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:35:00.978955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:36:01.768964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:37:01.628948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:38:01.599073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:39:01.359026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:40:01.259071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:41:01.199075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:42:00.998969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:43:01.768915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:44:01.718968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:45:01.550253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:46:01.399207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:47:01.179234'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:48:01.913400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:49:01.749046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:50:00.968963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:51:01.789105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:52:01.588938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:53:01.539018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:54:01.479105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:55:01.429024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:56:01.398961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:57:01.299005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:58:01.339022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T12:59:01.159088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:00:00.980198'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:01:01.758943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:02:01.548958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:03:01.449048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:04:01.429113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:05:01.328905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:06:01.139192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:07:00.969070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:08:01.739087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:09:01.558971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:10:01.339095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:11:01.179027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:12:00.978945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:13:01.758912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:14:01.579147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:15:01.450149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:16:01.459101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:17:01.398936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:18:01.349044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:19:01.169101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:20:00.959085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:21:01.739102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:22:01.568938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:23:01.408982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:24:01.168953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:25:01.891880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:26:00.949059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:27:01.738951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:28:01.748951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:29:01.738939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:30:01.580140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:31:01.698973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:32:01.579724'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:33:01.338949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:34:01.399011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:35:01.188977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:36:00.989000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:37:01.759075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:38:01.578940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:39:01.378974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:40:01.149164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:41:01.390180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:42:01.728944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:43:01.579020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:44:01.549085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:45:01.510360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:46:01.358961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:47:01.159036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:48:01.592750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:49:00.949006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:50:01.749064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:51:01.589008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:52:01.428953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:53:01.209205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:54:00.998916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:55:00.949062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:56:01.778954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:57:01.728907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:58:01.729073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T13:59:01.549067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:00:01.360185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:01:01.159037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:02:01.168973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:03:01.199041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:04:00.978862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:05:01.778973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:06:01.609026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:07:01.558962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:08:01.419243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:09:01.169029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:10:01.890380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:11:01.691850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:12:00.968911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:13:01.748938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:14:01.569029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:15:01.620134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:16:01.599161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:17:01.388924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:18:01.179040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:19:01.917800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:20:01.729059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:21:01.569041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:22:01.548948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:23:01.439082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:24:01.518946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:25:01.649441'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:26:01.558940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:27:01.419026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:28:01.329058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:29:01.169169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:30:00.990134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:31:01.818963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:32:01.738928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:33:01.699026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:34:01.738953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:35:01.578912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:36:01.578939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:37:01.538931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:38:01.509047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:39:01.548953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:40:01.409215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:41:01.358967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:42:01.168951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:43:00.958932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:44:01.729039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:45:01.640225'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:46:01.478929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:47:01.378958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:48:01.158958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:49:01.916400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:50:00.959978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:51:01.778935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:52:01.699023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:53:01.528927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:54:01.389047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:55:01.179031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:56:00.978936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:57:01.728944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:58:01.578934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T14:59:01.368976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:00:01.230111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:01:01.198974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:02:01.890430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:03:01.191680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:04:01.291070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:05:01.779085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:06:01.569114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:07:01.338938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:08:01.148975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:09:01.148965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:10:00.958937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:11:01.758926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:12:01.728923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:13:01.578956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:14:01.448998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:15:01.350219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:16:01.238944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:17:01.309062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:18:01.179179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:19:01.926700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:20:00.948976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:21:01.738913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:22:01.579043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:23:01.408950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:24:01.179007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:25:00.948924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:26:00.958874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:27:01.738935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:28:01.558914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:29:01.429219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:30:01.370119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:31:01.438997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:32:01.349061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:33:01.178982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:34:01.348927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:35:01.179224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:36:01.258930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:37:01.159113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:38:00.998926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:39:01.739112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:40:01.569059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:41:01.388934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:42:01.208978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:43:01.258927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:44:01.319023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:45:01.160418'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:46:00.988949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:47:01.748984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:48:01.569038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:49:01.348921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:50:01.188944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:51:01.790520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:52:00.969153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:53:00.958914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:54:01.738948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:55:01.548937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:56:01.448940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:57:01.419034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:58:01.228963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T15:59:01.159141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:00:00.990195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:01:01.738929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:02:01.599045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:03:01.559440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:04:01.378954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:05:01.189162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:06:00.978928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:07:00.969066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:08:01.728973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:09:01.578958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:10:01.599018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:11:01.478977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:12:01.348950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:13:01.178983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:14:00.978924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:15:01.730145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:16:01.548967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:17:01.438938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:18:01.378977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:19:01.208973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:20:01.893800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:21:01.748939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:22:01.548952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:23:01.478961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:24:01.568950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:25:01.518936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:26:01.339079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:27:01.148994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:28:01.189570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:29:01.769103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:30:01.760331'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:31:01.829041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:32:01.718927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:33:01.518980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:34:01.748931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:35:01.599063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:36:01.398995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:37:01.368991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:38:01.459080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:39:01.378942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:40:01.198974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:41:01.169044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:42:00.968942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:43:01.779019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:44:01.569481'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:45:01.360168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:46:01.159025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:47:00.988927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:48:01.768926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:49:01.708928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:50:01.629229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:51:01.639069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:52:01.529001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:53:01.388969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:54:01.348961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:55:01.169153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:56:00.948962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:57:01.738932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:58:01.749033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T16:59:01.708917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:00:01.620159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:01:01.559226'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:02:01.409018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:03:01.349053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:04:01.579020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:05:01.509486'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:06:01.369054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:07:01.189054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:08:01.109103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:09:00.998910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:10:01.748915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:11:01.539171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:12:01.339023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:13:01.149051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:14:00.939076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:15:01.750145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:16:01.588997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:17:01.619833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:18:01.579030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:19:01.329021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:20:01.148998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:21:00.998952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:22:01.738930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:23:01.598945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:24:01.369042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:25:01.308938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:26:01.199017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:27:01.218906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:28:01.229018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:29:01.188967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:30:01.403100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:31:01.791750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:32:00.968955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:33:01.739083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:34:00.948945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:35:01.778935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:36:01.698957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:37:01.548942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:38:01.468944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:39:01.378916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:40:01.179186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:41:01.690800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:42:00.998957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:43:01.738933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:44:01.588913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:45:01.580202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:46:01.398969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:47:01.189367'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:48:01.208924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:49:00.988955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:50:01.768961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:51:01.558967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:52:01.439030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:53:01.308946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:54:01.149114'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:55:01.190420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:56:01.738919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:57:01.618956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:58:01.689060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T17:59:01.529073'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:00:01.370103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:01:01.199075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:02:00.978930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:03:01.758971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:04:01.608935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:05:01.519085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:06:01.368934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:07:01.168992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:08:01.169011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:09:01.178920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:10:00.948944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:11:00.938970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:12:01.768922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:13:01.528944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:14:01.388943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:15:01.170128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:16:00.959060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:17:01.738932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:18:01.578978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:19:01.519033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:20:01.398931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:21:01.299230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:22:01.139112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:23:01.178961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:24:01.209253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:25:01.169063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:26:01.906600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:27:01.779119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:28:01.658909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:29:01.609019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:30:01.400191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:31:01.269104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:32:01.139124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:33:00.988996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:34:01.168966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:35:01.129079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:36:00.978913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:37:01.190270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:38:01.590690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:39:00.939016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:40:01.768942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:41:01.558965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:42:01.358959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:43:01.208975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:44:00.958963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:45:01.760172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:46:01.748939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:47:01.569027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:48:01.548926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:49:01.419059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:50:01.399053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:51:01.309054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:52:01.168942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:53:01.149036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:54:00.978902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:55:01.729002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:56:01.699049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:57:01.578904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:58:01.359103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T18:59:01.158938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:00:00.950246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:01:01.729066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:02:01.568917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:03:01.708943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:04:01.759397'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:05:01.658958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:06:01.558926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:07:01.398987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:08:01.158908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:09:01.196580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:10:01.788976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:11:01.558942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:12:01.348926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:13:01.368942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:14:01.199024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:15:01.602590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:16:01.491460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:17:01.889640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:18:00.958910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:19:01.778994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:20:01.558930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:21:01.339062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:22:01.188948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:23:01.109090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:24:01.291180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:25:01.808914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:26:01.838933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:27:01.738917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:28:01.589009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:29:01.579209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:30:01.590391'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:31:01.509077'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:32:01.369345'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:33:01.228989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:34:01.409039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:35:01.159042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:36:01.490560'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:37:01.907100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:38:00.948930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:39:01.739013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:40:01.598901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:41:01.368940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:42:01.209092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:43:01.339833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:44:01.179044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:45:00.980174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:46:01.728967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:47:01.588937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:48:01.379094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:49:01.159211'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:50:01.119246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:51:00.948927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:52:01.759029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:53:01.578977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:54:01.378922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:55:01.179051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:56:01.189180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:57:01.589800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:58:00.948944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T19:59:01.738940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:00:01.650173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:01:01.508899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:02:01.369009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:03:01.219011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:04:01.169207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:05:01.389250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:06:00.949017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:07:01.738956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:08:01.748919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:09:01.648907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:10:01.589188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:11:01.409164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:12:01.189119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:13:00.959012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:14:01.768934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:15:01.560334'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:16:01.358938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:17:01.219856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:18:00.938936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:19:01.729039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:20:01.549116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:21:01.388955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:22:01.308962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:23:01.188988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:24:01.149071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:25:00.968946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:26:01.779103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:27:01.579087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:28:01.349042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:29:01.208939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:30:01.301150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:31:01.849231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:32:01.708956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:33:01.539250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:34:01.749067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:35:01.728958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:36:01.769055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:37:01.758974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:38:01.529171'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:39:01.408943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:40:01.179039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:41:01.199011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:42:00.948915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:43:01.739017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:44:01.729071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:45:01.600282'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:46:01.359054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:47:01.189101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:48:00.959010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:49:00.948937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:50:00.949004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:51:01.738931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:52:01.588970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:53:01.409015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:54:01.148950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:55:00.998991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:56:01.758953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:57:01.518955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:58:01.348971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T20:59:01.148984'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:00:01.168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:01:00.978922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:02:00.949094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:03:01.778964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:04:00.959133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:05:01.748945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:06:01.549002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:07:01.338965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:08:01.178922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:09:00.968961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:10:01.779040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:11:01.589026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:12:01.408959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:13:01.168950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:14:00.988965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:15:00.990130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:16:00.958971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:17:01.800087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:18:01.758916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:19:01.548934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:20:01.368946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:21:01.169086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:22:00.998992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:23:01.769021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:24:01.619181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:25:01.558911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:26:01.388945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:27:01.188985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:28:01.179045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:29:01.289030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:30:01.170231'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:31:01.891330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:32:00.958935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:33:01.728908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:34:01.739055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:35:01.568985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:36:01.398934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:37:01.379048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:38:01.329094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:39:01.168974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:40:00.988965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:41:01.758932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:42:01.718917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:43:01.568954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:44:01.409118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:45:01.210328'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:46:01.190240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:47:00.958932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:48:01.758934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:49:01.529215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:50:01.358921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:51:01.179004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:52:01.158954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:53:01.292240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:54:01.729142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:55:01.669087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:56:01.619409'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:57:01.419053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:58:01.188952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T21:59:00.978940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:00:01.740296'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:01:01.538978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:02:01.408933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:03:01.189186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:04:00.989101'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:05:00.968980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:06:01.748934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:07:01.588920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:08:01.619003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:09:01.528924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:10:01.358944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:11:01.159387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:12:00.948960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:13:01.728939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:14:01.508920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:15:01.360200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:16:01.148958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:17:00.999168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:18:01.748966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:19:01.608963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:20:01.399026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:21:01.229085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:22:01.269156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:23:01.198953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:24:00.999046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:25:01.738922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:26:01.549043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:27:01.369099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:28:01.168877'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:29:01.954500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:30:01.770131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:31:01.658954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:32:01.589020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:33:01.338972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:34:01.428928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:35:01.369068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:36:01.338959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:37:01.138943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:38:01.191640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:39:00.958896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:40:01.738959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:41:01.529150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:42:01.379042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:43:01.199064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:44:00.979346'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:45:01.750263'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:46:01.618984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:47:01.558962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:48:01.428951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:49:01.430094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:50:01.399080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:51:01.178947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:52:01.590660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:53:01.191400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:54:01.758921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:55:01.549063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:56:01.539013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:57:01.408926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:58:01.139044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T22:59:01.192430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:00:01.750212'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:01:01.779078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:02:01.738986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:03:01.608970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:04:01.548969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:05:01.409001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:06:01.158995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:07:00.999134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:08:01.738941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:09:01.599102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:10:01.538966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:11:01.389155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:12:01.169262'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:13:01.391040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:14:01.769009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:15:01.790202'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:16:01.739108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:17:01.539075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:18:01.348951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:19:01.129173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:20:00.969000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:21:01.759057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:22:01.538926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:23:01.408971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:24:01.209044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:25:01.169058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:26:00.989019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:27:01.749123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:28:01.759104'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:29:01.548937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:30:01.520142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:31:01.449040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:32:01.359224'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:33:01.179006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:34:01.169074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:35:00.959267'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:36:01.788961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:37:01.728912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:38:01.578957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:39:01.358935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:40:01.348921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:41:01.368945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:42:01.308924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:43:01.318991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:44:01.169141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:45:00.980210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:46:01.728928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:47:01.538932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:48:01.369038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:49:01.159205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:50:00.978946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:51:01.748939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:52:01.598952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:53:01.418969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:54:01.209113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:55:01.189139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:56:01.179049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:57:01.139058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:58:00.958963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-25T23:59:01.749089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:00:01.590207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:01:01.398926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:02:01.268952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:03:01.249623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:04:01.139100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:05:01.308928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:06:01.428951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:07:01.388968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:08:01.418977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:09:01.328949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:10:01.189058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:11:00.998958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:12:01.729118'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:13:01.559044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:14:01.398972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:15:01.410190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:16:01.299029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:17:01.170273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:18:00.978994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:19:01.738928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:20:01.608949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:21:01.588957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:22:01.519173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:23:01.429034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:24:01.378966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:25:01.148934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:26:00.989056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:27:01.808910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:28:01.548998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:29:01.369035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:30:01.180162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:31:01.248965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:32:01.149315'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:33:00.969026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:34:01.189105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:35:01.179295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:36:01.691600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:37:01.891670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:38:00.988949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:39:01.739094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:40:01.549065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:41:01.407645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:42:01.177693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:43:00.937601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:44:00.957684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:45:01.728888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:46:01.687598'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:47:01.637679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:48:01.617627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:49:01.367659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:50:01.167708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:51:01.107820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:52:00.967608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:53:01.747593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:54:01.587800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:55:01.367732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:56:01.157787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:57:01.175710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:58:01.737627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T00:59:01.777801'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:00:01.568814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:01:01.387678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:02:01.328053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:03:01.187736'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:04:01.776850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:05:00.947686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:06:01.767603'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:07:01.557672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:08:01.517609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:09:01.347708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:10:01.187777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:11:01.577590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:12:01.277320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:13:00.947568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:14:01.797577'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:15:01.768828'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:16:01.537607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:17:01.377598'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:18:01.227743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:19:01.137817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:20:00.977581'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:21:01.757673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:22:01.597641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:23:01.367708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:24:01.147858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:25:00.977713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:26:01.737591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:27:01.577732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:28:01.597568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:29:01.538841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:30:01.349053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:31:01.247576'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:32:01.187640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:33:00.987589'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:34:01.147620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:35:01.277940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:36:01.760300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:37:01.747562'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:38:01.567787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:39:01.367672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:40:01.307597'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:41:01.257580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:42:01.197600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:43:00.977619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:44:01.737690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:45:01.538891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:46:01.437581'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:47:01.397636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:48:01.267612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:49:01.127856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:50:00.977586'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:51:01.727734'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:52:01.757730'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:53:01.557675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:54:01.377727'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:55:01.338069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:56:01.188415'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:57:00.967582'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:58:01.737590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T01:59:01.557660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:00:01.358831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:01:01.157647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:02:00.987647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:03:01.707585'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:04:01.577652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:05:01.497572'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:06:01.377586'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:07:01.357576'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:08:01.317696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:09:01.357574'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:10:01.138335'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:11:00.957593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:12:01.747588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:13:01.607844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:14:01.347676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:15:01.299076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:16:01.167628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:17:00.947696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:18:01.757580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:19:01.607719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:20:01.517930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:21:01.517702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:22:01.458062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:23:01.317516'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:24:01.207682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:25:01.276950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:26:01.737775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:27:01.527779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:28:01.367677'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:29:01.197617'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:30:01.148832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:31:01.378520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:32:00.998151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:33:01.717699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:34:01.277470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:35:01.378860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:36:00.957602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:37:01.737808'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:38:01.557672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:39:01.477592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:40:01.397610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:41:01.207836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:42:01.157631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:43:00.977604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:44:01.737596'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:45:01.579172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:46:01.337694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:47:01.237680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:48:01.337811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:49:01.307674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:50:01.157610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:51:00.967604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:52:01.727709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:53:01.697688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:54:01.557655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:55:01.367580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:56:01.197870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:57:00.977559'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:58:01.737593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T02:59:01.847728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:00:01.728844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:01:01.747660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:02:01.567626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:03:01.567705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:04:01.327741'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:05:01.157640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:06:01.676170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:07:00.947567'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:08:01.717612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:09:01.637552'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:10:01.527722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:11:01.387695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:12:01.157723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:13:01.278390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:14:00.947758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:15:00.948837'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:16:00.947684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:17:01.759056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:18:01.557660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:19:01.367597'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:20:01.217636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:21:00.957557'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:22:01.737614'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:23:01.558900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:24:01.417629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:25:01.317684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:26:01.167640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:27:01.377500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:28:01.796000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:29:00.957584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:30:01.748841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:31:01.647569'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:32:01.547574'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:33:01.457596'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:34:01.557587'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:35:01.337602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:36:01.147592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:37:00.947800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:38:01.697706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:39:01.587593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:40:01.587591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:41:01.547629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:42:01.438826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:43:01.527607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:44:01.337626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:45:01.149045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:46:00.957606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:47:01.737626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:48:01.507597'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:49:01.357604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:50:01.187592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:51:00.997904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:52:01.747584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:53:01.597680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:54:01.567702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:55:01.547613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:56:01.357818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:57:01.147608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:58:00.987675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T03:59:01.727580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:00:00.948897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:01:01.727674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:02:01.587760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:03:01.367591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:04:01.347568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:05:01.177699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:06:01.477410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:07:01.767000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:08:00.947590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:09:01.727819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:10:01.547661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:11:01.357739'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:12:01.147825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:13:00.957733'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:14:01.727581'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:15:01.568821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:16:01.347583'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:17:01.168845'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:18:00.967696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:19:01.176430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:20:00.947652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:21:00.967676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:22:00.957721'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:23:01.757728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:24:01.597778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:25:01.377763'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:26:01.187765'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:27:00.957741'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:28:01.747702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:29:01.597636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:30:01.378895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:31:01.437701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:32:01.367607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:33:01.167652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:34:01.247667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:35:01.167735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:36:01.758400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:37:01.747589'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:38:01.547844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:39:01.367841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:40:01.107777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:41:00.967616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:42:01.737577'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:43:01.607656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:44:01.527753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:45:01.339093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:46:01.157732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:47:01.187694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:48:01.277593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:49:01.147845'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:50:00.957610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:51:01.727593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:52:01.537860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:53:01.367670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:54:01.197648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:55:01.167621'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:56:00.947650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:57:01.747810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:58:01.557621'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T04:59:01.357604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:00:01.178735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:01:01.763000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:02:00.947595'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:03:01.727735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:04:01.567737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:05:01.407606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:06:01.167787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:07:00.977613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:08:00.967857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:09:01.727599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:10:01.537767'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:11:01.457591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:12:01.407590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:13:01.167770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:14:01.157717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:15:01.198832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:16:01.175760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:17:01.768945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:18:01.577588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:19:01.387568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:20:01.177821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:21:01.576760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:22:00.997623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:23:01.817724'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:24:01.587606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:25:01.387657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:26:01.157619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:27:01.175950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:28:00.948351'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:29:01.777604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:30:01.548811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:31:01.457762'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:32:01.337579'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:33:01.157776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:34:01.367606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:35:01.127822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:36:00.987631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:37:01.737609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:38:01.667706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:39:01.547728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:40:01.437592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:41:01.437645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:42:01.407599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:43:01.327610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:44:01.137634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:45:00.978874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:46:01.777810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:47:01.557755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:48:01.447607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:49:01.357753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:50:01.147684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:51:00.947652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:52:00.977633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:53:01.737759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:54:01.757714'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:55:01.797768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:56:01.747685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:57:01.547592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:58:01.457803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T05:59:01.357803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:00:01.168829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:01:01.769700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:02:01.767807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:03:01.517711'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:04:01.367619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:05:01.237615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:06:01.187814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:07:01.761700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:08:00.967610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:09:01.737667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:10:01.547768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:11:01.387699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:12:01.377607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:13:01.187627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:14:00.997684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:15:01.788832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:16:01.747617'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:17:01.858133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:18:01.737682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:19:01.567751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:20:01.387604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:21:01.397738'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:22:01.468506'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:23:01.357584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:24:01.157698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:25:00.977562'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:26:01.737731'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:27:01.567595'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:28:01.517599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:29:01.397575'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:30:01.198847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:31:01.247602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:32:01.147748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:33:00.987584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:34:01.287671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:35:01.217607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:36:01.157655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:37:00.957606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:38:01.737711'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:39:01.577619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:40:01.327570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:41:01.197612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:42:00.967736'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:43:01.747613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:44:01.527645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:45:01.348818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:46:01.318316'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:47:01.207761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:48:01.198566'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:49:00.987584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:50:01.737682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:51:01.547739'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:52:01.427603'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:53:01.357836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:54:01.157704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:55:00.977569'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:56:01.757614'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:57:01.577573'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:58:01.407709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T06:59:01.287573'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:00:01.198948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:01:01.197836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:02:01.177665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:03:01.157591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:04:00.947601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:05:01.737605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:06:01.547642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:07:01.347607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:08:01.207599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:09:01.876860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:10:01.776200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:11:01.737688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:12:01.527689'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:13:01.387786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:14:01.257644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:15:01.368887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:16:01.227727'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:17:00.987570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:18:00.957595'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:19:01.757771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:20:01.537630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:21:01.377724'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:22:01.137615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:23:01.117774'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:24:00.957606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:25:01.757584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:26:01.657628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:27:01.577608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:28:01.597672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:29:01.507622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:30:01.348840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:31:01.247795'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:32:01.167601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:33:01.677630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:34:01.197608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:35:00.987678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:36:01.757578'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:37:01.738082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:38:01.557571'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:39:01.567658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:40:01.377735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:41:01.437647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:42:01.467761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:43:01.317749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:44:01.197626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:45:01.139143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:46:01.377200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:47:00.947685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:48:01.747676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:49:01.557768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:50:01.417703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:51:01.157796'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:52:00.977764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:53:01.787751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:54:01.737777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:55:01.757682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:56:01.527671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:57:01.367685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:58:01.187727'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T07:59:00.997779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:00:01.789311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:01:01.547673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:02:01.337678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:03:01.157736'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:04:00.967764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:05:01.737712'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:06:01.567921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:07:01.577701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:08:01.467781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:09:01.408478'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:10:01.167784'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:11:00.967928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:12:00.937743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:13:01.747684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:14:01.727791'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:15:01.558856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:16:01.357655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:17:01.148796'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:18:00.997778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:19:00.977683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:20:01.757668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:21:00.957655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:22:00.937683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:23:01.727694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:24:01.597672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:25:01.367685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:26:01.197709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:27:00.968964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:28:01.737605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:29:01.597684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:30:01.338915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:31:01.497712'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:32:01.347601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:33:01.207694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:34:01.477687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:35:01.487887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:36:01.387634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:37:01.217611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:38:01.207704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:39:01.157608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:40:01.107831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:41:00.967912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:42:01.747591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:43:01.567590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:44:01.487728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:45:01.378976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:46:01.157820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:47:01.576670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:48:01.475770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:49:00.987728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:50:01.767790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:51:01.557745'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:52:01.387737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:53:01.167667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:54:01.377370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:55:01.777565'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:56:01.747580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:57:01.587751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:58:01.557720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T08:59:01.407570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:00:01.438783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:01:01.507791'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:02:01.377687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:03:01.177642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:04:00.997586'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:05:01.757591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:06:01.567579'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:07:01.357628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:08:01.287628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:09:01.157753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:10:00.967696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:11:01.747715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:12:01.587585'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:13:01.597620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:14:01.358037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:15:01.158766'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:16:00.967674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:17:01.848832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:18:01.737663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:19:01.577573'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:20:01.477628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:21:01.417714'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:22:01.197613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:23:01.137675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:24:00.987601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:25:01.747591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:26:01.587598'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:27:01.587675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:28:01.437680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:29:01.327725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:30:01.158909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:31:01.207865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:32:01.207622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:33:00.957685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:34:01.117665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:35:01.167693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:36:00.957686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:37:01.737864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:38:01.557709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:39:01.447547'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:40:01.327812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:41:01.167588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:42:01.127857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:43:00.997594'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:44:01.727574'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:45:01.549060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:46:01.287562'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:47:01.167675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:48:00.967732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:49:01.747715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:50:01.537669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:51:01.387634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:52:01.187684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:53:01.227719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:54:01.187665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:55:01.177665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:56:00.997626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:57:01.777605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:58:01.757607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T09:59:01.737764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:00:01.558843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:01:01.357628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:02:01.177691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:03:01.792800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:04:01.756200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:05:01.807668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:06:01.757601'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:07:01.787578'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:08:01.587628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:09:01.577586'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:10:01.387646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:11:01.167679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:12:00.957592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:13:01.737673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:14:01.657604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:15:01.578869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:16:01.447568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:17:01.387641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:18:01.207713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:19:01.577639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:20:01.537746'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:21:01.357605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:22:01.157699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:23:00.997609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:24:01.747746'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:25:01.537679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:26:01.327599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:27:01.167684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:28:01.282100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:29:00.937614'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:30:01.738816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:31:01.637566'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:32:01.597625'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:33:01.557621'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:34:01.767588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:35:01.597629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:36:01.577605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:37:01.367602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:38:01.177584'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:39:01.765700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:40:01.737881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:41:01.730019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:42:01.540074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:43:01.370146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:44:01.160267'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:45:01.914200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:46:01.130252'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:47:01.101200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:48:01.750889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:49:01.750061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:50:01.600160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:51:01.540019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:52:01.390634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:53:01.350127'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:54:01.150190'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:55:01.134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:56:00.960028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:57:01.760161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:58:01.580311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T10:59:01.610157'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:00:01.561437'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:01:01.370051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:02:01.120305'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:03:00.950069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:04:01.780054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:05:01.720190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:06:01.660030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:07:01.540023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:08:01.400160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:09:01.300034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:10:01.400142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:11:01.200273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:12:01.190079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:13:01.310190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:14:01.180158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:15:01.131417'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:16:01.300420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:17:00.950162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:18:01.770136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:19:01.550018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:20:01.460058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:21:01.330052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:22:01.170100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:23:01.180043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:24:00.980021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:25:01.770272'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:26:00.990154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:27:00.960170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:28:01.730027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:29:01.580112'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:30:01.351236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:31:01.260140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:32:01.100278'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:33:01.140165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:34:01.140155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:35:01.300230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:36:00.970062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:37:01.790120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:38:01.720039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:39:01.700035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:40:01.670099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:41:01.550031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:42:01.360198'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:43:01.280205'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:44:01.160193'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:45:01.213390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:46:01.740044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:47:01.600181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:48:01.390029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:49:01.180199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:50:01.200067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:51:00.990201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:52:00.960013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:53:00.960023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:54:01.770138'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:55:01.650005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:56:01.550149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:57:01.370021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:58:01.150295'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T11:59:00.980017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:00:01.741406'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:01:01.700019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:02:01.549998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:03:01.400102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:04:01.180052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:05:00.990135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:06:00.950209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:07:00.950085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:08:01.760122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:09:01.699989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:10:01.540156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:11:01.550028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:12:01.350059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:13:01.160199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:14:01.903440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:15:00.971260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:16:01.750099'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:17:02.101640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:18:00.950068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:19:00.999985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:20:01.100360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:21:01.411440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:22:00.940071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:23:01.740070'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:24:01.710046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:25:01.600111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:26:01.370163'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:27:01.150169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:28:00.980031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:29:01.740057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:30:01.591219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:31:01.660140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:32:01.550059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:33:01.430019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:34:01.680044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:35:01.520265'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:36:01.370056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:37:01.220142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:38:00.980047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:39:01.730152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:40:01.600004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:41:01.510158'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:42:01.400002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:43:01.160159'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:44:01.310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:45:01.751624'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:46:01.590027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:47:01.600029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:48:01.580552'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:49:01.430098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:50:01.340173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:51:01.290018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:52:01.170230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:53:00.970069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:54:01.770132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:55:01.810132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:56:01.730169'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:57:01.610044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:58:01.570025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T12:59:01.370186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:00:01.351240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:01:01.340196'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:02:01.180094'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:03:01.650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:04:01.740213'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:05:01.580028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:06:01.370030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:07:01.190383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:08:01.120064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:09:00.950036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:10:01.770215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:11:01.700035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:12:01.550030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:13:01.460111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:14:01.500137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:15:01.561365'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:16:01.360024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:17:01.170079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:18:01.320033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:19:01.180081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:20:01.129200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:21:01.750026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:22:01.590293'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:23:01.370028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:24:01.180056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:25:01.160052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:26:01.801760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:27:00.990863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:28:01.810018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:29:01.760717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:30:01.561186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:31:01.410152'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:32:01.180350'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:33:01.115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:34:01.150102'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:35:01.290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:36:01.760008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:37:01.540017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:38:01.370166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:39:01.320161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:40:01.310093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:41:01.230006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:42:01.180124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:43:00.970176'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:44:01.790610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:45:01.701280'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:46:01.610144'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:47:01.560065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:48:01.370021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:49:01.180319'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:50:01.137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:51:01.759980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:52:01.730031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:53:01.580178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:54:01.550029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:55:01.580437'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:56:01.410190'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:57:01.370048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:58:01.170145'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T13:59:01.191'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:00:01.761234'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:01:01.570062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:02:01.390159'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:03:01.190186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:04:01.203120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:05:01.702750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:06:01.159994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:07:01.160072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:08:01.900870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:09:01.202430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:10:00.950020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:11:01.740285'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:12:01.570340'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:13:01.390043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:14:01.210075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:15:00.981379'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:16:01.740062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:17:01.541107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:18:01.400130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:19:01.340046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:20:01.220021'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:21:01.210179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:22:01.210018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:23:00.960047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:24:01.730146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:25:01.630037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:26:01.760043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:27:01.600131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:28:01.570405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:29:01.360017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:30:01.161266'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:31:01.803160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:32:00.960002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:33:01.730025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:34:00.950003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:35:01.770119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:36:01.740147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:37:01.570107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:38:01.449996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:39:01.390032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:40:01.310074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:41:01.150139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:42:00.970121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:43:00.950048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:44:01.729984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:45:01.551279'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:46:01.400242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:47:01.380235'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:48:01.320870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:49:01.200173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:50:01.130254'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:51:00.940002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:52:00.940166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:53:01.730049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:54:01.590185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:55:01.380004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:56:01.130164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:57:00.960108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:58:01.760128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T14:59:01.529986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:00:01.441242'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:01:01.430030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:02:01.370056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:03:01.180019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:04:01.200310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:05:01.730109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:06:01.690108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:07:01.650102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:08:01.539997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:09:01.430178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:10:01.510109'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:11:01.360131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:12:01.180076'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:13:01.600270'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:14:01.687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:15:01.801331'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:16:01.510044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:17:01.369984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:18:01.340017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:19:01.170074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:20:00.970085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:21:01.749975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:22:01.720008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:23:01.630027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:24:01.530041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:25:01.330015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:26:01.190577'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:27:01.190229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:28:01.160040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:29:00.980117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:30:01.771203'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:31:01.750015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:32:01.560006'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:33:01.560024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:34:01.740149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:35:01.580017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:36:01.390219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:37:01.170110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:38:00.970085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:39:01.760015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:40:01.600053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:41:01.620027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:42:01.520168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:43:01.400061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:44:01.160160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:45:00.971271'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:46:01.740194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:47:01.559999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:48:01.410046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:49:01.280032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:50:01.260065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:51:01.150244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:52:00.990097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:53:01.740381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:54:00.960037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:55:01.750244'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:56:01.530022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:57:01.490164'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:58:01.310013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T15:59:01.130106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:00:01.124500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:01:00.950080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:02:01.750018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:03:01.600010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:04:01.490060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:05:01.410036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:06:01.350153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:07:01.430032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:08:01.340882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:09:01.150067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:10:00.970135'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:11:01.740160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:12:01.550025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:13:01.420119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:14:01.400039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:15:01.151448'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:16:00.970012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:17:01.881181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:18:01.740044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:19:01.559991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:20:01.450018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:21:01.350168'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:22:01.220028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:23:01.110111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:24:01.402940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:25:01.401770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:26:00.950060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:27:01.770067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:28:01.540032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:29:01.340140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:30:01.191243'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:31:01.602520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:32:00.960128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:33:00.980030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:34:01.230173'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:35:01.170857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:36:00.990023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:37:01.720042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:38:01.720055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:39:01.500004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:40:01.350035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:41:01.190039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:42:00.979983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:43:01.740108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:44:01.730014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:45:01.601251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:46:01.430007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:47:01.400051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:48:01.210028'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:49:01.170072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:50:00.970082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:51:00.950250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:52:01.760010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:53:01.729987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:54:01.520274'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:55:01.420139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:56:01.360046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:57:01.150192'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:58:00.960011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T16:59:01.730041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:00:01.591207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:01:01.720059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:02:01.580564'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:03:01.350153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:04:01.140037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:05:00.970089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:06:00.960019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:07:01.750065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:08:01.770090'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:09:01.670023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:10:01.559989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:11:01.370116'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:12:01.160055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:13:01.502260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:14:01.201060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:15:00.991162'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:16:01.749997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:17:01.520150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:18:01.380024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:19:01.160189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:20:00.979987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:21:01.740195'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:22:01.560210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:23:01.340189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:24:01.150408'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:25:00.960020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:26:01.750016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:27:01.590038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:28:01.610174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:29:01.590747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:30:01.341222'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:31:01.250022'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:32:01.150052'</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:33:01.167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:34:01.160023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:35:00.980046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:36:01.740004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:37:01.550036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:38:01.390055'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:39:01.360011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:40:01.180091'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:41:01.160012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:42:01.801510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:43:00.950013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:44:01.760017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:45:01.561237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:46:01.370012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:47:01.160113'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:48:00.960000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:49:01.750023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:50:01.540040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:51:01.380007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:52:01.150268'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:53:00.970004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:54:01.730430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:55:01.750199'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:56:01.740038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:57:01.560147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:58:01.390133'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T17:59:01.390254'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:00:01.181287'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:01:01.140051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:02:01.100100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:03:00.980050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:04:01.700016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:05:01.559990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:06:01.555942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:07:01.435607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:08:01.575853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:09:01.555676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:10:01.385698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:11:01.175698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:12:01.215723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:13:01.155697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:14:00.965658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:15:01.737032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:16:01.585665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:17:01.365752'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:18:01.315698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:19:01.355799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:20:01.185692'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:21:01.159400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:22:00.955668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:23:01.766392'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:24:01.535666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:25:01.355646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:26:01.275705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:27:01.165763'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:28:00.955652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:29:00.945627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:30:01.776865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:31:01.665655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:32:01.566146'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:33:01.395656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:34:01.605658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:35:01.555644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:36:01.445627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:37:01.355745'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:38:01.195874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:39:01.565100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:40:01.755892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:41:01.595737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:42:01.345717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:43:01.165740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:44:01.459870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:45:00.966864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:46:00.975649'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:47:00.995645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:48:01.765632'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:49:01.605698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:50:01.585633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:51:01.415658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:52:01.155666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:53:01.165693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:54:00.945788'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:55:01.745658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:56:01.635715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:57:01.545630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:58:01.375747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T18:59:01.165700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:00:00.987041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:01:00.945652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:02:00.945733'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:03:01.755962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:04:01.585629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:05:01.375807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:06:01.175683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:07:00.985664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:08:00.945817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:09:01.765654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:10:01.785675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:11:01.565637'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:12:01.375661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:13:01.195651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:14:01.195701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:15:01.176981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:16:00.996873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:17:00.935760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:18:01.725643'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:19:01.565882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:20:01.425645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:21:01.385681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:22:01.175779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:23:00.965666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:24:01.765735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:25:01.575777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:26:01.405659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:27:01.285674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:28:01.235860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:29:01.145892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:30:00.976989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:31:01.825649'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:32:01.745871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:33:01.655651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:34:01.745662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:35:01.565753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:36:01.355660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:37:01.375678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:38:01.205662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:39:00.975661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:40:01.765814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:41:01.795624'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:42:01.735973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:43:01.556185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:44:01.405647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:45:01.166916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:46:00.965722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:47:01.745674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:48:01.565691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:49:01.385656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:50:01.716270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:51:01.545839'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:52:01.425783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:53:01.395682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:54:01.355725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:55:01.215664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:56:01.175658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:57:01.415688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:58:01.356174'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T19:59:01.205786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:00:01.196951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:01:01.165705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:02:00.975786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:03:01.115725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:04:01.345579'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:05:01.215690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:06:01.155829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:07:01.406125'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:08:01.325778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:09:01.195697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:10:01.157000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:11:00.945675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:12:01.735674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:13:01.555810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:14:01.395659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:15:01.217063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:16:01.155705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:17:01.157810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:18:00.955732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:19:01.775658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:20:01.755646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:21:01.775631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:22:01.575657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:23:01.416166'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:24:01.205653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:25:01.155698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:26:00.985794'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:27:01.815781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:28:01.725672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:29:01.605770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:30:01.406990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:31:01.425664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:32:01.365632'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:33:01.345657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:34:01.635869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:35:01.585633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:36:01.355694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:37:01.175814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:38:00.996720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:39:00.945657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:40:01.775794'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:41:00.955666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:42:01.755636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:43:01.565648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:44:01.365661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:45:01.346928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:46:01.195817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:47:01.195761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:48:01.175660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:49:00.995929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:50:00.945694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:51:01.785654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:52:01.775651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:53:01.715761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:54:01.585799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:55:01.385629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:56:01.155789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:57:00.975631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:58:00.985654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T20:59:01.755654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:00:01.627044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:01:01.596145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:02:01.375671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:03:01.155781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:04:01.115756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:05:00.945691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:06:01.735656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:07:01.605641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:08:01.355805'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:09:01.155680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:10:00.985656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:11:01.755644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:12:01.615622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:13:01.595754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:14:01.555657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:15:01.366871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:16:01.165717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:17:00.955643'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:18:01.755741'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:19:01.565705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:20:01.365764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:21:01.165682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:22:00.995747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:23:01.745693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:24:01.605754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:25:01.725851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:26:01.735759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:27:01.645674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:28:01.576851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:29:01.355689'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:30:01.166862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:31:01.557030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:32:01.258910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:33:00.955720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:34:00.995764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:35:00.945745'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:36:01.735674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:37:01.575814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:38:01.385655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:39:01.155635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:40:01.155754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:41:01.225650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:42:01.556710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:43:01.156460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:44:00.965755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:45:01.856917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:46:01.735676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:47:01.545750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:48:01.415640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:49:01.355737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:50:01.145690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:51:00.985812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:52:01.565500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:53:01.755802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:54:01.556655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:55:01.395663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:56:01.375655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:57:01.165801'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:58:01.165753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T21:59:00.995665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:00:00.976927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:01:01.755747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:02:01.655826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:03:01.545667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:04:01.365652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:05:01.365659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:06:01.365645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:07:01.235703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:08:01.155777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:09:00.995708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:10:01.745864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:11:01.605682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:12:01.515654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:13:01.385826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:14:01.165755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:15:00.986848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:16:01.735694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:17:01.596258'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:18:01.425749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:19:01.475751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:20:01.455776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:21:01.295668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:22:01.355635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:23:01.175811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:24:00.975780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:25:01.745749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:26:01.565665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:27:01.355719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:28:01.155915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:29:00.955620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:30:01.756950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:31:01.655817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:32:01.585757'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:33:01.445755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:34:01.585624'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:35:01.435667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:36:01.455690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:37:01.325778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:38:01.185774'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:39:00.985654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:40:01.745751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:41:01.735616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:42:01.585744'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:43:01.355651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:44:01.155798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:45:01.368930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:46:01.859760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:47:01.125761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:48:00.985691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:49:01.745765'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:50:01.735786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:51:01.555718'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:52:01.345654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:53:01.185843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:54:00.955640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:55:01.745941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:56:01.585914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:57:01.395667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:58:01.145744'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T22:59:00.975629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:00:00.956836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:01:01.775865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:02:01.575635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:03:01.535740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:04:01.375667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:05:01.145762'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:06:00.985653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:07:01.735777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:08:01.535745'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:09:01.345659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:10:01.185709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:11:00.955708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:12:01.765733'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:13:01.755757'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:14:01.775651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:15:01.746928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:16:01.555790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:17:01.835922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:18:01.755849'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:19:01.535748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:20:01.385651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:21:01.165860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:22:01.564900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:23:01.845663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:24:01.765846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:25:01.745795'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:26:01.755885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:27:00.945686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:28:01.765751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:29:01.575639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:30:01.387071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:31:01.305728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:32:01.205777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:33:01.557440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:34:01.185732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:35:00.975749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:36:01.736048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:37:01.705679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:38:01.555771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:39:01.385662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:40:01.425755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:41:01.406678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:42:01.165697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:43:00.985747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:44:01.735716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:45:01.576902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:46:01.356187'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:47:01.175702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:48:00.965722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:49:01.755918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:50:01.635629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:51:01.575651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:52:01.575636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:53:01.585704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:54:01.705748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:55:01.575675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:56:01.415657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:57:01.305663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:58:01.165930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-26T23:59:00.955732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:00:01.756997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:01:01.605645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:02:01.575667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:03:01.395650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:04:01.175729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:05:01.135895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:06:01.758510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:07:01.106401'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:08:01.116085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:09:00.995663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:10:01.765703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:11:01.745914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:12:01.555639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:13:01.425662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:14:01.355690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:15:01.207029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:16:01.157520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:17:01.756884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:18:01.575659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:19:01.495709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:20:01.415899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:21:01.375671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:22:01.195676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:23:01.581700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:24:01.775631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:25:01.615703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:26:01.555859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:27:01.405743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:28:01.365742'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:29:01.185707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:30:01.968670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:31:01.857100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:32:01.360800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:33:01.165872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:34:01.325671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:35:01.315680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:36:01.175692'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:37:00.995738'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:38:01.796210'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:39:01.705755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:40:01.565761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:41:01.435634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:42:01.425787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:43:01.395958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:44:01.205691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:45:01.176905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:46:01.259390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:47:01.261320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:48:00.975705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:49:01.765938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:50:01.535779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:51:01.415628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:52:01.185769'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:53:00.985731'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:54:01.775720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:55:01.605635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:56:01.535762'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:57:01.385660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:58:01.165822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T00:59:01.358540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:00:01.787059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:01:01.745659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:02:01.555686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:03:01.335835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:04:01.165736'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:05:01.145895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:06:00.985804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:07:01.755647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:08:01.745699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:09:01.555651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:10:01.355653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:11:01.215750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:12:01.195764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:13:01.185777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:14:01.165761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:15:00.976876'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:16:01.775659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:17:01.766189'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:18:01.585800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:19:01.415660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:20:01.175658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:21:00.955704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:22:01.358390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:23:01.735790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:24:01.555697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:25:01.335642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:26:01.195668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:27:01.175780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:28:01.857650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:29:00.985705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:30:01.748128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:31:01.635638'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:32:01.565954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:33:01.425682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:34:01.555664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:35:01.365670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:36:01.175722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:37:01.115942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:38:01.156660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:39:00.935653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:40:00.955655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:41:00.955647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:42:01.755654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:43:01.605791'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:44:01.375682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:45:01.167107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:46:00.995770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:47:01.765751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:48:01.725635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:49:01.545794'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:50:01.355913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:51:01.165766'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:52:01.356860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:53:01.568650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:54:00.995658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:55:00.945702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:56:00.945807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:57:01.765649'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:58:01.705697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T01:59:01.545922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:00:01.387010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:01:01.175797'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:02:00.985700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:03:01.765751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:04:01.735686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:05:01.555656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:06:01.545744'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:07:01.515702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:08:01.485682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:09:01.465802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:10:01.385633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:11:01.155768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:12:00.985639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:13:01.755657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:14:01.575850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:15:01.386838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:16:01.205718'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:17:00.975802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:18:01.735674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:19:01.735693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:20:01.805682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:21:01.795682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:22:01.756410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:23:01.525678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:24:01.375791'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:25:01.185753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:26:00.995707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:27:01.755721'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:28:01.545941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:29:01.385657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:30:01.316905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:31:01.245968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:32:01.175868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:33:01.335941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:34:01.505675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:35:01.335947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:36:01.425760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:37:01.327579'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:38:01.155749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:39:00.965771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:40:01.755679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:41:01.545700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:42:01.395691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:43:01.325694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:44:01.175780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:45:01.168820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:46:01.755671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:47:01.735798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:48:01.585869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:49:01.355771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:50:01.285696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:51:01.155676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:52:01.157110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:53:01.755816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:54:01.535774'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:55:01.385697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:56:01.195755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:57:01.165725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:58:00.995685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T02:59:01.775651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:00:00.947246'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:01:01.765720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:02:01.565651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:03:01.415753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:04:01.515658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:05:01.355727'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:06:01.175795'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:07:01.145813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:08:00.965735'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:09:01.755676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:10:01.555697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:11:01.385966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:12:01.175766'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:13:01.255772'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:14:01.165820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:15:00.986856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:16:01.785665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:17:01.576874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:18:01.385713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:19:01.235738'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:20:01.155796'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:21:01.166150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:22:01.735743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:23:01.605668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:24:01.375812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:25:01.155767'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:26:01.357510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:27:01.155720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:28:01.758770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:29:00.955659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:30:01.746989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:31:01.825712'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:32:01.745679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:33:01.565851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:34:01.736303'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:35:01.555630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:36:01.355669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:37:01.195753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:38:01.577200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:39:01.785685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:40:01.735881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:41:01.665644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:42:01.545660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:43:01.387755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:44:01.137688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:45:00.978915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:46:01.747688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:47:01.737619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:48:01.527621'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:49:01.417579'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:50:01.137742'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:51:00.967675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:52:01.727701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:53:01.627622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:54:01.647610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:55:01.557734'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:56:01.407622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:57:01.167821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:58:00.947614'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T03:59:01.757635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:00:01.578857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:01:01.517609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:02:01.357630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:03:01.147642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:04:01.978510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:05:00.987612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:06:01.767589'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:07:01.637623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:08:01.597667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:09:01.347702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:10:01.197694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:11:00.987725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:12:01.727651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:13:01.547747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:14:01.427640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:15:01.308802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:16:01.167720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:17:00.997527'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:18:00.947852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:19:01.757608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:20:01.777637'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:21:01.737646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:22:01.577791'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:23:01.507618'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:24:01.487639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:25:01.357728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:26:01.147781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:27:00.957722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:28:00.947621'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:29:01.747633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:30:01.568999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:31:01.457633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:32:01.327764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:33:01.167824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:34:01.447695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:35:01.418273'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:36:01.127757'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:37:00.978100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:38:01.727595'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:39:01.537711'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:40:01.367652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:41:01.187648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:42:00.977605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:43:01.757641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:44:01.557707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:45:01.348916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:46:01.147896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:47:01.760700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:48:01.378730'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:49:00.947608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:50:01.747616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:51:01.617701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:52:01.577615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:53:01.477763'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:54:01.367683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:55:01.187820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:56:00.977623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:57:01.737606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:58:01.597680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T04:59:01.367629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:00:01.218851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:01:01.157822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:02:01.765700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:03:01.737607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:04:01.567746'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:05:01.417631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:06:01.157753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:07:00.987631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:08:01.747772'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:09:01.547605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:10:01.387903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:11:01.127726'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:12:00.977620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:13:01.757704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:14:01.667598'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:15:01.698824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:16:01.567596'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:17:01.448954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:18:01.307577'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:19:01.177684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:20:01.176970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:21:01.727704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:22:01.597549'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:23:01.557615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:24:01.397705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:25:01.337693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:26:01.177640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:27:01.578590'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:28:01.678580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:29:01.178390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:30:01.748814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:31:01.637609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:32:01.527593'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:33:01.387706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:34:01.507591'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:35:01.357693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:36:01.227633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:37:00.937608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:38:01.727645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:39:01.527611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:40:01.457653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:41:01.317860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:42:01.197626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:43:00.967616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:44:01.737614'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:45:01.549083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:46:01.367918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:47:01.167702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:48:01.177627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:49:01.317688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:50:01.187611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:51:00.987586'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:52:01.797632'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:53:01.587720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:54:01.587783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:55:01.457792'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:56:01.387610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:57:01.167720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:58:01.760500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T05:59:01.727697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:00:01.558808'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:01:01.417622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:02:01.197648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:03:01.378860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:04:00.957604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:05:00.957615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:06:01.737722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:07:01.577608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:08:01.687632'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:09:01.598349'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:10:01.377712'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:11:01.167694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:12:00.947787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:13:01.757722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:14:01.527707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:15:01.378990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:16:01.157634'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:17:00.967605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:18:01.757613'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:19:01.697633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:20:01.557616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:21:01.587592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:22:01.557815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:23:01.367645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:24:01.187828'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:25:00.987622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:26:00.947605'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:27:01.747611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:28:01.557602'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:29:01.397723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:30:01.299012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:31:01.177704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:32:01.137666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:33:00.957603'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:34:01.137653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:35:01.197779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:36:01.137715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:37:00.947622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:38:01.727816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:39:01.577714'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:40:01.577674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:41:01.417990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:42:01.167665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:43:00.987607'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:44:01.727661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:45:01.548880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:46:01.397703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:47:01.228666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:48:01.287875'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:49:01.147699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:50:00.977611'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:51:01.727874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:52:01.557730'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:53:01.417780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:54:01.147631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:55:00.977728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:56:01.737681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:57:01.767599'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:58:01.737657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T06:59:01.557666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:00:01.508865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:01:01.427754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:02:01.357612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:03:01.297542'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:04:01.147699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:05:00.987705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:06:01.747603'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:07:01.557668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:08:01.367587'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:09:01.147707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:10:01.176420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:11:01.737609'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:12:01.547663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:13:01.387686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:14:01.377780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:15:01.299048'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:16:01.187827'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:17:00.987636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:18:01.767656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:19:01.727681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:20:01.597844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:21:01.507827'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:22:01.337642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:23:01.217718'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:24:01.147795'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:25:01.177100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:26:00.957673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:27:01.727660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:28:01.687703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:29:01.607939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:30:01.508950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:31:01.427695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:32:01.317663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:33:01.167959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:34:01.337854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:35:01.157714'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:36:00.997845'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:37:01.767969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:38:01.537661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:39:01.367755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:40:01.417717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:41:01.357977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:42:01.177697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:43:00.967948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:44:00.947829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:45:01.778913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:46:01.597696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:47:01.437679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:48:01.387799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:49:01.157775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:50:00.987888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:51:01.737653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:52:01.557793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:53:01.397756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:54:01.267806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:55:01.167834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:56:00.987957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:57:01.747648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:58:01.537925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T07:59:01.427633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:00:01.378953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:01:01.207658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:02:01.765800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:03:01.737842'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:04:01.757893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:05:01.687800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:06:01.547647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:07:01.577763'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:08:01.577650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:09:01.417845'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:10:01.177821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:11:01.777700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:12:00.977732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:13:01.767643'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:14:01.667728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:15:01.598922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:16:01.477806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:17:01.438568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:18:01.397648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:19:01.137937'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:20:00.977806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:21:01.764900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:22:00.967635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:23:01.747902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:24:01.617670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:25:01.547947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:26:01.447778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:27:01.347934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:28:01.147954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:29:00.987680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:30:01.739030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:31:01.747904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:32:01.597667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:33:01.527653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:34:01.837739'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:35:00.967885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:36:01.747676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:37:01.557670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:38:01.407653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:39:01.167798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:40:00.957648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:41:01.807675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:42:01.547633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:43:01.387699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:44:01.147867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:45:01.901200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:46:01.737767'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:47:01.657698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:48:01.697707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:49:01.557626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:50:01.397709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:51:01.197679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:52:01.167798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:53:00.987671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:54:01.737669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:55:01.617698'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:56:01.447704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:57:01.337716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:58:01.187756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T08:59:01.477500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:00:01.490250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:01:00.947662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:02:00.947657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:03:01.747680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:04:01.548020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:05:01.427796'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:06:01.347749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:07:01.307659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:08:01.177750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:09:01.768600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:10:01.737716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:11:01.537651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:12:01.537644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:13:01.407731'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:14:01.227670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:15:01.428870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:16:01.317777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:17:01.157691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:18:01.147788'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:19:00.967749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:20:01.747924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:21:01.567740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:22:01.437797'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:23:01.347782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:24:01.217745'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:25:01.237932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:26:01.177695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:27:01.278450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:28:01.167723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:29:01.127728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:30:00.948962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:31:01.817676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:32:01.787703'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:33:01.557666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:34:01.727818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:35:01.717889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:36:01.587719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:37:01.387726'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:38:01.167690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:39:01.147737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:40:01.780000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:41:01.832600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:42:01.767711'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:43:01.547658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:44:01.407960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:45:01.368880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:46:01.177757'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:47:00.947678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:48:01.737776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:49:01.557770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:50:01.397758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:51:01.147759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:52:01.578250'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:53:00.999065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:54:01.777701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:55:01.597940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:56:01.357676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:57:01.157655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:58:00.967653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T09:59:00.947675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:00:01.759053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:01:01.557678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:02:01.427784'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:03:01.367638'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:04:01.157661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:05:00.947739'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:06:01.787906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:07:01.757647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:08:01.707813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:09:01.657636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:10:01.527660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:11:01.357719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:12:01.137718'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:13:00.977662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:14:01.737648'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:15:01.548866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:16:01.337649'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:17:01.227784'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:18:01.157764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:19:01.578620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:20:01.779170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:21:00.998236'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:22:00.967633'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:23:01.747644'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:24:01.597758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:25:01.577568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:26:01.587776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:27:01.547676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:28:01.337709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:29:01.157650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:30:00.958891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:31:01.807667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:32:01.738442'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:33:01.767654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:34:01.778850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:35:00.957623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:36:01.747629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:37:01.547940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:38:01.357720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:39:01.167799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:40:01.478340'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:41:00.957727'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:42:01.767671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:43:01.737723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:44:01.657654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:45:01.538923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:46:01.477687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:47:01.478057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:48:01.377700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:49:01.207672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:50:01.287911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:51:01.157712'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:52:01.177290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:53:01.777768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:54:01.597680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:55:01.497783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:56:01.357752'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:57:01.177908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:58:00.987681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T10:59:00.947687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:00:01.768895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:01:01.597673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:02:01.497742'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:03:01.457694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:04:01.297721'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:05:01.177779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:06:01.577520'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:07:00.967651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:08:01.737676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:09:01.577776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:10:01.407819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:11:01.337993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:12:01.237716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:13:01.197818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:14:01.207950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:15:01.158952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:16:00.977758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:17:01.818851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:18:01.547786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:19:01.347654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:20:01.177782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:21:00.977672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:22:01.697806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:23:01.527775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:24:01.417641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:25:01.177821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:26:01.107850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:27:01.277170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:28:00.957716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:29:01.747719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:30:01.548892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:31:01.467801'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:32:01.327636'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:33:01.157756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:34:01.307810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:35:01.187724'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:36:01.777500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:37:00.957938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:38:01.777656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:39:01.727686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:40:01.737728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:41:01.537673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:42:01.387747'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:43:01.157943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:44:00.947666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:45:01.728820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:46:01.607680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:47:01.517661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:48:01.367811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:49:01.137713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:50:00.957688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:51:01.737681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:52:01.627673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:53:01.657782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:54:01.717678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:55:01.537771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:56:01.397685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:57:01.177717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:58:00.967662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T11:59:01.767664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:00:01.559058'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:01:01.387656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:02:01.177758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:03:00.947751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:04:00.967667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:05:01.747697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:06:01.597793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:07:01.557891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:08:01.367683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:09:01.187826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:10:01.176510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:11:00.957686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:12:01.737708'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:13:01.557767'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:14:01.397840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:15:01.168926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:16:00.977792'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:17:01.757723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:18:01.587669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:19:01.537778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:20:01.497701'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:21:01.397786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:22:01.187686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:23:00.967820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:24:01.747687'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:25:01.577801'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:26:01.377772'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:27:01.137807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:28:00.957709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:29:01.737768'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:30:01.539079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:31:01.527657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:32:01.407695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:33:01.247743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:34:01.448037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:35:01.367756'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:36:01.167775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:37:01.767700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:38:01.767750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:39:01.547643'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:40:01.397762'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:41:01.247645'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:42:01.127934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:43:00.947655'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:44:01.737656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:45:01.598980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:46:01.577669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:47:01.487831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:48:01.427863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:49:01.397802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:50:01.168139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:51:00.977680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:52:01.757778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:53:01.567803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:54:01.327700'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:55:01.297658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:56:01.157819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:57:00.957754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:58:01.747821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T12:59:01.577635'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:00:01.569011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:01:01.568557'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:02:01.507779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:03:01.367782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:04:01.197665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:05:01.217989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:06:01.158129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:07:00.987740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:08:01.737786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:09:01.577647'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:10:01.347825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:11:01.167690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:12:01.179440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:13:01.179230'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:14:00.977892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:15:01.729404'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:16:01.577682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:17:01.468984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:18:01.397626'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:19:01.207798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:20:01.147992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:21:00.977668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:22:01.727845'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:23:01.567653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:24:01.407667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:25:01.187683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:26:01.778080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:27:00.957652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:28:01.728841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:29:01.707671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:30:01.548896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:31:01.427809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:32:01.377806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:33:01.157697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:34:01.327733'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:35:01.197682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:36:01.107691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:37:00.967672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:38:01.727723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:39:01.777767'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:40:01.777800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:41:01.547890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:42:01.387917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:43:01.157672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:44:00.957720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:45:01.748991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:46:01.727717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:47:01.567699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:48:01.437639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:49:01.327688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:50:01.157719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:51:01.117870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:52:01.107680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:53:01.784000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:54:00.947678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:55:01.737819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:56:01.537670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:57:01.347646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:58:01.157685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T13:59:00.997923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:00:01.748947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:01:01.577774'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:02:01.367663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:03:01.187682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:04:01.779570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:05:00.987750'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:06:00.967674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:07:01.777709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:08:01.577746'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:09:01.437652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:10:01.397684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:11:01.197815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:12:00.987900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:13:01.777950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:14:01.547660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:15:01.388889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:16:01.187651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:17:00.987790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:18:01.777761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:19:01.747649'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:20:01.777775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:21:01.727800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:22:01.557729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:23:01.397657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:24:01.167722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:25:00.967676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:26:01.747667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:27:01.647693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:28:01.507833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:29:01.397783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:30:01.198901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:31:01.217682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:32:00.967729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:33:00.967661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:34:01.227716'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:35:00.957661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:36:01.847841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:37:01.737641'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:38:01.557638'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:39:01.407802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:40:01.337688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:41:01.177670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:42:00.967823'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:43:01.777661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:44:01.567815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:45:01.418906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:46:01.178037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:47:01.147793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:48:00.987680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:49:01.767822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:50:01.737670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:51:01.567758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:52:01.427674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:53:01.447666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:54:01.327771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:55:01.287734'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:56:01.157787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:57:01.157874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:58:00.947699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T14:59:00.947682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:00:00.958886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:01:01.677663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:02:01.557693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:03:01.367782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:04:01.387901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:05:01.137860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:06:00.957713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:07:01.757657'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:08:01.557818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:09:01.397799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:10:01.287807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:11:01.147726'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:12:01.677810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:13:01.107887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:14:01.167926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:15:00.998966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:16:01.737697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:17:01.589033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:18:01.327682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:19:01.187812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:20:01.978630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:21:01.377150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:22:00.977674'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:23:01.737688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:24:01.547934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:25:01.387797'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:26:01.297718'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:27:01.197709'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:28:00.957755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:29:01.767714'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:30:01.568843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:31:01.477821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:32:01.367738'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:33:01.147787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:34:01.167697'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:35:01.279770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:36:01.737693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:37:01.537660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:38:01.307726'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:39:01.237723'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:40:01.298136'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:41:01.148097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:42:01.765900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:43:01.737902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:44:01.547951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:45:01.349033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:46:01.267813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:47:01.197792'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:48:01.277170'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:49:00.957662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:50:01.737804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:51:01.517759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:52:01.427751'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:53:01.437706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:54:01.447925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:55:01.357642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:56:01.187717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:57:00.967679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:58:00.937666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T15:59:01.787787'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:00:01.748998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:01:01.597748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:02:01.377642'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:03:01.177761'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:04:00.947802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:05:00.977801'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:06:01.767841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:07:01.757741'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:08:01.667850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:09:01.517656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:10:01.407817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:11:01.347836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:12:01.197720'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:13:00.987663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:14:00.968002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:15:01.758919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:16:01.717650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:17:01.597664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:18:01.577683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:19:01.427742'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:20:01.337827'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:21:01.157755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:22:00.977927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:23:01.737802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:24:01.587748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:25:01.537830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:26:01.387749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:27:01.197775'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:28:00.967900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:29:01.727673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:30:01.588883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:31:01.568305'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:32:01.437682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:33:01.417803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:34:01.417653'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:35:01.277826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:36:01.157864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:37:00.978470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:38:01.737677'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:39:01.607628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:40:01.357918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:41:01.167741'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:42:00.987688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:43:01.747748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:44:01.557760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:45:01.538993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:46:01.537702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:47:01.377665'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:48:01.187778'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:49:00.987732'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:50:01.737676'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:51:01.567862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:52:01.377680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:53:01.167783'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:54:00.957706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:55:01.727820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:56:01.527765'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:57:01.347825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:58:01.197824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T16:59:01.337748'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:00:01.178874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:01:00.987743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:02:01.378540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:03:01.757681'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:04:01.687803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:05:01.587615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:06:01.577663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:07:01.407669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:08:01.137707'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:09:00.997686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:10:00.987849'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:11:01.727666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:12:01.757664'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:13:01.727782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:14:01.480260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:15:01.891680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:16:01.128444'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:17:00.987631'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:18:01.747679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:19:01.547651'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:20:01.377675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:21:01.117829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:22:01.387610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:23:00.957628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:24:01.717771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:25:01.707793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:26:01.777663'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:27:01.757604'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:28:01.557659'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:29:01.387896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:30:01.188895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:31:01.137713'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:32:00.967654'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:33:01.767656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:34:00.977740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:35:01.797755'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:36:01.547832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:37:01.377675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:38:01.147656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:39:01.147754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:40:01.478640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:41:00.947706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:42:01.767705'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:43:01.557667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:44:01.357729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:45:01.148939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:46:00.947662'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:47:01.747831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:48:01.557652'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:49:01.407673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:50:01.177699'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:51:00.997758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:52:00.967689'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:53:01.117757'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:54:00.967692'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:55:01.747679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:56:01.747680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:57:01.537804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:58:01.397753'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T17:59:01.187769'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:00:00.989383'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:01:01.727822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:02:01.597682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:03:01.387912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:04:01.177688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:05:01.157770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:06:01.977330'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:07:00.977666'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:08:01.747777'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:09:01.557693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:10:01.407823'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:11:01.177831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:12:01.782800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:13:01.747847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:14:01.627810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:15:01.488900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:16:01.407743'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:17:01.137754'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:18:01.227696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:19:01.287740'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:20:01.167759'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:21:00.967737'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:22:01.747715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:23:01.637690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:24:01.548455'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:25:01.407784'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:26:01.377781'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:27:01.177794'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:28:00.977835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:29:01.747832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:30:01.658840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:31:01.587684'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:32:01.557685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:33:01.397694'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:34:01.497675'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:35:01.357764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:36:01.227725'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:37:00.997841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:38:01.768496'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:39:01.567669'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:40:01.577722'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:41:01.397834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:42:01.177932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:43:00.987922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:44:01.737696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:45:01.578939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:46:01.617619'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:47:01.437715'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:48:01.277734'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:49:01.157872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:50:00.977702'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:51:01.747696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:52:01.557710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:53:01.417661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:54:01.167973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:55:00.977852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:56:01.727673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:57:01.677682'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:58:01.597760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T18:59:01.567760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:00:01.359103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:01:01.158123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:02:00.997679'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:03:01.767670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:04:01.757794'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:05:01.537691'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:06:01.357764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:07:01.298023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:08:01.137841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:09:00.947671'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:10:01.727660'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:11:01.577730'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:12:01.567690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:13:01.557994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:14:01.357673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:15:01.209036'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:16:01.167802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:17:01.979000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:18:00.977688'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:19:01.727758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:20:01.637706'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:21:01.497673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:22:01.367683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:23:01.197717'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:24:01.197721'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:25:01.207749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:26:01.197806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:27:01.197863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:28:00.987928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:29:01.747805'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:30:01.598877'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:31:01.597677'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:32:01.377686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:33:01.167772'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:34:01.297673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:35:01.137858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:36:00.997749'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:37:00.998209'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:38:00.957854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:39:01.769000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:40:01.768488'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:41:01.557685'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:42:01.428094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:43:01.387693'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:44:01.367773'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:45:01.179027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:46:01.177060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:47:01.737807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:48:01.587789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:49:01.377797'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:50:01.157807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:51:01.137771'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:52:01.187721'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:53:01.147832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:54:01.117792'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:55:00.957628'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:56:01.737827'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:57:01.597790'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:58:01.347782'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T19:59:01.167821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:00:00.998894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:01:01.737773'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:02:01.617658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:03:01.507829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:04:01.398886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:05:01.427795'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:06:01.297758'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:07:01.167840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:08:01.117752'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:09:00.987689'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:10:01.787766'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:11:01.777696'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:12:01.587678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:13:01.387678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:14:01.167888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:15:00.999247'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:16:01.758004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:17:01.607661'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:18:01.727672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:19:01.607667'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:20:01.587658'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:21:01.447806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:22:01.317764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:23:01.167882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:24:00.967672'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:25:01.747670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:26:01.537692'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:27:01.367825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:28:01.167802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:29:00.947819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:30:01.738850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:31:01.787765'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:32:01.807673'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:33:01.737986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:34:01.737695'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:35:01.517773'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:36:01.357719'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:37:01.148580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:38:00.958366'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:39:01.738377'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:40:01.578543'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:41:01.428406'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:42:01.378905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:43:01.148493'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:44:01.184430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:45:01.296680'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:46:01.738468'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:47:01.548509'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:48:01.438373'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:49:01.278405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:50:01.178491'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:51:01.183840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:52:01.738389'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:53:01.568479'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:54:01.398512'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:55:01.338379'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:56:01.138623'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:57:01.383960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:58:01.138612'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T20:59:00.978474'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:00:01.729606'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:01:01.548388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:02:01.578370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:03:01.418370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:04:01.168405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:05:00.948402'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:06:01.768401'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:07:01.548363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:08:01.348474'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:09:01.278492'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:10:01.148508'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:11:01.836600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:12:01.484100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:13:00.988440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:14:01.738354'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:15:01.639608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:16:01.538473'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:17:01.369425'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:18:01.158408'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:19:00.968382'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:20:01.768403'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:21:01.548530'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:22:01.398646'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:23:01.178588'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:24:01.500440'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:25:01.292780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:26:00.978544'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:27:00.948451'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:28:01.738471'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:29:01.738554'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:30:01.549608'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:31:01.468466'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:32:01.438505'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:33:01.318417'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:34:01.528310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:35:01.318543'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:36:01.368476'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:37:01.148497'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:38:01.158470'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:39:01.198494'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:40:00.978360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:41:01.778379'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:42:01.528396'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:43:01.358332'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:44:01.158417'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:45:00.979683'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:46:01.738390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:47:01.598462'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:48:01.408381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:49:01.288381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:50:01.148362'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:51:01.108483'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:52:01.148403'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:53:01.138488'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:54:00.948387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:55:01.738789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:56:01.558472'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:57:01.368386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:58:01.198562'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T21:59:01.208550'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:00:00.999592'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:01:01.748556'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:02:01.588352'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:03:01.478504'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:04:01.448515'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:05:01.548507'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:06:01.488394'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:07:01.358562'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:08:01.168503'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:09:01.118627'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:10:00.988387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:11:00.948728'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:12:01.738410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:13:01.688594'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:14:01.508610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:15:01.319581'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:16:01.168544'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:17:01.385510'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:18:01.148616'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:19:00.988356'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:20:01.838200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:21:01.758480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:22:01.628948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:23:01.558363'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:24:01.408377'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:25:01.188547'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:26:00.978374'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:27:00.948515'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:28:01.738317'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:29:01.598457'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:30:01.589615'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:31:01.518468'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:32:01.528371'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:33:01.428419'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:34:01.568386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:35:01.348375'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:36:01.298467'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:37:01.178489'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:38:00.998524'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:39:01.748443'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:40:01.748462'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:41:01.548515'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:42:01.348367'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:43:01.168473'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:44:01.208678'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:45:01.997840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:46:00.968360'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:47:01.738476'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:48:01.548356'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:49:01.418370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:50:01.238668'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:51:01.138415'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:52:00.978436'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:53:01.798486'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:54:01.728481'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:55:01.538441'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:56:01.388435'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:57:01.318387'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:58:01.168370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T22:59:01.386200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:00:00.949639'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:01:01.748463'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:02:01.588402'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:03:01.578357'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:04:01.528555'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:05:01.378345'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:06:01.198391'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:07:01.389900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:08:00.958375'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:09:01.738451'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:10:01.558380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:11:01.498535'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:12:01.358385'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:13:01.158443'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:14:00.968355'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:15:01.739784'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:16:01.568377'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:17:01.609656'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:18:01.358407'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:19:01.168381'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:20:00.968425'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:21:01.748409'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:22:01.588371'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:23:01.368390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:24:01.388412'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:25:01.298487'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:26:01.178483'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:27:01.108505'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:28:00.988541'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:29:01.728534'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:30:01.549704'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:31:01.438393'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:32:01.298507'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:33:01.108565'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:34:01.168571'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:35:00.948353'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:36:01.728570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:37:01.618369'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:38:01.598469'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:39:01.539145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:40:01.358392'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:41:01.348491'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:42:01.168351'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:43:01.386640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:44:01.768388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:45:01.549629'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:46:01.348622'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:47:01.168405'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:48:00.988518'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:49:01.728516'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:50:01.608380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:51:01.668359'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:52:01.568524'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:53:01.358438'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:54:01.158485'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:55:00.968380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:56:01.728466'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:57:01.528395'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:58:01.388385'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-27T23:59:01.168402'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:00:00.959686'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:01:01.738568'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:02:01.588368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:03:01.408580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:04:01.438378'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:05:01.418563'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:06:01.168480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:07:00.978486'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:08:00.968386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:09:01.738415'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:10:01.518420'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:11:01.368477'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:12:01.158529'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:13:01.285890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:14:00.988572'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:15:00.959576'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:16:01.728368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:17:01.728415'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:18:01.718368'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:19:01.528516'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:20:01.378490'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:21:01.258483'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:22:01.118620'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:23:00.968373'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:24:01.738451'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:25:01.548353'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:26:01.418426'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:27:01.158447'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:28:01.109965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:29:00.948379'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:30:01.769729'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:31:01.858403'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:32:01.788388'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:33:01.698450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:34:01.738350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:35:01.578455'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:36:01.362863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:37:01.153015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:38:01.427930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:39:01.290100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:40:01.762913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:41:01.742833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:42:01.572962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:43:01.372867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:44:01.183040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:45:01.224130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:46:01.132981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:47:00.992887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:48:01.128120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:49:01.722914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:50:01.562964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:51:01.342912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:52:01.153088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:53:00.982834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:54:01.742840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:55:01.742818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:56:01.542812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:57:01.342918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:58:01.342906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T00:59:01.172925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:00:01.423000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:01:00.952900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:02:01.762882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:03:01.563044'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:04:01.392939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:05:01.172924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:06:01.228270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:07:00.952806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:08:01.752808'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:09:01.682799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:10:01.572836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:11:01.462830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:12:01.542824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:13:01.372911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:14:01.203459'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:15:01.154009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:16:00.962786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:17:01.962974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:18:01.732802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:19:01.712830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:20:01.562813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:21:01.362888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:22:01.162847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:23:01.532370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:24:01.628910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:25:00.982932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:26:01.742936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:27:01.542986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:28:01.402831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:29:01.192926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:30:01.164121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:31:01.328050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:32:01.792789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:33:01.562964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:34:01.742928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:35:01.533132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:36:01.543111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:37:01.412815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:38:01.222841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:39:01.233067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:40:01.132935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:41:00.962952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:42:01.732915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:43:01.512914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:44:01.342836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:45:01.164139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:46:00.982927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:47:01.752831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:48:01.563061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:49:01.462987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:50:01.352815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:51:01.362914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:52:01.402960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:53:01.352939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:54:01.182869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:55:00.962835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:56:01.732931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:57:01.562805'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:58:01.362835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T01:59:01.292831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:00:01.184284'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:01:00.992804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:02:01.722969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:03:01.572831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:04:01.462824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:05:01.412854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:06:01.232843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:07:01.112943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:08:00.982798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:09:01.752956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:10:01.582817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:11:01.422958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:12:01.352850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:13:01.312861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:14:01.172846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:15:00.964061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:16:01.772941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:17:01.553082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:18:01.612837'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:19:01.583030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:20:01.352914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:21:01.172929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:22:00.962811'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:23:01.752920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:24:01.572872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:25:01.552797'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:26:01.322825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:27:01.192889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:28:00.972799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:29:01.722846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:30:01.573993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:31:01.582814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:32:01.562810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:33:01.412938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:34:01.592786'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:35:01.492851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:36:01.392853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:37:01.182952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:38:00.992872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:39:01.752816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:40:01.552952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:41:01.362812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:42:01.152954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:43:01.279400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:44:01.762780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:45:01.694106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:46:01.552819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:47:01.542956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:48:01.402965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:49:01.152868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:50:01.172831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:51:01.132300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:52:00.962809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:53:01.742823'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:54:01.562822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:55:01.362908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:56:01.172883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:57:00.992815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:58:00.962769'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T02:59:01.772865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:00:01.683993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:01:01.603301'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:02:01.542852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:03:01.372809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:04:01.152869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:05:00.972897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:06:01.752762'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:07:01.532896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:08:01.342816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:09:01.182821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:10:00.982813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:11:00.962859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:12:01.802841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:13:01.733179'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:14:01.572776'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:15:01.404004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:16:01.152921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:17:00.993062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:18:01.240610'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:19:00.952851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:20:01.742820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:21:01.602817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:22:01.552814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:23:01.422813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:24:01.602852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:25:01.702808'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:26:01.563147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:27:01.522924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:28:01.422896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:29:01.352796'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:30:01.193993'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:31:01.730800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:32:00.992916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:33:01.752798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:34:00.962859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:35:01.742812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:36:01.582903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:37:01.342942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:38:01.322831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:39:01.322880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:40:01.192985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:41:00.983033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:42:01.732839'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:43:01.582947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:44:01.392986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:45:01.154078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:46:00.993038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:47:01.752810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:48:01.522834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:49:01.352843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:50:01.172764'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:51:01.139060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:52:01.762814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:53:01.742987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:54:01.603107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:55:01.552807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:56:01.392807'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:57:01.162892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:58:00.972912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T03:59:01.752938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:00:01.533992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:01:01.372915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:02:01.192830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:03:00.992915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:04:01.772833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:05:01.752820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:06:01.782857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:07:01.812822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:08:01.702929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:09:01.552793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:10:01.352906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:11:01.222825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:12:01.829080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:13:00.962793'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:14:01.742812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:15:01.594039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:16:01.552815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:17:01.492858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:18:01.512918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:19:01.412838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:20:01.372978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:21:01.312948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:22:01.163087'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:23:01.428460'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:24:01.228130'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:25:01.752817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:26:01.723030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:27:00.952824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:28:01.752846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:29:01.682809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:30:01.564178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:31:01.462976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:32:01.452974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:33:01.472948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:34:01.562990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:35:01.342809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:36:01.322817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:37:01.182948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:38:01.182967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:39:01.228010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:40:01.742967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:41:01.532927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:42:01.402805'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:43:01.192938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:44:00.972822'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:45:01.240710'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:46:01.529810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:47:00.953080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:48:01.752957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:49:01.742804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:50:01.562873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:51:01.442904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:52:01.302946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:53:01.162927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:54:00.972892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:55:00.962825'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:56:01.753052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:57:01.602960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:58:01.412831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T04:59:01.372976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:00:01.294016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:01:01.183075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:02:00.982940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:03:01.762802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:04:01.592849'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:05:01.452915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:06:01.402843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:07:01.182924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:08:01.173004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:09:00.972921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:10:01.742950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:11:01.543083'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:12:01.472939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:13:01.402885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:14:01.362812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:15:01.154237'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:16:00.972945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:17:01.743972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:18:01.562950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:19:01.362823'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:20:01.152969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:21:00.972922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:22:01.762929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:23:01.572935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:24:01.382835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:25:01.232852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:26:01.332779'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:27:01.172968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:28:00.992816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:29:01.732876'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:30:01.593997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:31:01.472967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:32:01.362934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:33:01.142953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:34:01.322798'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:35:01.143057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:36:00.952936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:37:01.762851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:38:01.542973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:39:01.612829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:40:01.702823'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:41:01.552864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:42:01.432818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:43:01.362925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:44:01.202952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:45:00.974175'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:46:01.763059'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:47:01.552834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:48:01.402789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:49:01.312864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:50:01.173105'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:51:01.128270'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:52:01.742930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:53:01.762892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:54:01.612885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:55:01.502920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:56:01.562838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:57:01.432865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:58:01.322806'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T05:59:01.202863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:00:01.124039'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:01:00.963054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:02:01.742844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:03:01.572868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:04:01.382814'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:05:01.152951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:06:01.192885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:07:01.152902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:08:00.992866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:09:01.742832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:10:01.552809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:11:01.402829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:12:01.182840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:13:00.963037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:14:01.763029'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:15:01.574015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:16:01.422864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:17:01.382830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:18:01.222922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:19:01.342976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:20:01.532983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:21:01.402925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:22:01.192926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:23:01.299000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:24:01.733172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:25:01.543998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:26:01.332840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:27:01.342810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:28:01.172952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:29:00.982871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:30:01.764047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:31:01.682970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:32:01.582821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:33:01.522936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:34:01.582809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:35:01.342843'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:36:01.152970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:37:01.288800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:38:01.732848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:39:01.562810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:40:01.482905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:41:01.382956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:42:01.182911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:43:00.982883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:44:00.992922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:45:00.994139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:46:00.953093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:47:01.182882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:48:01.133008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:49:00.953095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:50:01.752907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:51:01.572919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:52:01.372816'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:53:01.152932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:54:01.133100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:55:00.953094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:56:01.713096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:57:01.573853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:58:01.482826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T06:59:01.542809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:00:01.364043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:01:01.202934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:02:00.992928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:03:01.732964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:04:01.582808'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:05:01.362841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:06:01.192853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:07:01.103149'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:08:00.963072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:09:01.742821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:10:01.652856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:11:01.582800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:12:01.392817'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:13:01.382942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:14:01.292813'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:15:01.164018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:16:00.992916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:17:00.953094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:18:01.752866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:19:01.542872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:20:01.372812'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:21:01.242862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:22:01.173033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:23:01.131200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:24:00.953145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:25:01.772802'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:26:01.762955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:27:01.340630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:28:01.742967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:29:01.702799'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:30:01.564132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:31:01.632858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:32:01.532992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:33:01.342903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:34:01.522976'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:35:01.362820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:36:01.152910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:37:00.963145'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:38:01.742810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:39:01.572918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:40:01.523050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:41:01.524578'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:42:01.392952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:43:01.162853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:44:01.530260'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:45:00.954290'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:46:01.742904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:47:01.562909'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:48:01.562919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:49:01.372810'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:50:01.172831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:51:01.131450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:52:01.732890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:53:01.753089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:54:00.973093'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:55:01.772819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:56:01.572938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:57:01.432865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:58:01.542836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T07:59:01.352938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:00:01.194075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:01:01.331570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:02:00.993227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:03:01.772821'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:04:01.712926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:05:01.542973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:06:01.382923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:07:01.462809'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:08:01.512982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:09:01.413038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:10:01.342895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:11:01.183003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:12:01.153117'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:13:00.972989'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:14:00.952848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:15:00.954064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:16:01.782943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:17:01.552921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:18:01.432983'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:19:01.462907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:20:01.392901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:21:01.303004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:22:01.193760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:23:01.113172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:24:00.962852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:25:01.762866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:26:01.563040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:27:01.482850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:28:01.512858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:29:01.402944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:30:01.164321'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:31:01.213504'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:32:01.193132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:33:01.185043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:34:01.352914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:35:01.193228'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:36:01.133057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:37:00.992992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:38:01.772995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:39:01.552971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:40:01.442960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:41:01.323063'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:42:01.172914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:43:00.982920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:44:01.742944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:45:01.594102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:46:01.612860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:47:01.563124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:48:01.393034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:49:01.213078'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:50:00.993581'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:51:01.742872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:52:01.722846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:53:01.542868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:54:01.393178'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:55:01.243897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:56:01.192960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:57:01.295500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:58:01.762871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T08:59:01.752922'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:00:01.794124'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:01:01.792835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:02:01.552855'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:03:01.362946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:04:01.343004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:05:01.162984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:06:01.143050'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:07:00.952850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:08:00.952840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:09:01.762870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:10:01.572980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:11:01.413096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:12:01.382916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:13:01.162988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:14:01.132950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:15:00.964153'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:16:00.972965'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:17:02.228550'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:18:00.962866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:19:01.288400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:20:01.762940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:21:01.573005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:22:01.363337'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:23:01.142887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:24:00.962887'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:25:01.753035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:26:01.763103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:27:00.963901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:28:01.793010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:29:00.972928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:30:01.744186'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:31:01.662871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:32:01.522949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:33:01.372905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:34:01.372878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:35:01.172942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:36:01.152862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:37:00.963147'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:38:01.742958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:39:01.713012'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:40:00.952850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:41:00.962862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:42:01.752943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:43:01.743102'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:44:01.552891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:45:01.334229'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:46:01.163100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:47:00.972836'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:48:01.742920'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:49:01.802911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:50:01.592865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:51:01.402863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:52:01.172878'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:53:01.540980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:54:00.962870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:55:01.802952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:56:01.582886'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:57:01.312928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:58:01.172935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T09:59:01.128570'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:00:00.974079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:01:01.742992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:02:01.592885'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:03:01.553066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:04:01.352984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:05:01.213161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:06:01.431150'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:07:01.294200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:08:00.952803'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:09:01.753033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:10:01.683011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:11:01.563064'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:12:01.413161'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:13:01.172832'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:14:01.330960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:15:00.974026'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:16:01.732891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:17:01.702974'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:18:01.553140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:19:01.382901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:20:01.442928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:21:01.472895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:22:01.362881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:23:01.142907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:24:01.128780'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:25:00.952948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:26:01.752954'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:27:01.552941'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:28:01.362855'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:29:01.172838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:30:01.104318'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:31:01.103049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:32:00.962867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:33:01.752900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:34:01.330180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:35:00.962877'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:36:01.732847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:37:01.542857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:38:01.372840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:39:01.162879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:40:00.962851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:41:01.742969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:42:01.572869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:43:01.353004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:44:01.383051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:45:01.194227'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:46:00.982856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:47:01.762893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:48:01.792840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:49:01.762982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:50:01.572869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:51:01.352900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:52:01.152899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:53:00.982992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:54:00.962865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:55:01.752880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:56:01.552818'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:57:01.422830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:58:01.343475'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T10:59:01.172899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:00:01.164049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:01:01.172863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:02:01.202962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:03:01.132984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:04:01.132985'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:05:00.992837'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:06:01.762872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:07:01.562894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:08:01.382899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:09:01.182957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:10:01.233001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:11:01.182933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:12:00.982917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:13:01.792967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:14:01.622949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:15:01.574080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:16:01.352927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:17:01.305212'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:18:01.132947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:19:00.972853'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:20:01.762919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:21:01.602854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:22:01.512933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:23:01.392851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:24:01.202975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:25:01.163068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:26:00.962804'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:27:01.630910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:28:01.430770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:29:01.129640'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:30:01.774351'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:31:01.823081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:32:01.763194'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:33:01.612895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:34:01.293800'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:35:01.743061'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:36:01.612958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:37:01.402933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:38:01.172846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:39:00.962858'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:40:01.309200'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:41:01.637410'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:42:00.952848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:43:00.952949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:44:01.763041'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:45:01.704120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:46:01.542940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:47:01.422867'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:48:01.392874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:49:01.242882'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:50:01.162908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:51:01.429240'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:52:00.952870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:53:01.742916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:54:00.952870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:55:00.952979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:56:01.732963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:57:01.572840'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:58:01.612973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T11:59:01.322873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:00:01.314123'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:01:01.142998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:02:00.982888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:03:01.742890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:04:01.542850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:05:01.382964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:06:01.163051'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:07:01.143207'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:08:01.128390'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:09:01.782864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:10:01.572940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:11:01.392896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:12:01.143013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:13:00.962833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:14:01.742851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:15:01.764251'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:16:01.592854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:17:01.393018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:18:01.412999'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:19:01.163215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:20:01.142900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:21:01.113128'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:22:00.982862'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:23:01.782852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:24:01.692998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:25:01.563142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:26:01.402949'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:27:01.183018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:28:00.972849'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:29:01.752895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:30:01.704148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:31:01.612855'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:32:01.532855'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:33:01.422864'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:34:01.612835'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:35:01.623374'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:36:01.542824'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:37:01.383031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:38:01.142868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:39:00.972946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:40:01.742898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:41:01.532892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:42:01.532884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:43:01.382948'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:44:01.172919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:45:01.174155'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:46:00.953017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:47:01.772873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:48:01.592866'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:49:01.552947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:50:01.392958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:51:01.163025'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:52:01.103306'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:53:00.942961'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:54:01.742951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:55:01.592841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:56:01.353020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:57:01.193067'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:58:00.982890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T12:59:01.762842'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:00:01.584056'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:01:01.593129'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:02:01.602873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:03:01.562848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:04:01.402895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:05:01.262988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:06:01.162884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:07:01.329450'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:08:00.992831'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:09:00.952938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:10:01.752933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:11:01.562984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:12:01.372869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:13:01.183008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:14:01.182905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:15:01.194086'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:16:01.162990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:17:00.982815'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:18:00.992883'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:19:01.753031'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:20:01.572939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:21:01.392848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:22:01.203007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:23:01.162986'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:24:01.287000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:25:01.742851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:26:01.753082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:27:01.572833'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:28:01.602837'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:29:01.573003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:30:01.384094'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:31:01.272852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:32:01.162871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:33:01.162892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:34:01.372850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:35:01.162940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:36:01.298100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:37:01.753015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:38:01.552870'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:39:01.432905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:40:01.382828'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:41:01.282987'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:42:01.202934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:43:01.163140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:44:00.972829'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:45:01.744107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:46:01.563003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:47:01.362868'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:48:01.273035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:49:01.182884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:50:01.122950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:51:00.992847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:52:01.722859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:53:01.582936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:54:01.562838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:55:01.602857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:56:01.423219'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:57:01.322944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:58:01.192819'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T13:59:01.102946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:00:00.964062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:01:01.752842'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:02:01.563027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:03:01.392826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:04:01.192888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:05:01.142884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:06:01.331370'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:07:00.942923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:08:00.992854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:09:01.129690'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:10:00.962876'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:11:01.772995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:12:01.552834'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:13:01.403107'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:14:01.172891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:15:01.242120'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:16:00.962855'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:17:01.772852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:18:01.552891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:19:01.382901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:20:01.212871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:21:01.222841'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:22:01.152888'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:23:01.332350'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:24:00.962859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:25:01.722851'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:26:01.522872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:27:01.522969'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:28:01.562854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:29:01.372998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:30:01.204208'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:31:01.232995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:32:01.152917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:33:01.229480'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:34:01.362869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:35:01.243183'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:36:01.152956'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:37:00.982848'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:38:01.742830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:39:01.552830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:40:01.472963'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:41:01.373054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:42:01.162879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:43:01.129580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:44:01.732857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:45:01.604181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:46:01.512992'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:47:01.572911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:48:01.412869'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:49:01.302852'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:50:01.282847'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:51:01.142935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:52:00.993011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:53:01.732873'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:54:01.743037'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:55:01.542962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:56:01.332901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:57:01.293009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:58:01.142919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T14:59:00.994201'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:00:01.774132'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:01:01.732861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:02:01.752826'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:03:01.582860'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:04:01.392973'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:05:01.182893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:06:00.962894'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:07:01.782907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:08:01.752871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:09:01.582861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:10:01.402951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:11:01.342900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:12:01.172881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:13:01.431940'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:14:01.202913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:15:01.304148'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:16:01.172980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:17:01.113054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:18:01.240180'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:19:01.752955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:20:01.562846'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:21:01.392854'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:22:01.182859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:23:01.231010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:24:00.972838'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:25:01.732918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:26:01.542859'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:27:01.442861'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:28:01.442915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:29:01.383007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:30:01.374066'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:31:01.272857'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:32:01.142884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:33:00.972918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:34:01.202881'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:35:01.299000'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:36:00.962844'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:37:01.752970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:38:01.662990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:39:01.532926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:40:01.363014'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:41:01.352917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:42:01.342924'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:43:01.272932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:44:01.183042'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:45:00.974177'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:46:01.762932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:47:01.532995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:48:01.353004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:49:01.153019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:50:01.304500'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:51:01.752907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:52:01.722902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:53:01.552923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:54:01.452901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:55:01.542910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:56:01.512921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:57:01.352944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:58:01.183010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T15:59:01.328930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:00:00.964097'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:01:00.973060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:02:01.732907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:03:01.542890'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:04:01.383023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:05:01.403137'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:06:01.173151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:07:01.730540'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:08:01.631770'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:09:00.952994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:10:01.773008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:11:01.612946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:12:01.573016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:13:01.513032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:14:01.363040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:15:01.314215'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:16:01.173033'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:17:00.962942'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:18:00.963019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:19:01.762900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:20:01.603139'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:21:01.613233'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:22:01.683016'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:23:01.553040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:24:01.372991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:25:01.152932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:26:00.972928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:27:01.724098'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:28:01.653108'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:29:01.582926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:30:01.394253'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:31:01.232928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:32:01.463005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:33:01.422994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:34:01.563017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:35:01.703034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:36:01.543820'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:37:01.513002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:38:01.322945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:39:01.322982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:40:01.162964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:41:00.972959'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:42:00.972889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:43:00.992929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:44:00.962912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:45:00.944141'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:46:01.762918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:47:01.602912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:48:01.562903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:49:01.502906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:50:01.333081'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:51:01.193018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:52:00.972967'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:53:01.762982'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:54:01.542906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:55:01.403010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:56:01.193001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:57:00.992918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:58:01.712907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T16:59:01.583080'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:00:01.384315'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:01:01.412991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:02:01.183052'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:03:00.982910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:04:00.952939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:05:01.752872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:06:01.563071'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:07:01.352991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:08:01.162938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:09:01.228930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:10:01.752955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:11:01.572998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:12:01.432901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:13:01.412910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:14:01.343032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:15:01.354310'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:16:01.363018'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:17:01.152925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:18:01.329490'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:19:00.973065'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:20:01.792945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:21:01.702946'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:22:01.582900'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:23:01.502977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:24:01.402929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:25:01.192957'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:26:00.983043'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:27:01.130010'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:28:00.963082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:29:00.953009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:30:01.754249'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:31:01.663095'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:32:01.593111'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:33:01.502910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:34:01.682958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:35:01.552916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:36:01.442908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:37:01.392911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:38:01.173185'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:39:01.152928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:40:01.173034'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:41:01.292600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:42:01.430100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:43:01.330580'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:44:00.972955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:45:01.764286'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:46:01.573004'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:47:01.333351'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:48:01.183011'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:49:01.632670'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:50:00.992928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:51:01.762918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:52:01.552966'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:53:01.402884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:54:01.223020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:55:01.382892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:56:01.312880'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:57:01.163032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:58:00.982911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T17:59:00.952962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:00:00.954343'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:01:01.732931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:02:01.753089'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:03:01.563386'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:04:01.372892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:05:01.153038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:06:01.296100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:07:01.732930'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:08:01.743154'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:09:01.762903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:10:01.722997'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:11:01.602889'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:12:01.373068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:13:01.342977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:14:01.173057'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:15:00.944327'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:16:01.752914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:17:01.753017'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:18:01.552929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:19:01.382938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:20:01.172953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:21:01.113276'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:22:01.103088'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:23:00.992923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:24:01.742925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:25:01.552998'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:26:01.542944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:27:01.342945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:28:01.193143'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:29:00.983395'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:30:00.944268'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:31:01.863453'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:32:01.743045'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:33:01.613072'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:34:01.152968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:35:01.122979'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:36:01.301100'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:37:00.972905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:38:01.742996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:39:01.552952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:40:01.362953'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:41:01.172944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:42:00.972789'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:43:01.762908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:44:01.553167'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:45:01.514433'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:46:01.393165'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:47:01.203019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:48:01.362944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:49:01.173030'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:50:00.972926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:51:01.743053'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:52:01.602921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:53:01.552923'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:54:01.383019'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:55:01.312960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:56:01.193082'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:57:00.993008'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:58:01.762977'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T18:59:01.762939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:00:01.644181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:01:01.762905'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:02:01.752932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:03:01.602898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:04:01.403188'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:05:01.212932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:06:00.994307'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:07:01.782988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:08:01.553009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:09:01.473181'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:10:01.332932'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:11:01.162978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:12:01.331110'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:13:01.762918'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:14:01.733046'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:15:01.764160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:16:01.743400'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:17:01.724261'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:18:01.733020'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:19:01.582898'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:20:01.363075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:21:01.352960'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:22:01.182913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:23:00.973024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:24:01.752906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:25:01.542939'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:26:01.413160'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:27:01.343003'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:28:01.332897'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:29:01.313035'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:30:01.174172'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:31:01.830340'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:32:00.952906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:33:01.783062'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:34:00.962972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:35:01.732931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:36:01.633079'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:37:01.523005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:38:01.552944'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:39:01.342911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:40:01.222995'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:41:01.552896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:42:01.442972'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:43:01.382912'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:44:01.223005'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:45:01.274282'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:46:01.212945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:47:00.963049'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:48:01.762926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:49:01.552908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:50:01.432896'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:51:01.342908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:52:01.162955'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:53:00.992910'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:54:01.428980'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:55:01.528950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:56:00.942863'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:57:01.732917'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:58:01.562962'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T19:59:01.452879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:00:01.374373'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:01:01.173103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:02:01.162990'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:03:00.993038'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:04:01.772902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:05:01.742971'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:06:01.722879'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:07:01.693024'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:08:01.622978'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:09:01.383103'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:10:01.182936'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:11:00.952950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:12:01.752907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:13:01.672874'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:14:01.563009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:15:01.374092'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:16:01.322933'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:17:01.182929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:18:01.182901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:19:00.963047'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:20:01.742913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:21:01.742975'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:22:01.582893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:23:01.402968'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:24:01.193068'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:25:01.103122'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:26:00.962908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:27:01.743380'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:28:01.592938'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:29:01.383069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:30:01.174142'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:31:01.931060'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:32:01.128850'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:33:01.783027'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:34:01.153487'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:35:01.162915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:36:00.982984'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:37:01.762892'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:38:01.743002'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:39:01.562981'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:40:01.433084'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:41:01.362927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:42:01.182952'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:43:01.931650'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:44:00.982904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:45:01.342630'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:46:01.752945'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:47:00.952934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:48:00.962871'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:49:01.752893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:50:01.582908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:51:01.372996'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:52:01.173096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:53:01.128760'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:54:00.972925'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:55:01.812906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:56:01.712893'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:57:01.573009'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:58:01.443156'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T20:59:01.352899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:00:01.354085'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:01:01.312988'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:02:01.162921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:03:01.298600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:04:00.952911'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:05:01.732903'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:06:01.753311'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:07:01.542907'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:08:01.422958'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:09:01.372872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:10:01.163121'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:11:00.972856'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:12:01.733140'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:13:01.773054'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:14:01.722994'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:15:01.544115'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:16:01.592943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:17:01.433830'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:18:01.333151'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:19:01.163131'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:20:01.129430'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:21:01.752914'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:22:01.563023'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:23:01.382951'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:24:01.182935'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:25:01.142927'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:26:01.232320'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:27:00.983013'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:28:00.953032'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:29:01.803015'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:30:01.584106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:31:01.462931'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:32:01.302926'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:33:01.342884'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:34:01.392906'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:35:01.153119'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:36:00.972872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:37:01.732904'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:38:01.532908'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:39:01.452899'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:40:01.452991'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:41:01.362916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:42:01.333075'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:43:01.192915'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:44:01.229970'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:45:00.964134'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:46:01.752943'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:47:01.622891'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:48:01.562895'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:49:01.403001'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:50:01.332901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:51:01.142950'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:52:00.942928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:53:01.772865'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:54:01.643069'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:55:01.593096'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:56:01.492919'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:57:01.362934'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:58:01.162947'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T21:59:01.130600'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:00:01.774106'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:01:01.562913'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:02:01.332921'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:03:01.183074'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:04:00.982872'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:05:01.762964'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:06:01.572901'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:07:01.512902'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:08:01.593443'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:09:01.403007'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:10:01.322928'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:11:01.172916'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:12:01.317300'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:13:01.742929'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:14:01.693040'</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">numpy.datetime64</span><span style="font-weight: bold">(</span><span style="color: #008000; text-decoration-color: #008000">'2021-06-28T22:15:01.614231'</span><span style="font-weight: bold">)]</span>,
    <span style="color: #008000; text-decoration-color: #008000">'type'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">67</span>
<span style="font-weight: bold">}</span>
</pre>



### CRFS Bin - Versão 5 - Arquivos Comprimidos
Vamos listar arquivos da última versão do script Logger, Versão 5, arquivos comprimidos onde o piso de ruído é suprimido.

```python
file = r'binfiles\compressed\rfeye002290_210922_T204046_MaskBroken.bin'
```

```python
%%time
compressed = parse_bin(file)
```

    Wall time: 8.15 s
    

```python
print(compressed)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span>
    <span style="color: #008000; text-decoration-color: #008000">'filename'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002290_210922_T204046_MaskBroken.bin'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_version'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">23</span>,
    <span style="color: #008000; text-decoration-color: #008000">'string'</span>: <span style="color: #008000; text-decoration-color: #008000">'CRFS DATA FILE V023'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'hostname'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002290'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'method'</span>: <span style="color: #008000; text-decoration-color: #008000">'ScriptRFeye2021_v2.cfg'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'unit_info'</span>: <span style="color: #008000; text-decoration-color: #008000">'Stationary'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_number'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'identifier'</span>: <span style="color: #008000; text-decoration-color: #008000">'INFO'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'gps'</span>: GPS Data - Median of Coordinates: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.68619</span>:<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span> Altitude: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">208.80</span> 
#Satellites: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'spectrum'</span>: <span style="font-weight: bold">[</span><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">321</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 3 de 10). @ </span>
<span style="color: #008000; text-decoration-color: #008000">-80dBm, 100kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">320.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">340.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">512</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">301</span>, 
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 1 de 10). @ -80dBm, 10kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">108.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">137.0</span>,
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14848</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3690</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>,
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">341</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 5 de 10). @ -80dBm, 100kHz.'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">960.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001218.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">6656</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">311</span>, 
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 2 de 10). @ -80dBm, 10kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">156.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">163.0</span>,
<span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3690</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, 
<span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">371</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 8 de 10). @ -80dBm, 100kHz.'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">2690.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1002898.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">5376</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, 
<span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">351</span>, 
<span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 6 de 10). @ -80dBm, 100kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001388.999</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001428.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1280</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">331</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa </span>
<span style="color: #008000; text-decoration-color: #008000">4 de 10). @ -80dBm, 100kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">400.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">410.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">256</span>, 
<span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">68</span>, 
<span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">361</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'PMEC 2021 (Faixa 7 de 10). @ -80dBm, 100kHz.'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1530.0</span>,
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1001648.999</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3072</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">73828</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-100</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)]</span>
<span style="font-weight: bold">}</span>
</pre>



```python
fluxo = compressed['spectrum'] ; fluxos
```




    (#20) [SpecData(type=67, thread_id=300, description='PMEC 2021 (Faixa 1 de 10).', start_mega=105.0, stop_mega=140.0, dtype='dBm', ndata=3584, bw=18457, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5),SpecData(type=67, thread_id=310, description='PMEC 2021 (Faixa 2 de 10).', start_mega=155.0, stop_mega=165.0, dtype='dBm', ndata=1024, bw=18457, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5),SpecData(type=67, thread_id=100, description='PRD 2021 (Faixa principal 1 de 4).', start_mega=50.0, stop_mega=90.0, dtype='dBμV/m', ndata=1024, bw=73828, processing='peak', antuid=0, thresh=-70.5, minimum=-70.5),SpecData(type=67, thread_id=110, description='PRD 2021 (Faixa principal 2 de 4).', start_mega=70.0, stop_mega=110.0, dtype='dBμV/m', ndata=1024, bw=73828, processing='peak', antuid=0, thresh=-29.5, minimum=-29.5),SpecData(type=67, thread_id=120, description='PRD 2021 (Faixa principal 3 de 4).', start_mega=170.0, stop_mega=220.0, dtype='dBμV/m', ndata=1280, bw=73828, processing='peak', antuid=0, thresh=-69.5, minimum=-69.5),SpecData(type=67, thread_id=130, description='PRD 2021 (Faixa principal 4 de 4).', start_mega=470.0, stop_mega=700.0, dtype='dBμV/m', ndata=5888, bw=73828, processing='peak', antuid=0, thresh=-42.5, minimum=-42.5),SpecData(type=67, thread_id=200, description='PMEF 2021 (Faixa 1 de 6).', start_mega=700.0, stop_mega=960.0, dtype='dBm', ndata=6656, bw=73828, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5),SpecData(type=67, thread_id=210, description='PMEF 2021 (Faixa 2 de 6).', start_mega=1710.0, stop_mega=1980.0, dtype='dBm', ndata=6912, bw=73828, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5),SpecData(type=67, thread_id=220, description='PMEF 2021 (Faixa 3 de 6).', start_mega=2100.0, stop_mega=1002168.999, dtype='dBm', ndata=1792, bw=73828, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5),SpecData(type=67, thread_id=230, description='PMEF 2021 (Faixa 4 de 6).', start_mega=2290.0, stop_mega=2390.0, dtype='dBm', ndata=2560, bw=73828, processing='peak', antuid=0, thresh=-147.5, minimum=-147.5)...]



```python
fluxo = fluxos[0]
fluxo.matrix().iloc[:5, [0, 1, 2, -3, -2, -1]]
```




<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>Frequencies</th>
      <th>105.000000</th>
      <th>105.009768</th>
      <th>105.019537</th>
      <th>139.980463</th>
      <th>139.990232</th>
      <th>140.000000</th>
    </tr>
    <tr>
      <th>Time</th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>2021-06-22 15:18:01.549012</th>
      <td>-93.5</td>
      <td>-99.5</td>
      <td>-90.5</td>
      <td>-85.0</td>
      <td>-86.5</td>
      <td>-90.5</td>
    </tr>
    <tr>
      <th>2021-06-22 15:19:01.408958</th>
      <td>-93.5</td>
      <td>-90.5</td>
      <td>-90.5</td>
      <td>-88.0</td>
      <td>-88.5</td>
      <td>-90.0</td>
    </tr>
    <tr>
      <th>2021-06-22 15:20:01.149028</th>
      <td>-90.5</td>
      <td>-86.5</td>
      <td>-86.5</td>
      <td>-90.5</td>
      <td>-86.0</td>
      <td>-85.5</td>
    </tr>
    <tr>
      <th>2021-06-22 15:21:00.968982</th>
      <td>-90.5</td>
      <td>-90.5</td>
      <td>-91.5</td>
      <td>-87.5</td>
      <td>-88.5</td>
      <td>-88.0</td>
    </tr>
    <tr>
      <th>2021-06-22 15:22:01.729287</th>
      <td>-91.0</td>
      <td>-90.0</td>
      <td>-86.5</td>
      <td>-89.5</td>
      <td>-88.0</td>
      <td>-87.0</td>
    </tr>
  </tbody>
</table>
</div>



```python
print(len(fluxo))
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9058</span>
</pre>



### CRFS Bin - Versão 4

```python
file = r'binfiles\v4\rfeye002292_210208_T202215_CRFSBINv.4.bin'
blocks = parse_bin(file)
print(blocks)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span>
    <span style="color: #008000; text-decoration-color: #008000">'filename'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002292_210208_T202215_CRFSBINv.4.bin'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_version'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">22</span>,
    <span style="color: #008000; text-decoration-color: #008000">'string'</span>: <span style="color: #008000; text-decoration-color: #008000">'CRFS DATA FILE V022'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'hostname'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002292'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'method'</span>: <span style="color: #008000; text-decoration-color: #008000">'Script_CRFSBINv4'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'unit_info'</span>: <span style="color: #008000; text-decoration-color: #008000">'Stationary'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_number'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'identifier'</span>: <span style="color: #008000; text-decoration-color: #008000">'LOGGER_VERSION'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'group_id'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'text'</span>: <span style="color: #008000; text-decoration-color: #008000">'ClearWrite. Peak.'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'gps'</span>: GPS Data - Median of Coordinates: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.68619</span>:<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span> Altitude: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">208.80</span> 
#Satellites: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'spectrum'</span>: <span style="font-weight: bold">[</span><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">20</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">76.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">108.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">8192</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">30</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">70.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">110.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1024</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">39</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">10</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, 
<span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">12</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">63</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">13</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>,
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">9</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>,
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">48</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">51</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">47</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">46</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">59</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">44</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">62</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">50</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">49</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">43</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">52</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">54</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">42</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">37</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">53</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">45</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">55</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">58</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">64</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">description</span>=<span style="color: #008000; text-decoration-color: #008000">'Peak'</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105.0</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140.0</span>, <span style="color: #808000; text-decoration-color: #808000">dtype</span>=<span style="color: #008000; text-decoration-color: #008000">'dBm'</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">bw</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">39</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, 
<span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)]</span>
<span style="font-weight: bold">}</span>
</pre>



```python
blocks['spectrum'][0].matrix().iloc[:5, [0, 1, 2, -3, -2, -1]]
```




<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>Frequencies</th>
      <th>76.000000</th>
      <th>76.003907</th>
      <th>76.007813</th>
      <th>107.992187</th>
      <th>107.996093</th>
      <th>108.000000</th>
    </tr>
    <tr>
      <th>Time</th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>2021-02-08 20:22:15.500658</th>
      <td>-110.0</td>
      <td>-100.5</td>
      <td>-99.0</td>
      <td>-103.0</td>
      <td>-99.0</td>
      <td>-96.0</td>
    </tr>
    <tr>
      <th>2021-02-08 20:22:16.142770</th>
      <td>-105.5</td>
      <td>-100.0</td>
      <td>-97.5</td>
      <td>-94.5</td>
      <td>-95.0</td>
      <td>-98.0</td>
    </tr>
    <tr>
      <th>2021-02-08 20:22:16.500750</th>
      <td>-104.0</td>
      <td>-102.5</td>
      <td>-105.5</td>
      <td>-95.5</td>
      <td>-98.5</td>
      <td>-93.0</td>
    </tr>
    <tr>
      <th>2021-02-08 20:22:17.132990</th>
      <td>-105.0</td>
      <td>-107.0</td>
      <td>-103.0</td>
      <td>-99.5</td>
      <td>-99.5</td>
      <td>-102.5</td>
    </tr>
    <tr>
      <th>2021-02-08 20:22:17.501352</th>
      <td>-97.5</td>
      <td>-101.5</td>
      <td>-97.0</td>
      <td>-104.5</td>
      <td>-102.0</td>
      <td>-99.5</td>
    </tr>
  </tbody>
</table>
</div>



### CRFS Bin - Versão 3

```python
file = r'binfiles\v3\rfeye002292_210208_T203238_CRFSBINv.3.bin'
blocks = parse_bin(file)
print(blocks)
```


<pre style="white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace"><span style="font-weight: bold">{</span>
    <span style="color: #008000; text-decoration-color: #008000">'filename'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002292_210208_T203238_CRFSBINv.3.bin'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_version'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">21</span>,
    <span style="color: #008000; text-decoration-color: #008000">'string'</span>: <span style="color: #008000; text-decoration-color: #008000">'CRFS DATA FILE V021'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'hostname'</span>: <span style="color: #008000; text-decoration-color: #008000">'rfeye002292'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'method'</span>: <span style="color: #008000; text-decoration-color: #008000">'Script_CRFSBINv3'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'unit_info'</span>: <span style="color: #008000; text-decoration-color: #008000">'Stationary'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'file_number'</span>: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'identifier'</span>: <span style="color: #008000; text-decoration-color: #008000">'LOGGER_VERSION'</span>,
    <span style="color: #008000; text-decoration-color: #008000">'gps'</span>: GPS Data - Median of Coordinates: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-10.68619</span>:<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-37.43918</span> Altitude: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">208.80</span> 
#Satellites: <span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11.0</span>,
    <span style="color: #008000; text-decoration-color: #008000">'spectrum'</span>: <span style="font-weight: bold">[</span><span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">10</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, 
<span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">11</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">20</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">76</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">108</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">8192</span>, 
<span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">30</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">70</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">110</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1024</span>, <span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">4</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">12</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, 
<span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'peak'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">60</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">13</span>, 
<span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, <span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, 
<span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)</span>, <span style="color: #800080; text-decoration-color: #800080; font-weight: bold">SpecData</span><span style="font-weight: bold">(</span><span style="color: #808000; text-decoration-color: #808000">type</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">61</span>, <span style="color: #808000; text-decoration-color: #808000">thread_id</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">14</span>, <span style="color: #808000; text-decoration-color: #808000">start_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">105</span>, <span style="color: #808000; text-decoration-color: #808000">stop_mega</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">140</span>, <span style="color: #808000; text-decoration-color: #808000">ndata</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">3584</span>, 
<span style="color: #808000; text-decoration-color: #808000">nloops</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">1</span>, <span style="color: #808000; text-decoration-color: #808000">processing</span>=<span style="color: #008000; text-decoration-color: #008000">'average'</span>, <span style="color: #808000; text-decoration-color: #808000">antuid</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">0</span>, <span style="color: #808000; text-decoration-color: #808000">thresh</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-90</span>, <span style="color: #808000; text-decoration-color: #808000">minimum</span>=<span style="color: #008080; text-decoration-color: #008080; font-weight: bold">-147.5</span><span style="font-weight: bold">)]</span>
<span style="font-weight: bold">}</span>
</pre>



```python
blocks['spectrum'][0].matrix().iloc[:5, [0, 1, 2, -3, -2, -1]]
```




<div>
<style scoped>
    .dataframe tbody tr th:only-of-type {
        vertical-align: middle;
    }

    .dataframe tbody tr th {
        vertical-align: top;
    }

    .dataframe thead th {
        text-align: right;
    }
</style>
<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th>Frequencies</th>
      <th>105.000000</th>
      <th>105.009768</th>
      <th>105.019537</th>
      <th>139.980463</th>
      <th>139.990232</th>
      <th>140.000000</th>
    </tr>
    <tr>
      <th>Time</th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
      <th></th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>2021-02-08 20:32:39.548000</th>
      <td>-76.5</td>
      <td>-76.0</td>
      <td>-76.5</td>
      <td>-94.5</td>
      <td>-91.0</td>
      <td>-90.0</td>
    </tr>
    <tr>
      <th>2021-02-08 20:32:40.133600</th>
      <td>-79.5</td>
      <td>-80.5</td>
      <td>-79.5</td>
      <td>-99.0</td>
      <td>-94.5</td>
      <td>-92.5</td>
    </tr>
    <tr>
      <th>2021-02-08 20:32:41.858000</th>
      <td>-69.0</td>
      <td>-69.0</td>
      <td>-69.0</td>
      <td>-97.5</td>
      <td>-92.5</td>
      <td>-90.0</td>
    </tr>
    <tr>
      <th>2021-02-08 20:32:42.137500</th>
      <td>-70.5</td>
      <td>-71.0</td>
      <td>-71.5</td>
      <td>-97.0</td>
      <td>-98.0</td>
      <td>-94.5</td>
    </tr>
    <tr>
      <th>2021-02-08 20:32:43.716000</th>
      <td>-71.0</td>
      <td>-69.5</td>
      <td>-70.0</td>
      <td>-97.0</td>
      <td>-89.0</td>
      <td>-87.0</td>
    </tr>
  </tbody>
</table>
</div>


